# SPDX-License-Identifier: GPL-2.0-or-later OR AGPL-3.0-or-later OR CERN-OHL-S-2.0+
from .stdcell import StdCell, Wire, Via, Device

_cells = [
    StdCell(
        name='a2_x2', width=80, height=200,
        nets={
            '_net0': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_net0_ndif1",
                    space={"bottom": "vssrail"}, conn={"right": "n_i0_1"},
                ),
                Wire('METAL1', (10, 30), 40, 6, False, name="m1_net0_1"),
                Wire(
                    'METAL1', 30, (60, 100), 6, False,
                    conn={"top": "v_net0_pdif1", "bottom": "m1_net0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 30, 160, 2, name="v_net0_pdif1",
                    space={"top": "vddrail"},
                    conn={"left": "p_i0_1", "right": "p_i1_1"},
                ),
                Via('POLY', 'METAL1', 32, 80, 2, conn={"right": "pl_net0_1"}),
                Device(
                    'nmos', 60, 31, 4, 38, 'vertical', name="n_net0_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 60, 150, 4, 80, 'vertical', name="p_net0_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 60, (60, 100), 4, False, name="pl_net0_1",
                    conn={"top": "p_net0_1", "bottom": "n_net0_1"},
                ),
            ],
            '_net1': [
                Wire(
                    'NDIF', 30, (16, 46), 12, False,
                    conn={"left": "n_i0_1", "right": "n_i1_1"},
                ),
            ],
            'i0': [
                Device(
                    'nmos', 20, 50, 4, 38, 'vertical', name="n_i0_1",
                    source_net='_net0', drain_net='_net1',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='vdd', drain_net='_net0',
                ),
                Wire(
                    'POLY', 20, (60, 100), False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "pl_i0_1"}),
                Wire(
                    'METAL1', 10, (62, 138), 6, True,
                    space={"top": "vddrail", "bottom": "v_net0_ndif1"},
                ),
            ],
            'i1': [
                Device(
                    'nmos', 40, 31, 4, 38, 'vertical', name="n_i1_1",
                    source_net='_net1', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 48, 60, 2, conn={"left": "n_i1_1"}),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_i1_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Via('POLY', 'METAL1', 48, 100, 2, conn={"left": "p_i1_1"}),
                Wire(
                    'METAL1', 50, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 70, 40, 2,
                    space={"bottom": "vssrail"}, conn={"left": "n_net0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2,
                    space={"top": "vddrail"}, conn={"left": "p_net0_1"},
                ),
                Wire(
                    'METAL1', 70, (60, 100), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 10, 182, 2, conn={"right": "p_i0_1"}),
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 50, 182, 2,
                    conn={"left": "p_i1_1", "right": "p_net0_1", "up": "vddrail"},
                ),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 50, 18, 2,
                    conn={"left": "n_i1_1", "right": "n_net0_1", "up": "vssrail"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a3_x2', width=100, height=200,
        nets={
            '_net0': [
                Wire(
                    'NDIF', 30, (40, 50), 3, False,
                    conn={"left": "n_i0_1", "right": "n_i1_1"},
                )
            ],
            '_net1': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2,
                    space={"top": "m1_i0_i"}, conn={"right": "n_i0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 160, 2,
                    space={"bottom": "m1_i0_i"}, conn={"right": "p_i0_1"},
                ),
                Wire('METAL1', (10, 70), 40, 3, False, name="m1_net1_1"),
                Wire('METAL1', (10, 70), 160, 3, False, name="m1_net1_2"),
                Via(
                    'PDIF', 'METAL1', 50, 160, 2, space={"bottom": "m1_i2_i"},
                    conn={"left": "p_i1_1", "right": "p_i2_1"},
                ),
                Wire(
                    'METAL1', 70, (60, 100), 3, False, name="m1_net1_3",
                    conn={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 72, 80, 2, conn={"right": "pl_net1_1"}),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net1_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net1_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 80, (56, 104), 4, False, name="pl_net1_1",
                    conn={"top": "p_net1_1", "bottom": "n_net1_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 50, (40, 50), 3, False,
                    conn={"left": "n_i1_1", "right": "n_i2_1"},
                )
            ],
            'i0': [
                Wire('METAL1', 10, (50, 150), 6, True, name="m1_i0_i"),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 20, 50, 4, 40, 'vertical', name="n_i0_1",
                    source_net='_net1', drain_net='_net0',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='_net1', drain_net='vdd',
                ),
                Wire(
                    'POLY', 20, (76, 124), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (62, 120), 6, True,
                    space={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 32, 100, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 50, 4, 40, 'vertical', name="n_i1_1",
                    source_net='_net0', drain_net='_net2',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_i1_1",
                    source_net='vdd', drain_net='_net1',
                ),
                Wire(
                    'POLY', 40, (76, 122), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire(
                    'METAL1', 50, (60, 150), 3, True, name="m1_i2_i",
                    space={"bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 52, 100, 2, conn={"right": "pl_i2_1"}),
                Device(
                    'nmos', 60, 50, 4, 40, 'vertical', name="n_i2_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'pmos', 60, 150, 4, 40, 'vertical', name="p_i2_1",
                    source_net='_net1', drain_net='vdd',
                ),
                Wire('POLY', 60, (60, 100), 4, False, name="pl_i2_1",
                    conn={"top": "p_i2_1", "bottom": "n_i2_1"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 90, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net1_1"},
                ),
                Wire(
                    'METAL1', 90, (60, 100), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via(
                    'PDIF', 'METAL1', 30, 182, 2,
                    conn={"left": "p_i0_1", "right": "p_i1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 182, 2,
                    conn={"left": "p_i2_1", "right": "p_net1_1", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 50, 184, 2),
                Wire('NTIE', 50, (180, 188), 8, False),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 70, 18, 2,
                    conn={"left": "n_i2_1", "right": "n_net1_1", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', 50, (10, 18), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a4_x2', width=120, height=200,
        nets={
            '_net0': [
                Wire(
                    'NDIF', 50, (34, 66), 4, False,
                    conn={"left": "n_i1_1", "right": "n_i2_1"},
                ),
            ],
            '_net1': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, space={"top": "m1_i0_i"},
                    conn={"right": "n_i0_1"},
                ),
                Wire('METAL1', (10, 90), 40, 6, False, name="m1_net1_1"),
                Via(
                    'PDIF', 'METAL1', 30, 160, 2, space={"bottom": "m1_i1_i"},
                    conn={"left": "p_i0_1", "right": "p_i1_1"},
                ),
                Wire('METAL1', (30, 90), 160, 6, False, name="m1_net1_2"),
                Via(
                    'PDIF', 'METAL1', 70, 160, 2, space={"bottom": "m1_i3_i"},
                    conn={"left": "p_i2_1", "right": "p_i3_1"},
                ),
                Wire(
                    'METAL1', 90, (42, 138), 6, False,
                    conn={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 92, 90, 2, conn={"right": "pl_net1_1"}),
                Device(
                    'nmos', 100, 31, 4, 38, 'vertical', name="n_net1_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 100, 150, 4, 80, 'vertical', name="p_net1_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 100, (60, 100), 4, False, name="pl_net1_1",
                    conn={"top": "p_net1_1", "bottom": "n_net1_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 70, (34, 66), 4, False,
                    conn={"left": "n_i2_1", "right": "n_i3_1"},
                ),
            ],
            '_net3': [
                Wire(
                    'NDIF', 30, (34, 66), 4, False,
                    conn={"left": "n_i0_1", "right": "n_i1_1"},
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 10, (50, 118), 6, True, name="m1_i0_i",
                    space={"top": "vddrail"},
                ),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 20, 50, 4, 40, 'vertical', name="n_i0_1",
                    source_net='_net1', drain_net='_net3',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='vdd', drain_net='_net1',
                ),
                Wire(
                    'POLY', 20, (76, 124), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (50, 150), 6, True, name="m1_i1_i",
                    space={"bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 32, 120, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 50, 4, 40, 'vertical', name="n_i1_1",
                    source_net='_net3', drain_net='_net0',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_i1_1",
                    source_net='_net1', drain_net='vdd',
                ),
                Wire(
                    'POLY', 40, (76, 124), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire(
                    'METAL1', 50, (50, 118), 6, True, name="m1_i2_i",
                    space={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 52, 100, 2, conn={"right": "pl_i2_1"}),
                Device(
                    'nmos', 60, 50, 4, 40, 'vertical', name="n_i2_1",
                    source_net='_net0', drain_net='_net2',
                ),
                Device(
                    'pmos', 60, 150, 4, 40, 'vertical', name="p_i2_1",
                    source_net='vdd', drain_net='_net1',
                ),
                Wire(
                    'POLY', 60, (98, 124), 4, False, name="pl_i2_1",
                    conn={"top": "p_i2_1", "bottom": "n_i2_1"},
                ),
            ],
            'i3': [
                Wire(
                    'METAL1', 70, (50, 150), 6, True, name="m1_i3_i",
                    space={"bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 72, 80, 2, conn={"right": "pl_i3_1"}),
                Device(
                    'nmos', 80, 50, 4, 40, 'vertical', name="n_i3_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'pmos', 80, 150, 4, 40, 'vertical', name="p_i3_1",
                    source_net='_net1', drain_net='vdd',
                ),
                Wire(
                    'POLY', 80, (80, 124), 4, False, name="pl_i3_1",
                    conn={"top": "p_i3_1", "bottom": "n_i3_1"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 110, 40, 2, name="v_q_ndif1",
                    space={"bottom": "vssrail"}, conn={"left": "n_net1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 110, 140, 2, name="v_q_pdif1",
                    space={"top": "vddrail"}, conn={"left": "p_net1_1"},
                ),
                Wire(
                    'METAL1', 110, (60, 100), 6, True,
                    space= {"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 10, 182, 2, conn={"right": "p_i0_1"}),
                Via(
                    'PDIF', 'METAL1', 50, 182, 2,
                    conn={"left": "p_i1_1", "right": "p_i2_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 182, 2,
                    conn={"left": "p_i3_1", "right": "p_net1_1", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 8, False),
                Via('NTIE', 'METAL1', 70, 184, 2),
                Wire('NTIE', 70, (180, 188), 8, False),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 90, 18, 2,
                    conn={"left": "n_i3_1", "right": "n_net1_1", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', 30, (10, 18), 8, False),
                Via('PTIE', 'METAL1', 70, 14, 2),
                Wire('PTIE', 70, (10, 18), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ao22_x2', width=100, height=200,
        nets={
            '_net0': [
                Via(
                    'NDIF', 'METAL1', 30, 60, 2, name="v_net0_ndif1",
                    space={"top": "m1_i1_1", "bottom": "vssrail"},
                    conn={"left": "n_i0_1", "right": "n_i1_1"},
                ),
                Wire(
                    'METAL1', (30, 50), 60, 3, False, name="m1_net0_1",
                    conn={"left": "v_net0_ndif1"},
                ),
                Wire(
                    'METAL1', 50, (60, 100), 3, False,
                    conn={"top": "v_net0_pdif1", "bottom": "m1_net0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 50, 140, 2, name="v_net0_pdif1",
                    conn={"left": "p_i1_1", "right": "p_i2_1"},
                ),
                Via('POLY', 'METAL1', 52, 80, 2, conn={"right": "pl_net0_1"}),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net0_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net0_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 80, (56, 104), 4, False, name="pl_net0_1",
                    conn={"top": "p_net0_1", "bottom": "n_net0_1"},
                ),
            ],
            '_net1': [
                Wire(
                    'PDIF', 30, (130, 162), 3, False,
                    conn={"left": "p_i0_1", "right": "p_i1_1"},
                ),
            ],
            '_net2': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_net2_ndif1",
                    conn={"right": "n_i0_1"},
                ),
                Via(
                    'NDIF', 'METAL1', 50, 40, 2,
                    conn={"left": "n_i1_1", "right": "n_i2_1"},
                ),
                Wire('METAL1', (10, 50), 40, 6, False),
            ],
            'i0': [
                Wire(
                    'METAL1', 10, (82, 138), 6, True,
                    space={"top": "vddrail", "bottom": "v_net2_ndif1"},
                ),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='_net2', drain_net='_net0',
                ),
                Device(
                    'pmos', 20, 146, 4, 40, 'vertical', name="p_i0_1",
                    source_net='vdd', drain_net='_net1',
                ),
                Wire(
                    'POLY', 20, (56, 124), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (70, 158), 6, True, name="m1_i1_1",
                    space={"top": "vddrail"},
                ),
                Via('POLY', 'METAL1', 32, 100, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_i1_1",
                    source_net='_net0', drain_net='_net2',
                ),
                Device(
                    'pmos', 40, 146, 4, 40, 'vertical', name="p_i1_1",
                    source_net='_net1', drain_net='_net0',
                ),
                Wire(
                    'POLY', 40, (56, 104), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire(
                    'METAL1', 70, (62, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"}
                ),
                Via('POLY', 'METAL1', 68, 60, 2, conn={"left": "n_i2_1"}),
                Via('POLY', 'METAL1', 68, 100, 2, conn={"left": "p_i2_1"}),
                Device(
                    'nmos', 60, 40, 4, 20, 'vertical', name="n_i2_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'pmos', 60, 146, 4, 40, 'vertical', name="p_i2_1",
                    source_net='_net0', drain_net='vdd',
                ),
            ],
            'q': [
                Wire(
                    'METAL1', 90, (42, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 90, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net0_1"},
                ),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 10, 182, 2, conn={"right": "p_i0_1"}),
                Via(
                    'PDIF', 'METAL1', 70, 182, 2,
                    conn={"left": "p_i2_1", "right": "p_net0_1", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 50, 184, 2),
                Wire('NTIE', 50, (180, 188), 10, False),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 70, 18, 2,
                    conn={"left": "n_i2_1", "right": "n_net0_1", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', 50, (10, 18), 10, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='mx2_x2', width=140, height=200,
        nets={
            '_net0': [
                Wire(
                    'NDIF', 90, (35, 45), 4, False,
                    conn={"left": "n_cmd_2", "right": "n_i1_1"},
                ),
            ],
            '_net1': [
                Device(
                    'nmos', 120, 31, 4, 38, 'vertical', name="n_net1_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 120, 150, 4, 80, 'vertical', name="p_net1_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 120, (56, 104), 4, False, name="pl_net1_1",
                    conn={"top": "p_net1_1", "bottom": "n_net1_1"},
                ),
                Via('POLY', 'METAL1', 72, 100, 2, conn={"right": "pl_net1_1"}),
                Via(
                    'NDIF', 'METAL1', 70, 60, 2, name="v_net1_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_net5_1", "right": "n_cmd_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2, name="v_net1_pdif1",
                    space={"top": "vddrail"},
                    conn={"left": "p_cmd_2", "right": "p_net5_1"},
                ),
                Wire(
                    'METAL1', 70, (80, 120), 6, False,
                    conn={"top": "v_net1_pdif1", "bottom": "v_net1_ndif1"},
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 50, (15, 25), 4, False,
                    conn={"left": "n_i0_1", "right": "n_net5_1"},
                ),
            ],
            '_net3': [
                Wire(
                    'PDIF', 50, (134, 166), 4, False,
                    conn={"left": "p_i0_1", "right": "p_cmd_2"},
                ),
            ],
            '_net4': [
                Wire(
                    'PDIF', 90, (134, 166), 4, False,
                    conn={"left": "p_net5_1", "right": "p_i1_1"},
                ),
            ],
            '_net5': [
                Via('NDIF', 'METAL1', 10, 40, 2, conn={"right": "n_cmd_1"}),
                Via('PDIF', 'METAL1', 10, 140, 2, conn={"right": "p_cmd_1"}),
                Wire('METAL1', 10, (40, 140), 6, False, name="m1_net5_1"),
                Wire(
                    'METAL1', (10, 80), 40, 6, False, name="m1_net5_2",
                    conn={"left": "m1_net5_1", "right": "m1_net5_3"},
                ),
                Via('POLY', 'METAL1', 58, 40, 2, conn={"right": "n_net5_1"}),
                Device(
                    'nmos', 60, 21, 4, 18, 'vertical', name="n_net5_1",
                    source_net='_net2', drain_net='_net1',
                ),
                Via(
                    'POLY', 'METAL1', 83, 120, 2, name="v_net5_pl1",
                    conn={"left": "p_net5_1"},
                ),
                Device(
                    'pmos', 80, 150, 4, 40, 'vertical', name="p_net5_1",
                    source_net='_net1', drain_net='_net4',
                ),
                Wire(
                    'METAL1', 85, (40, 106), 6, False, name="m1_net5_3",
                    conn={"top": "v_net5_pl1"},
                ),
            ],
            'cmd': [
                Device(
                    'nmos', 20, 21, 4, 18, 'vertical', name="n_cmd_1",
                    source_net='_net5', drain_net='vss',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_cmd_1",
                    source_net='_net5', drain_net='vdd',
                ),
                Wire(
                    'POLY', 20, (52, 124), 4, False, name="pl_cmd_1",
                    conn={"top": "p_cmd_1", "bottom": "n_cmd_1"},
                ),
                Via(
                    'POLY', 'METAL1', 50, 80, 2,
                    conn={"left": "pl_cmd_1", "right": "n_cmd_2"}
                ),
                Wire(
                    'METAL1', 50, (62, 158), 6, True,
                    space={"top": "vddrail", "bottom": "m1_net5_2"},
                ),
                Wire('POLY', 60, (80, 120), 4, False, conn={"top": "p_cmd_2"}),
                Device(
                    'pmos', 60, 150, 4, 40, 'vertical', name="p_cmd_2",
                    source_net='_net3', drain_net='_net1',
                ),
                Device(
                    'nmos', 80, 41, 4, 18, 'vertical', name="n_cmd_2",
                    source_net='_net1', drain_net='_net0',
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 30, (62, 138), 6, True,
                    space={"top": "vddrail", "bottom": "m1_net5_2"},
                ),
                Device(
                    'nmos', 40, 21, 4, 18, 'vertical', name="n_i0_1",
                    source_net='vss', drain_net='_net2',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='vdd', drain_net='_net3',
                ),
                Via('POLY', 'METAL1', 32, 60, 2, conn={"right": "n_i0_1"}),
                Via('POLY', 'METAL1', 32, 120, 2, conn={"right": "p_i0_1"}),
            ],
            'i1': [
                Device(
                    'nmos', 100, 41, 4, 18, 'vertical', name="n_i1_1",
                    source_net='_net0', drain_net='vss',
                ),
                Device(
                    'pmos', 100, 150, 4, 40, 'vertical', name="p_i1_1",
                    source_net='_net4', drain_net='vdd',
                ),
                Wire(
                    'METAL1', 110, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 108, 60, 2, conn={"left": "n_i1_1"}),
                Wire('METAL1', (100, 110), 120, 3, conn={"left": "v_i1_pl1"}),
                Via(
                    'POLY', 'METAL1', 98, 120, 2, name="v_i1_pl1",
                    conn={"right": "p_i1_1"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 130, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 130, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net1_1"},
                ),
                Wire(
                    'METAL1', 130, (42, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via(
                    'PDIF', 'METAL1', 30, 182, 2,
                    conn={"left": "p_cmd_1", "right": "p_i0_1"}
                ),
                Via('NTIE', 'METAL1', 90, 184, 2),
                Wire('NTIE', 90, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 110, 182, 2,
                    conn={"left": "p_i1_1", "right": "p_net1_1", "up": "vddrail"},
                ),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 30, 18, 2,
                    conn={"left": "n_cmd_1", "right": "n_i0_1", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 90, 14, 2),
                Wire('PTIE', 90, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 110, 18, 2,
                    conn={"left": "n_i1_1", "right": "n_net1_1", "up": "vssrail"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='mx3_x2', width=220, height=200,
        nets={
            '_net0': [
                Via(
                    'PDIF', 'METAL1', 30, 160, 2, name="v_net0_pdif1",
                    space={"top": "vddrail"}, conn={"right": "p_i2_1"},
                ),
                Wire(
                    'METAL1', (30, 110), 160, 6, False, name="m1_net0_1",
                    # conn={"left": "v_net0_pdif1", "right": "v_net0_pdif2"},
                ),
                Via('PDIF', 'METAL1', 110, 160, 2, name="v_net0_pdif2",
                    space={"top": "vddrail", "bottom": "m1_net5_1"},
                    conn={"left": "p_i1_1", "right": "p_net4_1"},
                ),
            ],
            '_net1': [
                Via(
                    'NDIF', 'METAL1', 30, 40, 2, name="v_net1_ndif1",
                    space={"bottom": "vssrail"}, conn={"right": "n_i2_1"},
                ),
                Wire(
                    'METAL1', (30, 110), 40, 6, False,
                    conn={"left": "v_net1_ndif1", "right": "v_net1_ndif2"},
                ),
                Via(
                    'NDIF', 'METAL1', 110, 40, 2, name="v_net1_ndif2",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_i1_1", "right": "n_cmd0_2"},
                ),
            ],
            '_net2': [
                Wire(
                    'PDIF', 150, (154, 186), 4, False,
                    conn={"left": "p_cmd0_2", "right": "p_i0_1"},
                ),
            ],
            '_net3': [
                Via(
                    'NDIF', 'METAL1', 30, 64, 2, name="v_net3_ndif1",
                    conn={"left": "n_cmd1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 30, 120, 2, name="v_net3_pdif1",
                    space={"top": "m1_cmd1_1"}, conn={"left": "p_cmd1_1"},
                ),
                Wire(
                    'METAL1', 30, (80, 100), 3, False, name="m1_net3_1",
                    conn={"top": "v_net3_pdif1", "bottom": "v_net3_ndif1"},
                ),
                Wire(
                    'METAL1', (36, 60), 60, 6, False, name="m1_net3_2",
                    conn={"left": "v_net3_ndif1", "right": "v_net3_pl1"},
                ),
                Wire(
                    'METAL1', (36, 70), 120, 6, False, name="m1_net3_3",
                    conn={"left": "v_net3_pdif1", "right": "v_net3_pl2"},
                ),
                Via(
                    'POLY', 'METAL1', 58, 60, 2, name="v_net3_pl1",
                    conn={"right": "n_net3_1"},
                ),
                Device(
                    'nmos', 60, 34, 4, 24, 'vertical', name="n_net3_1",
                    source_net='_net9', drain_net='_net5',
                ),
                Via(
                    'POLY', 'METAL1', 75, 120, 2, name="v_net3_pl2",
                    conn={"right": "p_net3_1"},
                ),
                Device(
                    'pmos', 80, 150, 4, 40, 'vertical', name="p_net3_1",
                    source_net='_net5', drain_net='_net6',
                ),
            ],
            '_net4': [
                Via(
                    'NDIF', 'METAL1', 170, 64, 2, name="v_net4_ndif1",
                    conn={"right": "n_cmd0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 170, 120, 2, name="v_net4_pdif1",
                    space={"top": "m1_net5_1"}, conn={"right": "p_cmd0_1"},
                ),
                Wire(
                    'METAL1', 170, (80, 100), 6, False,
                    conn={"top": "v_net4_pdif1", "bottom": "v_net4_ndif1"},
                ),
                Device(
                    'nmos', 140, 26, 4, 24, 'vertical', name="n_net4_1",
                    source_net='vss', drain_net='_net7',    
                ),
                Device(
                    'pmos', 120, 170, 4, 40, 'vertical', name="p_net4_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Via(
                    'POLY', 'METAL1', 142, 60, 2, name="v_net4_pl1",
                    conn={"left": "p_net4_1"},
                ),
                Wire(
                    'METAL1', (140, 170), 60, 6, False, name="m1_net4_1",
                    conn={"left":"v_net4_pl1", "right": "v_net4_ndif1"},
                ),
                Wire(
                    'POLY', 140, (40, 60), False,
                    conn={"top": "v_net4_pl1", "bottom": "n_net4_1"},
                )
            ],
            '_net5': [
                Device(
                    'nmos', 200, 50, 4, 40, 'vertical', name="n_net5_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 200, 150, 4, 80, 'vertical', name="p_net5_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 200, (76, 104), 4, False, name="pl_net5_1",
                    conn={"top": "p_net5_1", "bottom": "n_net5_1"},
                ),
                Via('POLY', 'METAL1', 192, 80, 2, conn={"right": "pl_net5_1"}),
                Wire(
                    'METAL1', 190, (42, 138), 6, False,
                    conn={"top": "m1_net5_1", "bottom": "m1_net5_2"},
                ),
                Wire(
                    'METAL1', (84, 190), 140, 6, False, name="m1_net5_1",
                    conn={"left": "v_net5_pdif1"},
                ),
                Wire(
                    'METAL1', (170, 190), 40, 6, False, name="m1_net5_2",
                    conn={"left": "v_net5_ndif2"},
                ),
                Via(
                    'NDIF', 'METAL1', 170, 34, 2, name="v_net5_ndif2",
                    space={"bottom": "vssrail"}, conn={"left": "n_i0_1"},
                ),
                Wire(
                    'METAL1', 170, (142, 158), 6, False,
                    conn={"top": "v_net5_pdif2", "bottom": "m1_net5_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 170, 160, 2, name="v_net5_pdif2",
                    space={"top": "vddrail"}, conn={"left": "p_i0_1"},
                ),
                Wire(
                    'METAL1', 90, (62, 78), 6, False,
                    conn={"top": "m1_net5_1", "bottom": "m1_net5_3"},
                ),
                Wire(
                    'METAL1', (70, 90), 60, 6, False, name="m1_net5_3",
                    conn={"left": "v_net5_ndif1"},
                ),
                Via(
                    'NDIF', 'METAL1', 70, 60, 2, name="v_net5_ndif1",
                    conn={"left": "n_net3_1", "right": "n_cmd1_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2, name="v_net5_pdif1",
                    space={"top": "m1_net0_1"},
                    conn={"left": "p_cmd1_2", "right": "p_net3_1"},
                ),
            ],
            '_net6': [
                Wire(
                    'PDIF', 90, (134, 166), 4, False,
                    conn={"left": "p_net3_1", "right": "p_i1_1"},
                ),
            ],
            '_net7': [
                Wire(
                    'NDIF', 150, (26, 36), 8, False,
                    conn={"left": "n_net4_1", "right": "n_i0_1"},
                ),
            ],
            '_net8': [
                Wire(
                    'PDIF', 50, (154, 186), 4, False,
                    conn={"left": "p_i2_1", "right": "p_cmd1_2"},
                ),
            ],
            '_net9': [
                Wire(
                    'NDIF', 50, (26, 42), 8, False,
                    conn={"left": "n_i2_1", "right": "n_net3_1"},
                ),
            ],
            '_net10': [
                Wire(
                    'NDIF', 90, (36, 52), 8, False,
                    conn={"left": "n_cmd1_2", "right": "n_i1_1"},
                ),
            ],
            'cmd0': [
                Device(
                    'nmos', 180, 64, 4, 12, 'vertical', name="n_cmd0_1",
                    source_net='_net4', drain_net='vss',
                ),
                Device(
                    'pmos', 180, 124, 4, 28, 'vertical', name="p_cmd0_1",
                    source_net='_net4', drain_net='vdd',
                ),
                Wire(
                    'POLY', 180, (76, 104), 4, False, name="pl_cmd0_1",
                    conn={"top": "p_cmd0_1", "bottom": "n_cmd0_1"},
                ),
                Device(
                    'pmos', 140, 170, 4, 40, 'vertical', name="p_cmd0_2",
                    source_net='vdd', drain_net='_net2',
                ),
                Wire(
                    'POLY', 140, (100, 140), 2, False,
                    conn={"top": "p_cmd0_2"},
                ),
                Wire(
                    'METAL1', 130, (82, 118), 6, True,
                    space={"top": "m1_net5_1", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 132, 100, 2, conn={"right": "pl_cmd0_1"}),
                Via('POLY', 'METAL1', 128, 45, 2, conn={"left": "n_cmd0_2"}),
                Device(
                    'nmos', 120, 26, 4, 24, 'vertical', name="n_cmd0_2",
                    source_net='_net1', drain_net='vss',
                ),
            ],
            'cmd1': [
                Wire(
                    'METAL1', 10, (62, 140), 6, True, name="m1_cmd1_i",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "pl_cmd1_1"}),
                Device(
                    'nmos', 20, 66, 4, 16, 'vertical', name="n_cmd1_1",
                    source_net='vss', drain_net='_net3',
                ),
                Device(
                    'pmos', 20, 124, 4, 28, 'vertical', name="p_cmd1_1",
                    source_net='vdd', drain_net='_net3',
                ),
                Wire(
                    'POLY', 20, (80, 104), 4, False, name="pl_cmd1_1",
                    conn={"top": "p_cmd1_1", "bottom": "n_cmd1_1"},
                ),
                Wire(
                    'METAL1', (12, 60), 140, 6, False, name="m1_cmd1_1",
                    conn={"left": "m1_cmd1_i", "right": "v_cmd1_pl1"},
                ),
                Via('POLY', 'METAL1', 58, 140, 2, name="v_cmd1_pl1"),
                Device(
                    'pmos', 60, 170, 4, 40, 'vertical', name="p_cmd1_2",
                    source_net='_net8', drain_net='_net5',
                ),
                Wire(
                    'POLY', 60, (80, 140), 4, False,
                    conn={"top": "p_cmd1_2", "bottom": "pl_cmd1_2"},
                ),
                Wire('POLY', (60, 80), 80, 4, False, name="pl_cmd1_2"),
                Wire(
                    'POLY', 80, (52, 80), 4, False,
                    conn={"top": "pl_cmd1_2", "bottom": "n_cmd1_2"},
                ),
                Device(
                    'nmos', 80, 44, 4, 24, 'vertical', name="n_cmd1_2",
                    source_net='_net5', drain_net='_net10',
                ),
            ],
            'i0': [
                Device(
                    'nmos', 160, 26, 4, 24, 'vertical', name="n_i0_1",
                    source_net='_net7', drain_net='_net5',
                ),
                Device(
                    'pmos', 160, 170, 4, 40, 'vertical', name="p_i0_1",
                    source_net='_net2', drain_net='_net5',
                ),
                Via('POLY', 'METAL1', 152, 82, 2, conn={"right": "n_i0_1"}),
                Via('POLY', 'METAL1', 152, 120, 2, conn={"right": "p_i0_1"}),
                Wire(
                    'METAL1', 150, (80, 120), 6, True,
                    space={"top": "m1_net5_1", "bottom": "m1_net4_1"},
                ),
            ],
            'i1': [
                Device(
                    'nmos', 100, 44, 4, 24, 'vertical', name="n_i1_1",
                    source_net='_net10', drain_net='_net1',
                ),
                Device(
                    'pmos', 100, 150, 4, 40, 'vertical', name="p_i1_1",
                    source_net='_net6', drain_net='_net0',
                ),
                Wire(
                    'POLY', 100, (52, 144), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
                Wire(
                    'METAL1', 110, (80, 100), 3, True,
                    space={"top": "m1_net5_1", "bottom": "v_net1_ndif2"},
                ),
                Via('POLY', 'METAL1', 108, 100, 2, conn={"left": "pl_i1_1"}),
            ],
            'i2': [
                Device(
                    'nmos', 40, 34, 4, 24, 'vertical', name="n_i2_1",
                    source_net='_net1', drain_net='_net9',
                ),
                Device(
                    'pmos', 40, 170, 4, 40, 'vertical', name="p_i2_1",
                    source_net='_net0', drain_net='_net8',
                ),
                Wire(
                    'POLY', 40, (52, 144), 4, False, name="pl_i2_1",
                    conn={"top": "p_i2_1", "bottom": "n_i2_1"},
                ),
                Via('POLY', 'METAL1', 48, 100, 2, conn={"left": "pl_i2_1"}),
                Wire(
                    'METAL1', 50, (80, 100), 3, True,
                    space={"top": "m1_net3_3", "bottom": "m1_net3_2"},
                ),
            ],
            'q': [
                Via('NDIF', 'METAL1', 210, 60, 2, conn={"left": "n_net5_1"}),
                Via(
                    'PDIF', 'METAL1', 210, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net5_1"},
                ),
                Wire(
                    'METAL1', 210, (64, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 10, 182, 2, conn={"right": "p_cmd1_1"}),
                Via('NTIE', 'METAL1', 90, 184, 2),
                Wire('NTIE', 90, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 130, 182, 2,
                    conn={"left": "p_net4_1", "right": "p_cmd0_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 190, 182, 2, space={"bottom": "m1_net5_1"},
                    conn={"left": "p_cmd0_1", "right": "p_net5_1"},
                ),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 10, 18, 2, conn={"right": "n_cmd1_1"}),
                Via('PTIE', 'METAL1', 90, 14, 2),
                Wire('PTIE', 90, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 130, 18, 2,
                    conn={"left": "n_cmd0_2", "right": "n_net4_1", "up": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 190, 18, 2,
                    conn={"left": "n_cmd0_1", "right": "n_net5_1"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nsnrlatch_x1', width=100, height=200,
        nets={
            '_net0': [
                Wire(
                    'NDIF', 70, (40, 60), 4, False,
                    conn={"left": "n_q_1", "right": "n_nrst_1"},
                )
            ],
            '_net1': [
                Wire(
                    'NDIF', 30, (40, 60), 4, False,
                    conn={"left": "n_nset_1", "right": "n_nq_1"},
                )
            ],
            'nq': [
                Device(
                    'nmos', 40, 50, 4, 40, 'vertical', name="n_nq_1",
                    source_net='_net1', drain_net='vss',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_nq_1",
                    source_net='q', drain_net='vdd',
                ),
                Wire(
                    'POLY', 40, (76, 130), 2, False, name="pl_nq_1",
                    space={}, conn={"top": "n_nq_1", "bottom": "p_nq_1"},
                ),
                Via(
                    'POLY', 'METAL1', 42, 90, 2, name='v_nq_pl1',
                    conn={"right": "pl_nq_1"},
                ),
                Wire(
                    'METAL1', (50, 60), 90, 2,
                    conn={"left": "v_nq_pl1", "right": "m1_nq_1"},
                ),
                Wire(
                    'METAL1', 70, (40, 158), 3, True, name="m1_nq_1",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2,
                    conn={"left": "p_q_1", "right": "p_nrst_1"},
                ),
                Wire('METAL1', (69, 91), 40, 6, False),
                Via(
                    'NDIF', 'METAL1', 90, 40, 2,
                    space={"bottom": "vssrail"}, conn={"left": "n_nrst_1"},
                ),
            ],
            'nrst': [
                Device(
                    'nmos', 80, 50, 4, 40, 'vertical', name="n_nrst_1",
                    source_net='_net0', drain_net='nq',
                ),
                Device(
                    'pmos', 80, 150, 4, 40, 'vertical', name="p_nrst_1",
                    source_net='nq', drain_net='vdd',
                ),
                Wire(
                    'POLY', 80, (80, 124), 4, False, name="pl_nrst_1",
                    space={}, conn={"top": "p_nrst_1", "bottom": "n_nrst_1"},
                ),
                Wire('METAL1', 90, (80, 138), 6, True, space={"top": "vddrail"}),
                Via('POLY', 'METAL1', 88, 100, 2, conn={"left": "pl_nrst_1"}),
            ],
            'nset': [
                Device(
                    'nmos', 20, 50, 4, 40, 'vertical', name="n_nset_1",
                    source_net='q', drain_net='_net1',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_nset_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 20, (80, 124), 4, False, name="pl_nset_1",
                    space={}, conn={"top": "p_nset_1", "bottom": "n_nset_1"},
                ),
                Wire('METAL1', 10, (80, 138), 6, True, space={"top": "vddrail"}),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "pl_nset_1"}),
            ],
            'q': [
                Wire(
                    'METAL1', 30, (40, 158), 3, True, name="m1_q_1",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 30, 140, 2,
                    conn={"left": "p_nset_1", "right": "p_nq_1"},
                ),
                Wire('METAL1', (9, 31), 40, 6, False),
                Via(
                    'NDIF', 'METAL1', 10, 40, 2,
                    space={"bottom": "vssrail"}, conn={"right": "n_nset_1"},
                ),
                Device(
                    'nmos', 60, 50, 4, 40, 'vertical', name="n_q_1",
                    source_net='vss', drain_net='_net0',
                ),
                Device(
                    'pmos', 60, 150, 4, 40, 'vertical', name="p_q_1",
                    source_net='vdd', drain_net='nq',
                ),
                Wire(
                    'POLY', 60, (76, 130), 2, False, name="pl_q_1",
                    space={}, conn={"top": "n_q_1", "bottom": "p_q_1"},
                ),
                Wire(
                    'METAL1', (40, 50), 110, 2,
                    conn={"left": "m1_q_1", "right": "v_q_pl1"},
                ),
                Via(
                    'POLY', 'METAL1', 58, 110, 2, name="v_q_pl1",
                    conn={"right": "pl_q_1"},
                ),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 10, 182, 2, conn={"right": "p_nset_1"}),
                Via(
                    'PDIF', 'METAL1', 50, 160, 2, name="v_vdd_pdif1",
                     conn={"left": "p_nq_1", "right": "p_q_1"},
                ),
                Wire(
                    'METAL1', 50, (170, 180), 2,
                    conn={"bottom": "v_vdd_pdif1", "top": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 10, False),
                Via('NTIE', 'METAL1', 70, 184, 2),
                Wire('NTIE', 70, (180, 188), 10, False),
                Via('PDIF', 'METAL1', 90, 182, 2, conn={"left": "p_nrst_1"}),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', 30, (10, 18), 10, False),
                Via(
                    'NDIF', 'METAL1', 50, 40, 2, name="v_vss_ndif1",
                    conn={"left": "n_nq_1", "right": "n_q_1"},
                ),
                Wire(
                    'METAL1', 50, (20, 30), 2,
                    conn={"bottom": "vssrail", "top": "v_vss_ndif1"},
                ),
                Via('PTIE', 'METAL1', 70, 14, 2),
                Wire('PTIE', 70, (10, 18), 10, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nxr2_x1', width=140, height=200,
        nets={
            '_net0': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_net0_ndif1",
                    conn={"right": "n_i0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 140, 2, name="v_net0_pdif1",
                    conn={"right": "p_i0_1"},
                ),
                Wire(
                    'METAL1', 10, (60, 120), 3, False,
                    conn={"top": "v_net0_pdif1", "bottom": "v_net0_ndif1"},
                ),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_net0_1"}),
                Wire(
                    'POLY', 80, (56, 104), 4, False, name="pl_net0_1",
                    conn={"top": "p_net0_1", "bottom": "n_net0_1"},
                ),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net0_1",
                    source_net='nq', drain_net='_net2',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net0_1",
                    source_net='nq', drain_net='_net1',
                ),
            ],
            '_net1': [
                Via(
                    'PDIF', 'METAL1', 50, 160, 2, name="v_net1_pdif1",
                    space={"top": "vddrail", "bottom": "m1_nq_o"},
                    conn={"left": "p_i0_2", "right": "p_i1_1"},
                ),
                Wire(
                    'METAL1', (50, 90), 160, 6, False, name="m1_net1_1",
                    conn={"left": "v_net1_pdif1", "right": "v_net1_pdif2"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, name="v_net1_pdif2",
                    space={"top": "vddrail"},
                    conn={"left": "p_net0_1", "right": "p_net3_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 90, (16, 46), 12, False,
                    conn={"left": "n_net0_1", "right": "n_i1_1"},
                ),
            ],
            '_net3': [
                Via(
                    'NDIF', 'METAL1', 130, 40, 2, name="v_net3_ndif1",
                    conn={"left": "n_i1_2"},
                ),
                Via('PDIF', 'METAL1', 130, 140, 2, name="v_net3_pdif1",
                    conn={"left": "p_i1_2"},
                ),
                Wire(
                    'METAL1', 130, (60, 120), 3, False,
                    conn={"top": "v_net3_pdif1", "bottom": "v_net3_ndif1"}
                ),
                Via('POLY', 'METAL1', 128, 80, 2, conn={"left": "p_net3_1"}),
                Device(
                    'pmos', 100, 150, 4, 80, 'vertical', name="p_net3_1",
                    source_net='_net1', drain_net='vdd',
                ),
                Via(
                    'POLY', 'METAL1', 92, 80, 2, name="v_net3_pl1",
                    conn={"right": "p_net3_1"},
                ),
                Wire(
                    'METAL1', 90, (60, 80), 6, False, name="m1_net3_1",
                    conn={"top": "v_net3_pl1"},
                ),
                Wire(
                    'METAL1', (70, 90), 60, 6, False,
                    conn={"left": "v_net3_pl2", "right": "m1_net3_1"},
                ),
                Via(
                    'POLY', 'METAL1', 62, 60, 2, name="v_net3_pl2",
                    conn={"left": "n_net3_1"}
                ),
                Device(
                    'nmos', 60, 31, 4, 38, 'vertical', name="n_net3_1",
                    source_net='_net4', drain_net='nq',
                ),
            ],
            '_net4': [
                Wire(
                    'NDIF', 50, (16, 46), 4, False,
                    conn={"left": "n_i0_2", "right": "n_net3_1"},
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 30, (60, 140), 3, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'POLY', 'METAL1', 30, 60, 2,
                    conn={"left": "n_i0_1", "right": "n_i0_2"},
                ),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='_net0', drain_net='vss',
                ),
                Device(
                    'nmos', 40, 31, 4, 38, 'vertical', name="n_i0_2",
                    source_net='vss', drain_net='_net4',
                ),
                Via(
                    'POLY', 'METAL1', 30, 100, 2,
                    conn={"left": "p_i0_1", "right": "p_i0_2"},
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Device(
                    'pmos', 40, 150, 4, 80, 'vertical', name="p_i0_2",
                    source_net='vdd', drain_net='_net1',
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 110, (40, 140), 4, True, name="m1_i1_i",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'POLY', 'METAL1', 110, 60, 2,
                    conn={"left": "n_i1_1", "right": "n_i1_2"},
                ),
                Device(
                    'nmos', 100, 31, 4, 38, 'vertical', name="n_i1_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'nmos', 120, 40, 4, 20, 'vertical', name="n_i1_2",
                    source_net='vss', drain_net='_net3',
                ),
                Wire(
                    'METAL1', (70, 110), 100, 6, False,
                    conn={"left": "v_i1_pl1", "right": "m1_i1_i"},
                ),
                Via(
                    'POLY', 'METAL1', 62, 100, 2, name="v_i1_pl1",
                    conn={"left": "p_i1_1"},
                ),
                Device(
                    'pmos', 60, 150, 4, 80, 'vertical', name="p_i1_1",
                    source_net='_net1', drain_net='nq',
                ),
                Via('POLY', 'METAL1', 112, 100, 2, conn={"right": "p_i1_2"}),
                Device(
                    'pmos', 118, 150, 4, 40, 'vertical', name="p_i1_2",
                    source_net='vdd', drain_net='_net3',
                ),
            ],
            'nq': [
                Wire(
                    'METAL1', 50, (40, 150), 6, True, name="m1_nq_o",
                    space={"bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (50, 72), 40, 6, False,
                    conn={"left": "m1_nq_o", "right": "v_nq_ndif1"},
                ),
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, name="v_nq_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_net3_1", "right": "n_net0_1"},
                ),
                Wire(
                    'METAL1', (50, 72), 140, 6, False,
                    conn={"left": "m1_nq_o", "right": "v_nq_pdif1"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2, name="v_nq_pdif1",
                    space={"top": "m1_net1_1"},
                    conn={"left": "p_i1_1", "right": "p_net0_1"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 10, 184, 2),
                Wire('NTIE', 10, (180, 190), 6, False),
                Via(
                    'PDIF', 'METAL1', 30, 182, 2,
                    conn={"left": "p_i0_1", "right": "p_i0_2", "up": "vddrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 110, 182, 2,
                    conn={"left": "p_net3_1", "right": "p_i1_2", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 130, 184, 2),
                Wire('NTIE', 130, (180, 190), 6, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 30, 18, 2,
                    conn={"left": "n_i0_1", "right": "n_i0_2", "up": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 110, 18, 2,
                    conn={"left": "n_i1_1", "right": "n_i1_2", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 130, 14, 2),
                Wire('PTIE', 130, (8, 18), 6, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o2_x2', width=80, height=200,
        nets={
            '_net0': [
                Wire(
                    'PDIF', 30, (140, 160), 4, False,
                    conn={"left": "p_i1_1", "right": "p_i0_1"},
                )
            ],
            '_net1': [
                Via(
                    'PDIF', 'METAL1', 10, 160, 2, space={"bottom": "m1_i1_i"},
                    conn={"right": "p_i1_1"},
                ),
                Wire('METAL1', (10, 30), 160, 6, False, name="m1_net1_1"),
                Via(
                    'NDIF', 'METAL1', 30, 40, 2, name="v_net1_ndif1",
                    conn={"left": "n_i1_1", "right": "n_i0_1"},
                ),
                Wire(
                    'METAL1', 30, (60, 160), 4, False,
                    conn={"top": "m1_net1_1", "bottom": "v_net1_ndif1"},
                ),
                Via('POLY', 'METAL1', 32, 80, 2, conn={"right": "pl_net1_1"}),
                Device(
                    'nmos', 60, 31, 4, 38, 'vertical', name="n_net1_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 60, 150, 4, 80, 'vertical', name="p_net1_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 60, (56, 104), 4, False, name="pl_net1_1",
                    conn={"top": "p_net1_1", "bottom": "n_net1_1"},
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 50, (42, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='_net1', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 48, 60, 2, conn={"left": "n_i0_1"}),
                Device(
                    'pmos', 40, 140, 4, 60, 'vertical', name="p_i0_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Via('POLY', 'METAL1', 48, 100, 2, conn={"left": "p_i0_1"}),
            ],
            'i1': [
                Wire(
                    'METAL1', 10, (60, 150), 6, True, name="m1_i1_i",
                    space={"bottom": "vssrail"}),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i1_1",
                    source_net='vss', drain_net='_net1',
                ),
                Device(
                    'pmos', 20, 140, 4, 60, 'vertical', name="p_i1_1",
                    source_net='_net1', drain_net='_net0',
                ),
                Wire(
                    'POLY', 20, (56, 104), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'q': [
                Wire(
                    'METAL1', 70, (40, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net1_1"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 50, 182, 2,
                    conn={"left": "p_i0_1", "right": "p_net1_1", "up": "vddrail"},
                ),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 10, 18, 2, conn={"right": "n_i1_1"}),
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', 30, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 50, 18, 2,
                    conn={"left": "n_i0_1", "right": "n_net1_1", "up": "vssrail"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o3_x2', width=100, height=200,
        nets={
            '_net0': [
                Wire(
                    'PDIF', 30, (140, 160), 4, False,
                    conn={"left": "p_i2_1", "right": "p_i1_1"},
                )
            ],
            '_net1': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, space={"top": "m1_i2_i"},
                    conn={"right": "n_i2_1"},
                ),
                Wire('METAL1', (10, 70), 40, 6, False, name="m1_net1_1"),
                Via(
                    'NDIF', 'METAL1', 50, 40, 2, space={"top": "m1_i0_i"},
                    conn={"left": "n_i1_1", "right": "n_i0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 160, 2, space={"bottom": "m1_i2_i"},
                    conn={"right": "p_i2_1"},
                ),
                Wire('METAL1', (10, 70), 160, 6, False, name="m1_net1_2"),
                Wire(
                    'METAL1', 70, (62, 158), 6, False,
                    conn={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 72, 80, 2, conn={"right": "pl_net1_1"}),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net1_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net1_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 80, (56, 104), 4, False, name="pl_net1_1",
                    conn={"top": "p_net1_1", "bottom": "n_net1_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'PDIF', 50, (140, 160), 4, False,
                    conn={"left": "p_i1_1", "right": "p_i0_1"},
                )
            ],
            'i0': [
                Wire(
                    'METAL1', 50, (50, 140), 6, True, name="m1_i0_i",
                    space={"top": "m1_net1_2"},
                ),
                Via('POLY', 'METAL1', 52, 100, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 60, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='_net1', drain_net='vss',
                ),
                Device(
                    'pmos', 60, 140, 4, 60, 'vertical', name="p_i0_1",
                    source_net='_net2', drain_net='vdd',
                ),
                Wire(
                    'POLY', 60, (56, 98), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (80, 140), 6, True, name="m1_i1_i",
                    space={"top": "m1_net1_2", "bottom": "m1_net1_1"},
                ),
                Via('POLY', 'METAL1', 30, 60, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_i1_1",
                    source_net='vss', drain_net='_net1',
                ),
                Device(
                    'pmos', 40, 140, 4, 60, 'vertical', name="p_i1_1",
                    source_net='_net0', drain_net='_net2',
                ),
                Wire(
                    'POLY', 40, (56, 104), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire('METAL1', 10, (50, 150), 6, True, name="m1_i2_i"),
                Via('POLY', 'METAL1', 10, 80, 2, conn={"right": "pl_i2_1"}),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i2_1",
                    source_net='_net1', drain_net='vss',
                ),
                Device(
                    'pmos', 20, 140, 4, 60, 'vertical', name="p_i2_1",
                    source_net='_net1', drain_net='_net0',
                ),
                Wire(
                    'POLY', 20, (56, 104), 4, False, name="pl_i2_1",
                    conn={"top": "p_i2_1", "bottom": "n_i2_1"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 90, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net1_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net1_1"},
                ),
                Wire(
                    'METAL1', 90, (40, 160), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 10, 184, 2),
                Wire('NTIE', 10, (180, 190), 6, False),
                Via('NTIE', 'METAL1', 50, 184, 2),
                Wire('NTIE', 50, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 70, 184, 2, space={"bottom": "m1_net1_2"},
                    conn={"left": "p_i0_1", "right": "p_net1_1"},
                ),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 30, 18, 2, space={"top": "m1_net1_1"},
                    conn={"left": "n_i2_1", "right": "n_i1_1"},
                ),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', 50, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 70, 18, 2, space={"top": "m1_net1_1"},
                    conn={"left": "n_i0_1", "right": "n_net1_1"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o4_x2', width=120, height=200,
        nets={
            '_net0': [
                Wire(
                    'PDIF', 70, (140, 160), 4, False,
                    conn={"left": "p_i0_1", "right": "p_i2_1"},
                )
            ],
            '_net1': [
                Wire(
                    'PDIF', 30, (140, 160), 4, False,
                    conn={"left": "p_i3_1", "right": "p_i1_1"},
                )
            ],
            '_net2': [
                Via(
                    'NDIF', 'METAL1', 30, 40, 2, name="v_net2_ndif1",
                    space={"top": "m1_i1_i"},
                    conn={"left": "n_i3_1", "right": "n_i1_1"},
                ),
                Wire('METAL1', (30, 90), 40, 3, False, name="m1_net2_1"),
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, name="v_net2_ndif2",
                    space={"top": "m1_i2_i"},
                    conn={"left": "n_i0_1", "right": "n_i2_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 160, 2, name="v_net2_pdif1",
                    space={"bottom": "m1_i3_i"},
                    conn={"right": "p_i3_1"},
                ),
                Wire('METAL1', (10, 90), 160, 6, False, name="m1_net2_2"),
                Wire(
                    'METAL1', 90, (60, 100), 3, False,
                    conn={"top": "m1_net2_2", "bottom": "m1_net2_1"},
                ),
                Via('POLY', 'METAL1', 92, 80, 2, conn={"right": "pl_net2_1"}),
                Device(
                    'nmos', 100, 31, 4, 38, 'vertical', name="n_net2_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 100, 150, 4, 80, 'vertical', name="p_net2_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 100, (60, 100), 4, False, name="pl_net2_1",
                    conn={"top": "p_net2_1", "bottom": "n_net2_1"},
                ),
            ],
            '_net3': [
                Wire(
                    'PDIF', 50, (140, 160), 4, False,
                    conn={"left": "p_i1_1", "right": "p_i0_1"},
                )
            ],
            'i0': [
                Wire(
                    'METAL1', 50, (82, 138), 6, True, name="m1_i0_i",
                    space={"top": "m1_net2_2", "bottom": "m1_net2_1"},
                ),
                Via('POLY', 'METAL1', 52, 80, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 60, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='vss', drain_net='_net2',
                ),
                Device(
                    'pmos', 60, 140, 4, 60, 'vertical', name="p_i0_1",
                    source_net='_net3', drain_net='_net0',
                ),
                Wire(
                    'POLY', 60, (60, 100), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (50, 138), 3, True, name="m1_i1_i",
                    space={"top": "m1_net2_2"},
                ),
                Via('POLY', 'METAL1', 32, 80, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_i1_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'pmos', 40, 140, 4, 60, 'vertical', name="p_i1_1",
                    source_net='_net1', drain_net='_net3',
                ),
                Wire(
                    'POLY', 40, (60, 100), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire(
                    'METAL1', 70, (50, 138), 3, True, name="m1_i2_i",
                    space={"top": "m1_net2_2"},
                ),
                Via('POLY', 'METAL1', 72, 80, 2, conn={"right": "pl_i2_1"}),
                Device(
                    'nmos', 80, 40, 4, 20, 'vertical', name="n_i2_1",
                    source_net='_net2', drain_net='vss',
                ),
                Device(
                    'pmos', 80, 140, 4, 60, 'vertical', name="p_i2_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Wire(
                    'POLY', 80, (60, 100), 4, False, name="pl_i2_1",
                    conn={"top": "p_i2_1", "bottom": "n_i2_1"},
                ),
            ],
            'i3': [
                Wire(
                    'METAL1', 10, (62, 150), 3, True, name="m1_i3_i",
                    space={"bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_i3_1"}),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i3_1",
                    source_net='vss', drain_net='_net2',
                ),
                Device(
                    'pmos', 20, 140, 4, 60, 'vertical', name="p_i3_1",
                    source_net='_net2', drain_net='_net1',
                ),
                Wire(
                    'POLY', 20, (60, 100), 4, False, name="pl_i3_1",
                    conn={"top": "p_i3_1", "bottom": "n_i3_1"},
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 110, 40, 2,
                    space={"bottom": "vssrail"}, conn={"left": "n_net2_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 110, 140, 2,
                    space={"top": "vddrail"}, conn={"left": "p_net2_1"},
                ),
                Wire(
                    'METAL1', 110, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 8, False),
                Via('NTIE', 'METAL1', 70, 184, 2),
                Wire('NTIE', 70, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 90, 184, 2, space={"bottom": "m1_net2_2"},
                    conn={"left": "p_i2_1", "right": "p_net2_1"},
                ),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 10, 18, 2,
                    conn={"right": "n_i3_1"},
                ),
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', 30, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 50, 18, 2,
                    conn={"left": "n_i1_1", "right": "n_i0_1"},
                ),
                Via('PTIE', 'METAL1', 70, 14, 2),
                Wire('PTIE', 70, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 90, 18, 2, space={"top": "m1_net2_1"},
                    conn={"left": "n_i2_1", "right": "n_net2_1"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa22_x2', width=100, height=200,
        nets={
            '_net0': [
                Via(
                    'PDIF', 'METAL1', 30, 140, 2, name="v_net0_pdif1",
                    space={"top": "m1_net1_1"},
                    conn={"left": "p_i0_1", "right": "p_i1_1"},
                ),
                Wire(
                    'METAL1', (30, 50), 140, 3, False, name="m1_net0_1",
                    conn={"left": "v_net0_pdif1"},
                ),
                Wire(
                    'METAL1', 50, (60, 100), 3, False,
                    conn={"top": "m1_net0_1", "bottom": "v_net0_ndif1"},
                ),
                Via(
                    'NDIF', 'METAL1', 50, 40, 2, name="v_net0_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_i1_1", "right": "n_i2_1"},
                ),
                Via('POLY', 'METAL1', 52, 80, 2, conn={"right": "pl_net0_1"}),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net0_1",
                   source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net0_1",
                   source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 80, (56, 104), 4, False, name="pl_net0_1",
                    conn={"top": "p_net0_1", "bottom": "n_net0_1"},
                ),
            ],
            '_net1': [
                Via(
                    'PDIF', 'METAL1', 10, 160, 2, name="v_net1_pdif1",
                    space={"bottom": "m1_i0_i"}, conn={"right": "p_i0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 50, 160, 2, name="v_net1_pdif2",
                    space={"bottom": "m1_net0_1"},
                    conn={"left": "p_i1_1", "right": "p_i2_1"},
                ),
                Wire(
                    'METAL1', (10, 50), 160, 6, False, name="m1_net1_1",
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 30, (36, 66), 8, False,
                    conn={"left": "n_i0_1", "right": "n_i1_1"},
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 10, (42, 150), 6, True, name="m1_i0_i",
                    space={"bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_i0_1"}),
                Device(
                    'nmos', 20, 51, 4, 38, 'vertical', name="n_i0_1",
                   source_net='vss', drain_net='_net2',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                   source_net='_net1', drain_net='_net0',
                ),
                Wire(
                    'POLY', 20, (60, 100), 4, False, name="pl_i0_1",
                    conn={"top": "p_i0_1", "bottom": "n_i0_1"},
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 30, (42, 118), 6, True,
                    space={"top": "v_net0_pdif1", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 32, 100, 2, conn={"right": "pl_i1_1"}),
                Device(
                    'nmos', 40, 51, 4, 38, 'vertical', name="n_i1_1",
                   source_net='_net2', drain_net='_net0',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_i1_1",
                   source_net='_net0', drain_net='_net1',
                ),
                Wire(
                    'POLY', 40, (60, 100), 4, False, name="pl_i1_1",
                    conn={"top": "p_i1_1", "bottom": "n_i1_1"},
                ),
            ],
            'i2': [
                Wire(
                    'METAL1', 70, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 68, 60, 2, conn={"left": "n_i2_1"}),
                Device(
                    'nmos', 60, 31, 4, 38, 'vertical', name="n_i2_1",
                   source_net='_net0', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 68, 100, 2, conn={"left": "p_i2_1"}),
                Device(
                    'pmos', 60, 150, 4, 40, 'vertical', name="p_i2_1",
                   source_net='_net1', drain_net='vdd',
                ),
            ],
            'q': [
                Wire(
                    'METAL1', 90, (60, 100), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 90, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_net0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_net0_1"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 30, 184, 2),
                Wire('NTIE', 30, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 70, 182, 2,
                    conn={"left": "p_i2_1", "right": "p_net0_1", "up": "vddrail"},
                ),
            ],
            'vss': [
                Via(
                    'NDIF', 'METAL1', 10, 18, 2,
                    conn={"right": "n_i0_1", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', 30, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 70, 18, 2,
                    conn={"left": "n_i2_1", "right": "n_net0_1", "up": "vssrail"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='powmid_x0', width=140, height=200,
        nets={
            'vdd': [
                Wire('METAL3', 40, (0, 200), 48, True),
                # TODO VIA1 via
                Wire('METAL2', (20, 60), 190, 6, True),
                *(
                    Via('METAL1', 'METAL2', x, 190, 2)
                    for x in (25, 35, 45, 55)
                ),
                *(
                    Via('METAL2', 'METAL3', x, 190, 2)
                    for x in (25, 35, 45, 55)
                ),
                *(
                    Via('NTIE', 'METAL1', x, 182, 2)
                    for x in (10, 30, 50, 70, 90, 110, 130)
                ),
                Wire('NTIE', (10, 130), 182, 6, False),
            ],
            'vss': [
                Wire('METAL3', 100, (0, 200), 48, True),
                *(
                    Via('PTIE', 'METAL1', x, 18, 2)
                    for x in (10, 30, 50, 70, 90, 110, 130)
                ),
                # TODO VIA1 via
                Wire('METAL2', (80, 120), 10, 6, True),
                *(
                    Via('METAL1', 'METAL2', x, 10, 2)
                    for x in (85, 95, 105, 115)
                ),
                *(
                    Via('METAL2', 'METAL3', x, 10, 2)
                    for x in (85, 95, 105, 115)
                ),
                Wire('PTIE', (10, 130), 18, 6, False),
                *(
                    Via('POLY', 'METAL1', x, 40, 2, name=f"v_vss_top{i}")
                    for i, x in enumerate((10, 30, 50, 70, 90, 110, 130))
                ),
                *(
                    Wire(
                        'METAL1', x, (18, 54), 6, False,
                        conn={"top": f"v_vss_top{i}", "bottom": "vssrail"},
                    )
                    for i, x in enumerate((10, 30, 50, 70, 90, 110, 130))
                ),
                Wire('POLY', 70, (30, 170), 130, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='sff1_x4', width=300, height=200,
        nets={
            '_net0': [
                Wire(
                    'PDIF', 230, (154, 186), 4, False,
                    conn={"left": "p_ckr_2", "right": "p_q_1"},
                ),
            ],
            '_net1': [
                Wire(
                    'PDIF', 110, (154, 186), 4, False,
                    conn={"left": "p_u", "right": "p_ckr_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'NDIF', 110, (34, 46), 4, False,
                    conn={"left": "n_u", "right": "n_nckr_2"},
                ),
            ],
            '_net4': [
                Wire(
                    'NDIF', 150, (16, 46), 4, False,
                    conn={"left": "n_ckr_1", "right": "n_y_1"},
                ),
            ],
            '_net5': [
                Wire(
                    'PDIF', 150, (134, 186), 4, False,
                    conn={"left": "p_nckr_2", "right": "p_y_1"},
                ),
            ],
            '_net6': [
                Wire(
                    'NDIF', 230, (34, 46), 4, False,
                    conn={"left": "n_nckr_3", "right": "n_q_1"},
                ),
            ],
            'ck': [
                Wire(
                    'METAL1', 30, (42, 158), 3, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_ck",
                    source_net='nckr', drain_net='vss',
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_ck",
                    source_net='nckr', drain_net='vdd',
                ),
                Via('POLY', 'METAL1', 28, 60, 2, conn={"left": "n_ck"}),
                Via('POLY', 'METAL1', 28, 120, 2, conn={"left": "p_ck"}),
            ],
            'ckr': [
                Device(
                    'pmos', 120, 150, 4, 40, 'vertical', name="p_ckr_1",
                    source_net='_net1', drain_net='sff_m',
                ),
                Device(
                    'nmos', 140, 40, 4, 20, 'vertical', name="n_ckr_1",
                    source_net='sff_m', drain_net='_net4',
                ),
                Device(
                    'nmos', 200, 40, 4, 20, 'vertical', name="n_ckr_2",
                    source_net='y', drain_net='sff_s',
                ),
                Device(
                    'pmos', 220, 150, 4, 40, 'vertical', name="p_ckr_2",
                    source_net='sff_s', drain_net='_net0',
                ),
                Via(
                    'NDIF', 'METAL1', 50, 40, 2,
                    conn={"left": "n_nckr_1"}, space={"bottom": "vssrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 50, 140, 2,
                    conn={"left": "p_nckr_1"}, space={"top": "vddrail"},
                ),
                Wire('METAL1', 50, (42, 138), 6, False, space={}),
                Via('POLY', 'METAL1', 52, 80, 2, conn={"right": "n_ckr_2"}),
                Via(
                    'POLY', 'METAL1', 124, 120, 2, name="v_ckr_p1",
                    conn={"left": "p_ckr_1"},
                ),
                Wire(
                    'METAL1', (125, 136), 120, 3, False, name="m1_ckr_v1",
                    conn={"left": "v_ckr_p1"},
                ),
                Via(
                    'POLY', 'METAL1', 136, 80, 2, name="v_ckr_n1",
                    conn={"right": "n_ckr_1"},
                ),
                Wire(
                    'METAL1', 135, (82, 121), 3, False,
                #     conn={"top": "m1_ckr_v1", "bottom": "v_ckr_n1"},
                    conn={"bottom": "v_ckr_n1"},
                ),
                Via('POLY', 'METAL1', 208, 80, 2, conn={"left": "n_ckr_2"}),
                Via('POLY', 'METAL1', 212, 120, 2, conn={"right": "p_ckr_2"}),
                Wire('METAL1', 210, (79, 121), 6, False, space={}),
            ],
            'i': [
                Device(
                    'nmos', 80, 40, 4, 20, 'vertical', name="n_i",
                    source_net='u', drain_net='vss',
                ),
                Device(
                    'pmos', 80, 170, 4, 40, 'vertical', name="p_i",
                    source_net='u', drain_net='vdd',
                ),
                Wire(
                    'METAL1', 90, (42, 158), 3, True, name="m1_i",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via('POLY', 'METAL1', 88, 60, 2, conn={"left": "n_i"}),
                Via('POLY', 'METAL1', 88, 140, 2, conn={"left": "p_i"}),
            ],
            'nckr': [
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_nckr_1",
                    source_net='vss', drain_net='ckr',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_nckr_1",
                    source_net='vdd', drain_net='ckr',
                ),
                Device(
                    'nmos', 120, 40, 4, 20, 'vertical', name="n_nckr_2",
                    source_net='_net2', drain_net='sff_m',
                ),
                Device(
                    'pmos', 140, 150, 4, 40, 'vertical', name="p_nckr_2",
                    source_net='sff_m', drain_net='_net5',
                ),
                Device(
                    'pmos', 200, 150, 4, 40, 'vertical', name="p_nckr_3",
                    source_net='y', drain_net='sff_s',
                ),
                Device(
                    'nmos', 220, 40, 4, 20, 'vertical', name="n_nckr_3",
                    source_net='sff_s', drain_net='_net6',
                ),
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_ndif_nckr",
                    conn={"right": "n_ck"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 140, 2, name="v_pdif_nckr",
                    conn={"right": "p_ck"},
                ),
                Wire(
                    'METAL1', 10, (42, 138), 6, False,
                    conn={"top": "v_pdif_nckr", "bottom": "v_ndif_nckr"},
                ),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "n_nckr_3"}),
                Wire(
                    'POLY', 40, (56, 124), 4, False,
                    conn={"bottom": "n_nckr_1", "top": "p_nckr_1"},
                ),
                Via('POLY', 'METAL1', 120, 60, 2, conn={"left": "n_nckr_2"}),
                Via('POLY', 'METAL1', 120, 100, 2),
                Wire('METAL1', 120, (60, 100), 3, False, space={}),
                Wire('POLY', 140, (100, 124), 4, False, conn={"top": "p_nckr_2"}),
                Wire('POLY', 200, (100, 144), 4, False, conn={"top": "p_nckr_3"}),
            ],
            'q': [
                Wire(
                    'METAL1', 270, (42, 158), 6, True, name="m1_q_o",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 270, 40, 2, space={"bottom": "vssrail"},
                    conn={"left": "n_sffs_1", "right": "n_sffs_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 270, 140, 2, space={"top": "vddrail"},
                    conn={"left": "p_sffs_1", "right": "p_sffs_2"},
                ),
                Device(
                    'nmos', 240, 40, 4, 20, 'vertical', name="n_q_1",
                    source_net='_net6', drain_net='vss',
                ),
                Via(
                    'POLY', 'METAL1', 245, 60, 2, name="v_q_n1",
                    # conn={"left": "n_q_1", "right": "m1_q_o"}, space={},
                    conn={"left": "n_q_1"},
                ),
                Wire(
                    'METAL1', (244, 270), 60, 6, False,
                    conn={"left": "v_q_n1", "right": "m1_q_o"},
                ),
                Device(
                    'pmos', 240, 170, 4, 40, 'vertical', name="p_q_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Via(
                    'POLY', 'METAL1', 245, 100, 2, name="v_q_p1",
                    # conn={"left": "p_q_1", "right": "m1_q_o"}, space={},
                    conn={"left": "p_q_1"},
                ),
                Wire(
                    'METAL1', (244, 270), 100, 6, False,
                    conn={"left": "v_q_p1", "right": "m1_q_o"}
                ),
            ],
            'sff_m': [
                Via(
                    'NDIF', 'METAL1', 130, 40, 4, name="v_sffm_ndif1",
                    conn={"left": "n_nckr_2", "right": "n_ckr_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 130, 150, 2, name="v_sffm_pdif1",
                    conn={"left": "p_ckr_1", "right": "p_nckr_2"},
                ),
                Wire(
                    'METAL1', (130, 151), 40, 6, False,
                    conn={"left": "v_sffm_ndif1"},
                ),
                Wire(
                    'METAL1', (130, 151), 150, 6, False,
                    conn={"left": "v_sffm_pdif1"},
                ),
                Wire('METAL1', 150, (39, 151), 6, False, space={}),
                Via(
                    'POLY', 'METAL1', 175, 60, 2, name="v_sffm_n1",
                    conn={"right": "n_sffm_1"},
                ),
                Wire(
                    'METAL1', (149, 176), 60, 6, False,
                    conn={"right": "v_sffm_n1"},
                ),
                Via(
                    'POLY', 'METAL1', 175, 120, 2, name="v_sffm_p1",
                    conn={"right": "p_sffm_1"},
                ),
                Wire(
                    'METAL1', (149, 176), 120, 6, False,
                    conn={"right": "v_sffm_p1"},
                ),
                Device(
                    'nmos', 180, 21, 4, 18, 'vertical', name="n_sffm_1",
                    source_net='vss', drain_net='y',
                ),
                Device(
                    'pmos', 180, 170, 4, 40, 'vertical', name="p_sffm_1",
                    source_net='vdd', drain_net='y',
                ),
            ],
            'sff_s': [
                Device(
                    'nmos', 260, 31, 4, 38, 'vertical', name="n_sffs_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 260, 150, 4, 80, 'vertical', name="p_sffs_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 260, (56, 104), 4, False,
                    conn={"top": "p_sffs_1", "bottom": "n_sffs_1"},
                ),
                Device(
                    'nmos', 280, 31, 4, 38, 'vertical', name="n_sffs_2",
                    source_net='q', drain_net='vss',
                ),
                Device(
                    'pmos', 280, 150, 4, 80, 'vertical', name="p_sffs_2",
                    source_net='q', drain_net='vdd',
                ),
                Wire(
                    'POLY', 280, (56, 104), 4, False, name="pl_sffs_2",
                    conn={"top": "p_sffs_2", "bottom": "n_sffs_2"},
                ),
                Via(
                    'POLY', 'METAL1', 255, 80, 2, name="v_sffs_pl",
                    conn={"right": "pl_sffs_2"},
                ),
                Wire(
                    'METAL1', 230, (39, 161), 6, False, name="m1_sffs_1",
                ),
                Wire(
                    'METAL1', (229, 256), 80, 6, False,
                    conn={"left": "m1_sffs_1","right": "v_sffs_pl"},
                ),
                Via(
                    'NDIF', 'METAL1', 210, 40, 2, name="v_sffs_ndif1",
                    conn={"left": "n_ckr_2", "right": "n_nckr_3"},
                    space={"bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (209, 231), 40, 3, False,
                    # conn={"left": "v_sffs_ndif1", "right": "m1_sffs_1"},
                    conn={"left": "v_sffs_ndif1"},
                ),
                Via(
                    'PDIF', 'METAL1', 210, 140, 2, name="v_sffs_pdif1",
                    conn={"left": "p_nckr_3", "right": "p_ckr_2"},
                    space={"top": "vddrail"},
                ),
                Wire(
                    'METAL1', (209, 231), 160, 3, False,
                    # conn={"left": "v_sffs_pdif1", "right": "m1_sffs_1"},
                    conn={"left": "v_sffs_pdif1"},
                ),
            ],
            'u': [
                Device(
                    'nmos', 100, 40, 4, 20, 'vertical', name="n_u",
                    source_net='vss', drain_net='_net2',
                ),
                Device(
                    'pmos', 100, 170, 4, 40, 'vertical', name="p_u",
                    source_net='vdd', drain_net='_net1',
                ),
                Via('POLY', 'METAL1', 72, 120, 2, conn={"right": "p_u"}),
                Wire(
                    'METAL1', 70, (42, 158), 6, False,
                    conn={"bottom": "v_u_ndif", "top": "v_u_pdif"},
                ),
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, name="v_u_ndif",
                    conn={"right": "n_i"}, space={"bottom": "vssrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 160, 2, name="v_u_pdif",
                    conn={"right": "p_i"}, space={"top": "vddrail"},
                ),
                Wire(
                    'METAL1', 104, (62, 118), 3, False,
                    conn={"top": "v_u_p", "bottom": "v_u_n"},
                ),
                Via(
                    'POLY', 'METAL1', 104, 60, 2, name="v_u_n",
                    conn={"left": "n_u"},
                ),
                Via(
                    'POLY', 'METAL1', 104, 120, 2, name="v_u_p",
                    conn={"left": "p_u"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 10, 184, 2),
                Wire('NTIE', 10, (180, 190), 6, False),
                Via(
                    'PDIF', 'METAL1', 30, 184, 2,
                    conn={"left": "p_ck", "right": "p_nckr_1"},
                ),
                Via('NTIE', 'METAL1', 50, 184, 2),
                Wire('NTIE', 50, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 90, 184, 2,
                    conn={"left": "p_i", "right": "p_u", "up": "vddrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 170, 184, 2,
                    conn={"left": "p_y_1", "right": "p_sffm_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 250, 140, 2,
                    conn={"left": "p_q_1", "right": "p_sffs_1"},
                ),
                Via('PDIF', 'METAL1', 290, 160, 2, conn={"left": "p_sffs_2"}),
                Via('NTIE', 'METAL1', 130, 184, 2),
                Wire('NTIE', 130, (180, 188), 10, False),
                Via('NTIE', 'METAL1', 210, 184, 2),
                Wire('NTIE', 210, (180, 188), 10, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 30, 16, 2,
                    conn={"left": "n_ck", "right": "n_nckr_1"}, 
                ),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', 50, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 90, 16, 2,
                    conn={"left": "n_i", "right": "n_u"},
                ),
                Via(
                    'NDIF', "METAL1", 170, 20, 4,
                    conn={"left": "n_y_1", "right": "n_sffm_1"},
                ),
                Via(
                    'NDIF', 'METAL1', 250, 40, 2,
                    conn={"left": "n_q_1", "right": "n_sffs_1"},
                ),
                Via('NDIF', 'METAL1', 290, 40, 2, conn={"left": "n_sffs_2"}),
                Via('PTIE', 'METAL1', 130, 14, 2),
                Wire('PTIE', 130, (10, 18), 10, False),
                Via('PTIE', 'METAL1', 230, 14, 2),
                Wire('PTIE', 230, (10, 18), 10, False),
            ],
            'y': [
                Device(
                    'nmos', 160, 21, 4, 18, 'vertical', name="n_y_1",
                    source_net='_net4', drain_net='vss',
                ),
                Device(
                    'pmos', 160, 170, 4, 40, 'vertical', name="p_y_1",
                    source_net='_net5', drain_net='vdd',
                ),
                Via(
                    'POLY', 'METAL1', 164, 40, 2, name="v_y_n1",
                    conn={"left": "n_y_1"},
                ),
                Wire('METAL1', (164, 191), 40, 6, False, conn={"left": "v_y_n1"}),
                Via(
                    'POLY', 'METAL1', 164, 140, 2, name="v_y_p1",
                    conn={"left": "p_y_1"},
                ),
                Wire('METAL1', (164, 191), 140, 6, False, conn={"left": "v_y_p1"}),
                Via(
                    'NDIF', 'METAL1', 190, 40, 2, name="v_y_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_sffm_1", "right": "n_ckr_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 190, 160, 2, name="v_y_pdif1",
                    space={"top": "vddrail"},
                    conn={"left": "p_sffm_1", "right": "p_nckr_3"},
                ),
                Wire(
                    'METAL1', 190, (42, 158), 3, False,
                    conn={"top": "v_y_pdif1", "bottom": "v_y_ndif1"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='sff1r_x4', width=360, height=200,
        nets={
            '_net0': [
                Wire(
                    'PDIF', 110, (140, 170), 4, False,
                    conn={"left": "p_u_1", "right": "p_ckr_1"},
                ),
            ],
            '_net2': [
                Wire(
                    'PDIF', 150, (134, 186), 4, False,
                    conn={"left": "p_nckr_2", "right": "p_y_1"},
                ),
            ],
            '_net3': [
                Via(
                    'PDIF', 'METAL1', 230, 160, 2, name="v_net3_pdif1",
                    space={"top": "vddrail"}, conn={"left": "p_nrst_2"},
                ),
                Wire(
                    'METAL1', (230, 290), 160, 6, False, name="m1_net3_1",
                    conn={"left": "v_net3_pdif1", "right": "v_net3_pdif2"},
                ),
                Via(
                    'PDIF', 'METAL1', 290, 160, 2, name="v_net3_pdif2",
                    space={"top": "vddrail"},
                    conn={"left": "p_ckr_2", "right": "p_q_1"}
                ),
            ],
            '_net4': [
                Wire(
                    'NDIF', 190, (16, 26), 4, False,
                    conn={"left": "n_sffm_1", "right": "n_nrst_1"},
                ),
            ],
            '_net5': [
                Wire(
                    'NDIF', 290, (34, 46), 8, False,
                    conn={"left": "n_nrst_2", "right": "n_q_1"},
                ),
            ],
            '_net6': [
                Wire(
                    'NDIF', 150, (16, 46), 4, False,
                    conn={"left": "n_ckr_1", "right": "n_y_1"},
                ),
            ],
            '_net7': [
                Wire(
                    'NDIF', 110, (35, 45), 4, False,
                    conn={"left": "n_u_1", "right": "n_nckr_2"},
                ),
            ],
            '_net8': [
                Wire(
                    'NDIF', 270, (34, 46), 8, False,
                    conn={"left": "n_nckr_3", "right": "n_nrst_2"},
                ),
            ],
            'ck': [
                Wire(
                    'METAL1', 30, (40, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"}
                ),
                Via('POLY', 'METAL1', 30, 60, 2, conn={"left": "n_ck_1"}),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_ck_1",
                    source_net='nckr', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 30, 120, 2, conn={"left": "p_ck_1"}),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_ck_1",
                    source_net='nckr', drain_net='vdd',
                ),
            ],
            'ckr': [
                Via(
                    'NDIF', 'METAL1', 50, 40, 2, name="v_ckr_ndif1",
                    conn={"left": "n_nckr_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 50, 140, 2, name="v_ckr_pdif1",
                    conn={"left": "p_nckr_1"},
                ),
                Wire(
                    'METAL1', 50, (60, 100), 6, False,
                    conn={"top": "v_ckr_pdif1", "bottom": "v_ckr_ndif1"},
                ),
                Via('POLY', 'METAL1', 52, 80, 2, conn={"right": "n_ckr_2"}),
                Via('POLY', 'METAL1', 135, 80, 2, name="v_ckr_pl1"),
                Wire(
                    'METAL1', 135, (82, 120), 3, False, name="m1_ckr_1",
                    conn={"top": "v_ckr_pl2", "bottom": "v_ckr_pl1"},
                ),
                Wire('METAL1', (122, 135), 120, 3, False, conn={"right": "m1_ckr_1"}),
                Via(
                    'POLY', 'METAL1', 122, 120, 2, name="v_ckr_pl2",
                    conn={"left": "p_ckr_1"},
                ),
                Device(
                    'pmos', 120, 150, 4, 40, 'vertical', name="p_ckr_1",
                    source_net='_net0', drain_net='sff_m',
                ),
                Wire(
                    'POLY', 140, (60, 80), 4, False,
                    conn={"bottom": "n_ckr_1"},
                ),
                Device(
                    'nmos', 140, 40, 4, 20, 'vertical', name="n_ckr_1",
                    source_net='sff_m', drain_net='_net6',
                ),

                Device(
                    'nmos', 240, 40, 4, 20, 'vertical', name="n_ckr_2",
                    source_net='y', drain_net='sff_s',
                ),
                Via(
                    'POLY', 'METAL1', 245, 80, 2, name="v_ckr_pl3",
                    conn={"left": "n_ckr_2"},
                ),
                Wire(
                    'METAL1', (245, 270), 80, 6, False,
                    conn={"left": "v_ckr_pl3", "right": "m1_ckr_2"},
                ),
                Wire(
                    'METAL1', 270, (80, 100), 6, False, name="m1_ckr_2",
                    conn={"top": "v_ckr_pl4"},
                ),
                Via(
                    'POLY', 'METAL1', 272, 100, 2, name="v_ckr_pl4",
                    conn={"right": "p_ckr_2"},
                ),
                Device(
                    'pmos', 280, 150, 4, 40, 'vertical', name="p_ckr_2",
                    source_net='sff_s', drain_net='_net3',
                ),
            ],
            'i': [
                Wire(
                    'METAL1', 90, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"}
                ),
                Via('POLY', 'METAL1', 88, 60, 2, conn={"left": "n_i_1"}),
                Device(
                    'nmos', 80, 40, 4, 20, 'vertical', name="n_i_1",
                    source_net='u', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 88, 140, 2, conn={"left": "p_i_1"}),
                Device(
                    'pmos', 80, 170, 4, 40, 'vertical', name="p_i_1",
                    source_net='u', drain_net='vdd',
                ),
            ],
            'nckr': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_nckr_ndif1",
                    conn={"right": "n_ck_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 140, 2, name="v_nckr_pdif1",
                    conn={"right": "p_ck_1"},
                ),
                Wire(
                    'METAL1', 10, (60, 100), 6, False,
                    conn={"top": "v_nckr_pdif1", "bottom": "v_nckr_ndif1"},
                ),
                Via('POLY', 'METAL1', 12, 100, 2, conn={"right": "n_nckr_3"}),
                Device(
                    'nmos', 40, 40, 4, 20, 'vertical', name="n_nckr_1",
                    source_net='vss', drain_net='ckr',
                ),
                Device(
                    'pmos', 40, 150, 4, 40, 'vertical', name="p_nckr_1",
                    source_net='vdd', drain_net='ckr',
                ),
                Wire(
                    'POLY', 40, (56, 124), 4, False,
                    conn={"top": "p_nckr_1", "bottom": "n_nckr_1"},
                ),
                Via('POLY', 'METAL1', 120, 100, 2, name="v_nckr_pl1"),
                Wire(
                    'METAL1', 120, (60, 100), 6, False,
                    conn={"top": "v_nckr_pl1", "bottom": "v_nckr_pl2"},
                ),
                Via(
                    'POLY', 'METAL1', 120, 60, 2, name="v_nckr_pl2",
                    conn={"right": "n_nckr_2"},
                ),
                Device(
                    'nmos', 120, 40, 4, 20, 'vertical', name="n_nckr_2",
                    source_net='_net7', drain_net='sff_m',
                ),
                Wire('POLY', 140, (100, 120), 4, False, conn={"top": "p_nckr_2"}),
                Device(
                    'pmos', 140, 150, 4, 40, 'vertical', name="p_nckr_2",
                    source_net='sff_m', drain_net='_net2',
                ),
                Device(
                    'nmos', 260, 40, 4, 20, 'vertical', name="n_nckr_3",
                    source_net='sff_s', drain_net='_net8',
                ),
                Wire('POLY', 260, (100, 120), 4, False, conn={"top": "p_nckr_3"}),
                Device(
                    'pmos', 260, 150, 4, 40, 'vertical', name="p_nckr_3",
                    source_net='y', drain_net='sff_s',
                ),
            ],
            'nrst': [
                Device(
                    'nmos', 200, 21, 4, 18, 'vertical', name="n_nrst_1",
                    source_net='_net4', drain_net='y',
                ),
                Via('POLY', 'METAL1', 228, 60, 2, conn={"left": "n_nrst_1"}),
                Device(
                    'pmos', 200, 170, 4, 40, 'vertical', name="p_nrst_1",
                    source_net='y', drain_net='vdd',
                ),
                Device(
                    'pmos', 220, 170, 4, 40, 'vertical', name="p_nrst_2",
                    source_net='vdd', drain_net='_net3',
                ),
                Via('POLY', 'METAL1', 228, 120, 2, conn={"left": "p_nrst_1"}),
                Wire('POLY', 220, (120, 140), 8, False, conn={"top": "p_nrst_2"}),
                Wire(
                    'METAL1', 230, (40, 60), 6, True, name="m1_nrst_1",
                    space={"top": "m1_y_2", "bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (230, 278), 60, 6, False,
                    conn={"left": "m1_nrst_1", "right": "v_nrst_pl2"},
                ),
                Via(
                    'POLY', 'METAL1', 278, 60, 2, name="v_nrst_pl2",
                    conn={"right": "n_nrst_2"},
                ),
                Device(
                    'nmos', 280, 40, 4, 20, 'vertical', name="n_nrst_2",
                    source_net='_net8', drain_net='_net5',
                ),
            ],
            'q': [
                Via(
                    'NDIF', 'METAL1', 330, 40, 2, name="v_q_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_sffs_1", "right": "n_sffs_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 330, 140, 2, name="v_q_pdif1",
                    space={"top": "vddrail"},
                    conn={"left": "p_sffs_1", "right": "p_sffs_2"},
                ),
                Wire(
                    'METAL1', 330, (60, 100), 6, True, name="m1_q_i",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (310, 330), 60, 6, False,
                    conn={"left": "v_q_pl1", "right": "m1_q_i"},
                ),
                Via(
                    'POLY', 'METAL1', 302, 60, 2, name="v_q_pl1",
                    conn={"left": "n_q_1"},
                ),
                Device(
                    'nmos', 300, 40, 4, 20, 'vertical', name="n_q_1",
                    source_net='_net5', drain_net='vss',
                ),
                Wire(
                    'METAL1', (310, 330), 100, 6, False,
                    conn={"left": "v_q_pl2", "right": "m1_q_i"},
                ),
                Via(
                    'POLY', 'METAL1', 302, 100, 2, name="v_q_pl2",
                    conn={"left": "p_q_1"},
                ),
                Device(
                    'pmos', 300, 170, 4, 40, 'vertical', name="p_q_1",
                    source_net='_net3', drain_net='vdd',
                ),
            ],
            'sff_m': [
                Via(
                    'NDIF', 'METAL1', 130, 40, 2, name="v_sffm_ndif1",
                    conn={"left": "n_nckr_2", "right": "n_ckr_1"},
                ),
                Wire(
                    'METAL1', (130, 150), 40, 6, False,
                    conn={"left": "v_sffm_ndif1", "right": "m1_sffm_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 130, 140, 2, name="v_sffm_pdif1",
                    conn={"left": "p_ckr_1", "right": "p_nckr_2"},
                ),
                Wire(
                    'METAL1', (130, 150), 140, 6, False,
                    conn={"left": "v_sffm_pdif1", "right": "m1_sffm_1"},
                ),
                Wire('METAL1', 150, (40, 140), 6, False, name="m1_sffm_1"),
                Wire(
                    'METAL1', (150, 170), 60, 6, False,
                    conn={"left": "m1_sffm_1", "right": "v_sffm_pl1"}
                ),
                Via(
                    'POLY', 'METAL1', 178, 60, 2, name="v_sffm_pl1",
                    conn={"right": "n_sffm_1"},
                ),
                Device(
                    'nmos', 180, 21, 4, 18, 'vertical', name="n_sffm_1",
                    source_net='vss', drain_net='_net4',
                ),
                Wire(
                    'METAL1', (150, 170), 120, 6, False,
                    conn={"left": "m1_sffm_1", "right": "v_sffm_pl2"}
                ),
                Via(
                    'POLY', 'METAL1', 178, 120, 2, name="v_sffm_pl2",
                    conn={"right": "p_sffm_1"},
                ),
                Device(
                    'pmos', 180, 170, 4, 40, 'vertical', name="p_sffm_1",
                    source_net='vdd', drain_net='y',
                ),
            ],
            'sff_s': [
                Device(
                    'nmos', 320, 31, 4, 38, 'vertical', name="n_sffs_1",
                    source_net='vss', drain_net='q',
                ),
                Device(
                    'pmos', 320, 150, 4, 80, 'vertical', name="p_sffs_1",
                    source_net='vdd', drain_net='q',
                ),
                Wire(
                    'POLY', 320, (60, 100), 4, False,
                    conn={"top": "p_sffs_1", "bottom": "n_sffs_1"},
                ),
                Device(
                    'nmos', 340, 31, 4, 38, 'vertical', name="n_sffs_2",
                    source_net='q', drain_net='vss',
                ),
                Device(
                    'pmos', 340, 150, 4, 80, 'vertical', name="p_sffs_2",
                    source_net='q', drain_net='vdd',
                ),
                Wire(
                    'POLY', 340, (60, 100), 4, False, name="pl_sffs_1",
                    conn={"top": "p_sffs_2", "bottom": "n_sffs_2"},
                ),
                Via(
                    'POLY', 'METAL1', 312, 80, 2, name='v_sffs_pl1',
                    conn={"right": "pl_sffs_1"},
                ),
                Wire(
                    'METAL1', (290, 310), 80, 6, False,
                    conn={"left": "m1_sffs_1", "right": "v_sffs_pl1"},
                ),
                Wire('METAL1', 290, (40, 120), 6, False, name="m1_sffs_1"),
                Wire(
                    'METAL1', (250, 290), 40, 6, False,
                    conn={"left": "v_sffs_ndif1", "right": "m1_sffs_1"},
                ),
                Via(
                    'NDIF', 'METAL1', 250, 40, 2, name="v_sffs_ndif1",
                    conn={"left": "n_ckr_2", "right": "n_nckr_3"},
                ),
                Wire(
                    'METAL1', (270, 290), 120, 6, False,
                    conn={"left": "v_sffs_pdif1", "right": "m1_sffs_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 270, 140, 2, name="v_sffs_pdif1",
                    conn={"left": "p_nckr_3", "right": "p_ckr_2"},
                    space={"top": "m1_net3_1"},
                ),
            ],
            'u': [
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, name="v_u_ndif1",
                    conn={"right": "n_i_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 70, 160, 2, name="v_u_pdif1",
                    space={"top": "vddrail"}, conn={"right": "p_i_1"},
                ),
                Wire(
                    'METAL1', 70, (60, 100), 3, False,
                    conn={"top": "v_u_pdif1", "bottom": "v_u_ndif1"},
                ),
                Via('POLY', 'METAL1', 72, 120, 2, conn={"right": "p_u_1"}),
                Device(
                    'pmos', 100, 170, 4, 40, 'vertical', name="p_u_1",
                    source_net='vdd', drain_net='_net0',
                ),
                Via(
                    'POLY', 'METAL1', 103, 120, 2, name="v_u_pl1",
                    conn={"left": "p_u_1"},
                ),
                Wire(
                    'METAL1', 105, (60, 100), 6, False,
                    conn={"top": "v_u_pl1", "bottom": "v_u_pl2"},
                ),
                Via(
                    'POLY', 'METAL1', 103, 60, 2, name="v_u_pl2",
                    conn={"right": "n_u_1"},
                ),
                Device(
                    'nmos', 100, 40, 4, 20, 'vertical', name="n_u_1",
                    source_net='vss', drain_net='_net7',
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 10, 184, 2),
                Wire('NTIE', 10, (180, 190), 6, False),
                Via(
                    'PDIF', 'METAL1', 30, 182, 2,
                    conn={"left": "p_ck_1", "right": "p_nckr_1"},
                ),
                Via('NTIE', 'METAL1', 50, 184, 2),
                Wire('NTIE', 50, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 90, 182, 2,
                    conn={"left": "p_i_1", "right": "p_u_1", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 130, 184, 2),
                Wire('NTIE', 130, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 170, 182, 2,
                    conn={"left": "p_y_1", "right": "p_sffm_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 210, 182, 2,
                    conn={"left": "p_nrst_1", "right": "p_nrst_2"},
                ),
                Via('NTIE', 'METAL1', 270, 184, 2),
                Wire('NTIE', 270, (180, 188), 8, False),
                Via(
                    'PDIF', 'METAL1', 310, 182, 2,
                    conn={"left": "p_q_1", "right": "p_sffs_1"},
                ),
                Via('PDIF', 'METAL1', 350, 182, 2, conn={"left": "p_sffs_2"}),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 30, 18, 2,
                    conn={"left": "n_ck_1", "right": "n_nckr_1"},
                ),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', 50, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 90, 18, 2,
                    conn={"left": "n_i_1", "right": "n_u_1"},
                ),
                Via('PTIE', 'METAL1', 130, 14, 2),
                Wire('PTIE', 130, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 170, 18, 2,
                    conn={"left": "n_y_1", "right": "n_sffm_1"},
                ),
                Via('PTIE', 'METAL1', 290, 14, 2),
                Wire('PTIE', 290, (10, 18), 8, False),
                Via(
                    'NDIF', 'METAL1', 310, 18, 2,
                    conn={"left": "n_q_1", "right": "n_sffs_1"},
                ),
                Via('NDIF', 'METAL1', 350, 18, 2, conn={"left": "n_sffs_2"}),
            ],
            'y': [
                Device(
                    'nmos', 160, 21, 4, 18, 'vertical', name="n_y_1",
                    source_net='_net6', drain_net='vss',
                ),
                Via('POLY', 'METAL1', 162, 40, 2, conn={"left": "n_y_1"}),
                Device(
                    'pmos', 160, 170, 4, 40, 'vertical', name="p_y_1",
                    source_net='_net2', drain_net='vdd',
                ),
                Via('POLY', 'METAL1', 162, 140, 2, conn={"left": "p_y_1"}),
                Via(
                    'PDIF', 'METAL1', 190, 160, 2, name="v_y_pdif1",
                    space={"top": "vddrail"},
                    conn={"left": "p_sffm_1", "right": "p_nrst_1"},
                ),
                Wire('METAL1', 190, (42, 158), 6, False, name="m1_y_1"),
                Wire(
                    'METAL1', (162, 210), 40, 6, False,
                    conn={"left": "m1_y_1", "right": "v_y_ndif1"}
                ),
                Via(
                    'NDIF', 'METAL1', 210, 40, 2, name="v_y_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_nrst_1", "right": "n_ckr_2"},
                ),
                Wire(
                    'METAL1', (162, 240), 140, 6, False, name="m1_y_2",
                    conn={"left": "m1_y_1", "right": "v_y_pdif2"},
                ),
                Via(
                    'PDIF', 'METAL1', 250, 140, 2, name="v_y_pdif2",
                    conn={"right": "p_nckr_3"}, space={"top": "m1_net3_1"},
                ),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='xr2_x1', width=140, height=200,
        nets={
            '_net0': [
                Via(
                    'NDIF', 'METAL1', 10, 40, 2, name="v_net0_ndif1",
                    conn={"right": "n_i0_1"},
                ),
                Via(
                    'PDIF', 'METAL1', 10, 140, 2, name="v_net0_pdif1",
                    conn={"right": "p_i0_1"},
                ),
                Wire(
                    'METAL1', 10, (60, 120), 3, False,
                    conn={"top": "v_net0_pdif1", "bottom": "v_net0_ndif1"},
                ),
                Via('POLY', 'METAL1', 12, 80, 2, conn={"right": "pl_net0_1"}),
                Wire(
                    'POLY', 80, (60, 100), 4, False, name="pl_net0_1",
                    conn={"top": "p_net0_1", "bottom": "n_net0_1"},
                ),
                Device(
                    'nmos', 80, 31, 4, 38, 'vertical', name="n_net0_1",
                    source_net='q', drain_net='_net4',
                ),
                Device(
                    'pmos', 80, 150, 4, 80, 'vertical', name="p_net0_1",
                    source_net='q', drain_net='_net2',
                ),
            ],
            '_net1': [
                Wire(
                    'NDIF', 50, (16, 46), 4, False,
                    conn={"left": "n_i0_2", "right": "n_i1_1"},
                ),
            ],
            '_net2': [
                Via(
                    'PDIF', 'METAL1', 50, 160, 2, name="v_net2_pdif1",
                    space={"top": "vddrail", "bottom": "m1_q_o"},
                    conn={"left": "p_i0_2", "right": "p_net3_1"},
                ),
                Wire(
                    'METAL1', (50, 90), 160, 6, False, name="m1_net2_1",
                    conn={"left": "v_net2_pdif1", "right": "v_net2_pdif2"},
                ),
                Via(
                    'PDIF', 'METAL1', 90, 140, 2, name="v_net2_pdif2",
                    space={"top": "vddrail"},
                    conn={"left": "p_net0_1", "right": "p_i1_1"},
                ),
            ],
            '_net3': [
                Via(
                    'NDIF', 'METAL1', 130, 40, 2, name="v_net3_ndif1",
                    conn={"left": "n_i1_2"},
                ),
                Via(
                    'PDIF', 'METAL1', 130, 140, 2, name="v_net3_pdif1",
                    conn={"left": "p_i1_2"},
                ),
                Wire(
                    'METAL1', 130, (42, 138), 6, False,
                    conn={"top": "v_net3_pdif1", "bottom": "v_net3_ndif1"},
                ),
                Via('POLY', 'METAL1', 128, 80, 2, conn={"left": "n_net3_1"}),
                Device(
                    'nmos', 100, 31, 4, 38, 'vertical', name="n_net3_1",
                    source_net='_net4', drain_net='vss',
                ),
                Via(
                    'POLY', 'METAL1', 98, 80, 2, name="v_net3_pl1",
                    conn={"right": "n_net3_1"},
                ),
                Wire(
                    'METAL1', (70, 98), 80, 6, False,
                    conn={"left": "m1_net3_1", "right": "v_net3_pl1"},
                ),
                Wire(
                    'METAL1', 70, (80, 98), 6, False, name="m1_net3_1",
                    conn={"top": "v_net3_pl2"},
                ),
                Via(
                    'POLY', 'METAL1', 68, 100, 2, name="v_net3_pl2",
                    conn={"left": "p_net3_1"},
                ),
                Device(
                    'pmos', 60, 150, 4, 80, 'vertical', name="p_net3_1",
                    source_net='_net2', drain_net='q',
                ),
            ],
            '_net4': [
                Wire(
                    'NDIF', 90, (16, 46), 4, False,
                    conn={"left": "n_net0_1", "right": "n_net3_1"},
                ),
            ],
            'i0': [
                Wire(
                    'METAL1', 30, (42, 158), 6, True,
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Via(
                    'POLY', 'METAL1', 30, 60, 2,
                    conn={"left": "n_i0_1", "right": "n_i0_2"},
                ),
                Device(
                    'nmos', 20, 40, 4, 20, 'vertical', name="n_i0_1",
                    source_net='_net0', drain_net='vss',
                ),
                Device(
                    'nmos', 40, 31, 4, 38, 'vertical', name="n_i0_2",
                    source_net='vss', drain_net='_net1',
                ),
                Via(
                    'POLY', 'METAL1', 30, 100, 2,
                    conn={"left": "p_i0_1", "right": "p_i0_2"},
                ),
                Device(
                    'pmos', 20, 150, 4, 40, 'vertical', name="p_i0_1",
                    source_net='_net0', drain_net='vdd',
                ),
                Device(
                    'pmos', 40, 150, 4, 80, 'vertical', name="p_i0_2",
                    source_net='vdd', drain_net='_net2',
                ),
            ],
            'i1': [
                Wire(
                    'METAL1', 110, (42, 158), 6, True, name="m1_i1_i",
                    space={"top": "vddrail", "bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (62, 110), 60, 6, False,
                    conn={"left": "v_i1_pl1", "right": "m1_i1_i"},
                ),
                Via(
                    'POLY', 'METAL1', 62, 60, 2, name="v_i1_pl1",
                    conn={"left": "n_i1_1"},
                ),
                Device(
                    'nmos', 60, 31, 4, 38, 'vertical', name="n_i1_1",
                    source_net='_net1', drain_net='q',
                ),
                Via('POLY', 'METAL1', 110, 60, 2, conn={"right": "n_i1_2"}),
                Device(
                    'nmos', 120, 40, 4, 20, 'vertical', name="n_i1_2",
                    source_net='vss', drain_net='_net3',
                ),
                Via(
                    'POLY', 'METAL1', 110, 100, 2,
                    conn={"left": "p_i1_1", "right": "p_i1_2"},
                ),
                Device(
                    'pmos', 100, 150, 4, 80, 'vertical', name="p_i1_1",
                    source_net='_net2', drain_net='vdd',
                ),
                Device(
                    'pmos', 120, 150, 4, 40, 'vertical', name="p_i1_2",
                    source_net='vdd', drain_net='_net3',
                ),
            ],
            'q': [
                Wire(
                    'METAL1', 50, (40, 130), 3, True, name="m1_q_o",
                    space={"bottom": "vssrail"},
                ),
                Wire(
                    'METAL1', (50, 70), 40, 6, False,
                    conn={"left": "m1_q_o", "right": "v_q_ndif1"},
                ),
                Via(
                    'NDIF', 'METAL1', 70, 40, 2, name="v_q_ndif1",
                    space={"bottom": "vssrail"},
                    conn={"left": "n_i1_1", "right": "n_net0_1"},
                ),
                Wire('METAL1', (50, 70), 120, 6, False),
                Via(
                    'PDIF', 'METAL1', 70, 140, 2, name="v_q_pdif1",
                    space={"top": "m1_net2_1"},
                    conn={"left": "p_net3_1", "right": "p_net0_1"},
                ),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 10, 184, 2),
                Wire('NTIE', 10, (180, 190), 6, False),
                Via(
                    'PDIF', 'METAL1', 30, 184, 2,
                    conn={"left": "p_i0_1", "right": "p_i0_2", "up": "vddrail"},
                ),
                Via(
                    'PDIF', 'METAL1', 110, 184, 2,
                    conn={"left": "p_i1_1", "right": "p_i1_2", "up": "vddrail"},
                ),
                Via('NTIE', 'METAL1', 130, 184, 2),
                Wire('NTIE', 130, (180, 190), 6, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 10, 14, 2),
                Wire('PTIE', 10, (8, 18), 6, False),
                Via(
                    'NDIF', 'METAL1', 30, 18, 2,
                    conn={"left": "n_i0_1", "right": "n_i0_2", "up": "vssrail"},
                ),
                Via(
                    'NDIF', 'METAL1', 110, 18, 2,
                    conn={"left": "n_net3_1", "right": "n_i1_2", "up": "vssrail"},
                ),
                Via('PTIE', 'METAL1', 130, 14, 2),
                Wire('PTIE', 130, (8, 18), 6, False),
            ],
        },
        finalize=True,
    ),
]


_oldcells = [
    StdCell(
        name='a2_x2', width=100, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 16, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (16, 36), 40, 6, False),
                Via('PDIF', 'METAL1', 34, 160, 2),
                Wire('PDIF', 36, (134, 166), 12, False),
                Wire('METAL1', 38, (42, 160), 6, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', (40, 72), 80, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net1': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Via('POLY', 'METAL1', 20, 120, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', 24, (54, 82), 4, False),
                Wire('POLY', 24, (118, 126), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'i1': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 48, (54, 60), 4, False),
                Wire('POLY', 48, (100, 124), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (48, 60), 60, 4, False),
                Wire('POLY', (48, 60), 100, 4, False),
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('NDIF', 82, (16, 46), 12, False),
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 14, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (162, 178), 6, False),
                Wire('PDIF', 60, (114, 186), 10, False),
                Via('PDIF', 'METAL1', 64, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 60, 18, 2),
                Wire('NDIF', 60, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a2_x4', width=120, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 16, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (16, 36), 40, 6, False),
                Wire('PDIF', 36, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 36, 160, 2),
                Wire('METAL1', 38, (42, 158), 6, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', (40, 96), 80, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (60, 140), 6, True),
                Via('POLY', 'METAL1', 20, 120, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 24, (56, 62), 4, False),
                Wire('POLY', 24, (118, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Wire('POLY', 44, (100, 124), 4, False),
                Device('pmos', 44, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 48, (54, 60), 4, False),
                Wire('POLY', (44, 56), 100, 4, False),
                Wire('POLY', (48, 60), 60, 4, False),
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 12, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (162, 178), 6, False),
                Wire('PDIF', 58, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 62, 182, 2),
                Via('PDIF', 'METAL1', 108, 120, 2),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('METAL1', 108, (122, 178), 6, False),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
                Via('PDIF', 'METAL1', 108, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 60, 18, 2),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 108, 20, 2),
                Wire('METAL1', 108, (22, 38), 6, False),
                Wire('NDIF', 108, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 108, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a3_x2', width=120, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 12, (134, 166), 8, False),
                Wire('NDIF', 14, (34, 66), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('PDIF', 'METAL1', 16, 148, 2),
                Wire('METAL1', (16, 78), 40, 6, False),
                Wire('METAL1', (16, 78), 148, 6, False),
                Via('PDIF', 'METAL1', 60, 148, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (42, 146), 6, False),
                Wire('POLY', (82, 92), 80, 4, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 120), 6, True),
                Device('nmos', 24, 50, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 24, (76, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'i1': [
                Device('nmos', 40, 50, 4, 40, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('METAL1', 40, (62, 120), 6, True),
                Wire('POLY', 40, (76, 122), 4, False),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', (40, 48), 122, 4, False),
                Wire('POLY', 48, (122, 128), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i2': [
                Device('nmos', 56, 50, 4, 40, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 56, (76, 104), 4, False),
                Wire('METAL1', 60, (62, 120), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', (56, 68), 104, 4, False),
                Wire('POLY', 68, (104, 124), 4, False),
                Device('pmos', 68, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 160), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 104, (16, 46), 8, False),
                Wire('PDIF', 104, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 36, 164, 2),
                Wire('METAL1', 36, (164, 176), 8, False),
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 82, 164, 2),
                Wire('METAL1', 82, (164, 176), 8, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 14, 14, 2),
                Via('PTIE', 'METAL1', 30, 14, 2),
                Wire('PTIE', (16, 48), 14, 12, False),
                Via('PTIE', 'METAL1', 46, 14, 2),
                Wire('NDIF', 70, (16, 66), 8, False),
                Via('NDIF', 'METAL1', 72, 18, 2),
                Wire('NDIF', 80, (16, 46), 16, False),
                Via('NDIF', 'METAL1', 84, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a3_x4', width=140, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 12, (126, 158), 12, False),
                Wire('NDIF', 14, (16, 46), 6, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', (14, 78), 138, 6, False),
                Wire('METAL1', (16, 78), 40, 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (126, 158), 12, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (42, 136), 6, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (80, 116), 80, 8, False),
                Device('nmos', 116, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 116, (56, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (62, 120), 6, True),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', 24, (56, 116), 4, False),
                Device('pmos', 24, 142, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'i1': [
                Device('nmos', 40, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', 40, (56, 98), 4, False),
                Wire('METAL1', 40, (62, 120), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', (40, 48), 104, 4, False),
                Wire('POLY', 48, (104, 116), 4, False),
                Device('pmos', 48, 142, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i2': [
                Device('nmos', 56, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 56, (56, 80), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 120), 6, True),
                Wire('POLY', 64, (80, 112), 4, False),
                Wire('POLY', (64, 70), 112, 4, False),
                Wire('POLY', 70, (112, 120), 4, False),
                Device('pmos', 70, 142, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 104, (16, 46), 12, False),
                Wire('PDIF', 104, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (126, 158), 12, False),
                Via('PDIF', 'METAL1', 36, 156, 2),
                Wire('METAL1', 36, (156, 176), 8, False),
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
                Via('PDIF', 'METAL1', 124, 120, 2),
                Via('PDIF', 'METAL1', 124, 140, 2),
                Wire('METAL1', 124, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 124, 160, 2),
                Via('PDIF', 'METAL1', 124, 182, 2),
                Wire('PDIF', 128, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 68, (16, 46), 12, False),
                Wire('NDIF', 76, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 80, 18, 2),
                Wire('NDIF', 84, (16, 46), 4, False),
                Via('NDIF', 'METAL1', 124, 18, 2),
                Wire('METAL1', 124, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 124, 40, 2),
                Wire('NDIF', 126, (16, 46), 6, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a4_x2', width=140, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 48, (34, 66), 8, False),
            ],
            '_net1': [
                Wire('PDIF', 30, (134, 166), 4, False),
                Via('PDIF', 'METAL1', 32, 140, 2),
                Wire('METAL1', (38, 100), 140, 6, False),
                Wire('PDIF', 74, (134, 166), 4, False),
                Via('PDIF', 'METAL1', 76, 140, 2),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 86, (34, 66), 8, False),
                Wire('METAL1', (86, 100), 40, 6, False),
                Via('POLY', 'METAL1', 100, 90, 2),
                Wire('METAL1', 102, (42, 138), 6, False),
                Wire('POLY', (98, 112), 90, 8, False),
                Wire('POLY', 108, (102, 106), 4, False),
                Device('pmos', 108, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (108, 112), 102, 4, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 112, (56, 100), 4, False),
            ],
            '_net2': [
                Wire('NDIF', 66, (34, 66), 8, False),
            ],
            '_net3': [
                Wire('NDIF', 30, (34, 66), 8, False),
            ],
            'i0': [
                Wire('METAL1', 20, (60, 118), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Device('nmos', 22, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 22, (76, 124), 4, False),
                Device('pmos', 22, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Device('nmos', 40, 50, 4, 40, 'vertical', source_net='_net3', drain_net='_net0'),
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', 40, (76, 124), 4, False),
                Device('pmos', 40, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'i2': [
                Device('nmos', 58, 50, 4, 40, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 58, (76, 102), 4, False),
                Wire('METAL1', 60, (42, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 64, (98, 124), 4, False),
                Device('pmos', 64, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i3': [
                Device('nmos', 76, 50, 4, 40, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 76, (76, 80), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 118), 6, True),
                Wire('POLY', 84, (80, 124), 4, False),
                Device('pmos', 84, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'q': [
                Wire('NDIF', 118, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 120, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 12, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('METAL1', 12, (162, 178), 8, False),
                Wire('PDIF', 52, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 52, 160, 2),
                Wire('METAL1', 52, (160, 176), 8, False),
                Wire('PDIF', 98, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 98, 162, 2),
                Wire('METAL1', 98, (162, 176), 8, False),
            ],
            'vss': [
                Wire('NDIF', 12, (34, 66), 8, False),
                Wire('METAL1', 14, (26, 44), 6, False),
                Via('NDIF', 'METAL1', 14, 44, 2),
                Via('PTIE', 'METAL1', 40, 12, 2),
                Wire('PTIE', (34, 78), 12, 12, False),
                Via('PTIE', 'METAL1', 72, 12, 2),
                Via('NDIF', 'METAL1', 104, 18, 2),
                Wire('NDIF', 104, (24, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='a4_x4', width=160, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 48, (34, 66), 8, False),
            ],
            '_net1': [
                Wire('NDIF', 30, (34, 66), 8, False),
            ],
            '_net2': [
                Wire('NDIF', 66, (34, 66), 8, False),
            ],
            '_net3': [
                Wire('PDIF', 36, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('METAL1', (38, 100), 140, 6, False),
                Wire('PDIF', 78, (134, 166), 4, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('METAL1', (86, 100), 40, 6, False),
                Via('POLY', 'METAL1', 98, 90, 2),
                Wire('METAL1', 102, (42, 138), 6, False),
                Wire('POLY', (98, 110), 90, 4, False),
                Wire('POLY', 110, (56, 106), 4, False),
                Device('pmos', 110, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (110, 112), 56, 4, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', (110, 126), 100, 8, False),
                Wire('POLY', 128, (56, 106), 4, False),
                Device('pmos', 128, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (128, 130), 56, 4, False),
                Device('nmos', 130, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('METAL1', 20, (62, 140), 6, True),
                Device('nmos', 22, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 22, (76, 100), 4, False),
                Wire('POLY', 24, (100, 126), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Device('nmos', 40, 50, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('METAL1', 40, (42, 118), 6, True),
                Wire('POLY', 40, (76, 120), 4, False),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', (40, 48), 122, 4, False),
                Wire('POLY', 48, (122, 128), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
            ],
            'i2': [
                Device('nmos', 58, 50, 4, 40, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 58, (76, 102), 4, False),
                Wire('METAL1', 60, (42, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 64, (100, 120), 4, False),
                Wire('POLY', (64, 68), 122, 4, False),
                Wire('POLY', 68, (122, 128), 4, False),
                Device('pmos', 68, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i3': [
                Device('nmos', 76, 50, 4, 40, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('POLY', 76, (76, 80), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 118), 6, True),
                Wire('POLY', 84, (80, 120), 4, False),
                Wire('POLY', (84, 88), 122, 4, False),
                Wire('POLY', 88, (122, 128), 4, False),
                Device('pmos', 88, 150, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
            ],
            'q': [
                Wire('NDIF', 120, (16, 46), 4, False),
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (40, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Wire('PDIF', 120, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 120, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 12, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('METAL1', 12, (162, 178), 6, False),
                Wire('PDIF', 58, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 58, 162, 2),
                Wire('METAL1', 58, (162, 176), 8, False),
                Wire('PDIF', 100, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 102, 184, 2),
                Wire('METAL1', 136, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 136, 182, 2),
                Via('PDIF', 'METAL1', 138, 120, 2),
                Via('PDIF', 'METAL1', 138, 140, 2),
                Wire('PDIF', 138, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 138, 160, 2),
            ],
            'vss': [
                Wire('METAL1', 14, (24, 40), 8, False),
                Via('NDIF', 'METAL1', 14, 40, 2),
                Wire('NDIF', 14, (34, 66), 12, False),
                Via('PTIE', 'METAL1', 40, 12, 2),
                Wire('PTIE', (34, 78), 12, 12, False),
                Via('PTIE', 'METAL1', 72, 12, 2),
                Via('NDIF', 'METAL1', 104, 18, 2),
                Wire('METAL1', 136, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 138, 18, 2),
                Wire('NDIF', 138, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 138, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='an12_x1', width=100, height=200,
        nets={
            '_net0': [
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 52, (56, 80), 4, False),
                Wire('POLY', 52, (82, 104), 4, False),
                Device('pmos', 52, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (52, 82), 80, 4, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Via('POLY', 'METAL1', 84, 80, 2),
                Via('PDIF', 'METAL1', 84, 120, 2),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('NDIF', 86, (34, 46), 8, False),
                Wire('METAL1', 86, (42, 138), 6, False),
                Wire('PDIF', 86, (114, 146), 8, False),
            ],
            'i0': [
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 28, (56, 92), 4, False),
                Via('POLY', 'METAL1', 28, 80, 2),
                Wire('POLY', (28, 36), 92, 4, False),
                Wire('METAL1', (30, 40), 80, 8, False),
                Wire('POLY', 36, (94, 104), 4, False),
                Device('pmos', 36, 150, 4, 80, 'vertical', source_net='q', drain_net='_net1'),
                Wire('METAL1', 40, (82, 158), 6, True),
            ],
            'i1': [
                Wire('METAL1', 60, (62, 158), 6, True),
                Wire('METAL1', (62, 66), 60, 8, False),
                Wire('METAL1', (62, 66), 100, 6, False),
                Via('POLY', 'METAL1', 70, 60, 2),
                Via('POLY', 'METAL1', 70, 100, 2),
                Wire('POLY', (72, 76), 56, 4, False),
                Wire('POLY', (72, 76), 104, 4, False),
                Device('nmos', 76, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Device('pmos', 76, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'q': [
                Wire('METAL1', 12, (60, 98), 6, False),
                Wire('METAL1', (12, 18), 60, 6, False),
                Wire('METAL1', (14, 16), 100, 6, False),
                Wire('PDIF', 16, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Wire('METAL1', 20, (102, 160), 6, True),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 24, (114, 166), 12, False),
                Wire('METAL1', (20, 38), 60, 6, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (34, 46), 12, False),
                Wire('METAL1', 40, (42, 60), 6, False),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 60, 182, 2),
                Wire('PDIF', 64, (114, 186), 8, False),
                Wire('NTIE', 82, (164, 186), 12, False),
                Via('NTIE', 'METAL1', 82, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 16, (34, 46), 12, False),
                Wire('METAL1', 20, (24, 38), 8, False),
                Via('NDIF', 'METAL1', 20, 38, 2),
                Wire('METAL1', 64, (24, 40), 8, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
                Wire('NDIF', 64, (34, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='an12_x4', width=160, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (62, 76), 40, 6, False),
                Via('PDIF', 'METAL1', 76, 140, 2),
                Wire('PDIF', 76, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 76, 160, 2),
                Wire('METAL1', 78, (42, 158), 6, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', (80, 132), 80, 4, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 112, (56, 104), 4, False),
                Device('pmos', 112, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 132, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 132, (56, 104), 4, False),
                Device('pmos', 132, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('NDIF', 14, (34, 52), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Wire('NDIF', 16, (22, 34), 12, False),
                Via('NDIF', 'METAL1', 16, 52, 2),
                Via('POLY', 'METAL1', 16, 100, 2),
                Wire('METAL1', 16, (54, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('POLY', (14, 64), 100, 4, False),
                Wire('POLY', 64, (60, 124), 4, False),
                Device('pmos', 64, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
                Wire('POLY', (64, 72), 58, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 72, (52, 58), 4, False),
            ],
            '_net2': [
                Wire('NDIF', 82, (16, 46), 8, False),
            ],
            'i0': [
                Wire('POLY', 24, (124, 128), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Device('nmos', 28, 28, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 28, (40, 44), 4, False),
                Wire('POLY', (28, 36), 46, 4, False),
                Wire('POLY', (24, 42), 122, 4, False),
                Wire('POLY', 36, (48, 62), 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
            ],
            'i1': [
                Wire('POLY', 88, (102, 124), 4, False),
                Device('pmos', 88, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 92, (54, 56), 4, False),
                Wire('POLY', 92, (58, 62), 4, False),
                Wire('POLY', (88, 100), 102, 4, False),
                Wire('POLY', (92, 100), 64, 4, False),
                Via('POLY', 'METAL1', 100, 68, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Via('PDIF', 'METAL1', 120, 160, 2),
                Wire('NDIF', 124, (16, 46), 12, False),
                Wire('PDIF', 124, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 44, (134, 166), 28, False),
                Via('PDIF', 'METAL1', 44, 160, 2),
                Wire('METAL1', 44, (160, 176), 8, False),
                Wire('PDIF', 100, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 104, 182, 2),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('METAL1', 140, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
                Via('PDIF', 'METAL1', 140, 182, 2),
                Wire('PDIF', 144, (114, 186), 8, False),
            ],
            'vss': [
                Wire('METAL1', 38, (26, 32), 8, False),
                Via('NDIF', 'METAL1', 38, 32, 2),
                Wire('NDIF', 40, (22, 34), 8, False),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 140, 18, 2),
                Wire('METAL1', 140, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 140, 40, 2),
                Wire('NDIF', 144, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ao22_x2', width=120, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 38, (34, 60), 12, False),
                Via('NDIF', 'METAL1', 38, 62, 2),
                Wire('METAL1', (38, 58), 64, 6, False),
                Via('POLY', 'METAL1', 60, 88, 2),
                Wire('METAL1', 60, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 60, 136, 2),
                Wire('PDIF', 60, (130, 162), 12, False),
                Via('PDIF', 'METAL1', 60, 156, 2),
                Wire('POLY', (58, 92), 88, 4, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net1': [
                Wire('PDIF', 36, (130, 162), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (18, 58), 40, 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 138), 6, True),
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', 24, (56, 124), 4, False),
                Device('pmos', 24, 146, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 48), 104, 4, False),
                Wire('POLY', (40, 52), 76, 4, False),
                Wire('POLY', 48, (104, 122), 4, False),
                Device('pmos', 48, 146, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 52, (56, 72), 4, False),
            ],
            'i2': [
                Device('nmos', 70, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 70, (52, 56), 4, False),
                Wire('POLY', 70, (104, 124), 4, False),
                Device('pmos', 70, 146, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (70, 80), 56, 4, False),
                Wire('POLY', (70, 80), 104, 4, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Via('POLY', 'METAL1', 80, 100, 2),
                Wire('METAL1', 80, (62, 158), 6, True),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 160), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 104, (16, 46), 8, False),
                Wire('PDIF', 104, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 14, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (160, 176), 8, False),
                Via('NTIE', 'METAL1', 36, 182, 2),
                Wire('NTIE', (30, 66), 184, 8, False),
                Via('NTIE', 'METAL1', 60, 182, 2),
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 82, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 82, 40, 2),
                Wire('METAL1', 84, (22, 40), 6, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ao22_x4', width=160, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 34, (32, 44), 4, False),
                Wire('NDIF', 40, (32, 60), 8, False),
                Via('NDIF', 'METAL1', 40, 62, 2),
                Wire('NDIF', 46, (32, 44), 4, False),
                Wire('METAL1', (38, 58), 62, 6, False),
                Via('POLY', 'METAL1', 60, 88, 2),
                Wire('METAL1', 60, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 60, 136, 2),
                Wire('PDIF', 60, (130, 162), 12, False),
                Via('PDIF', 'METAL1', 60, 156, 2),
                Wire('POLY', (60, 132), 84, 4, False),
                Device('nmos', 108, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 108, (56, 104), 4, False),
                Device('pmos', 108, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 132, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 132, (56, 104), 4, False),
                Device('pmos', 132, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('PDIF', 36, (130, 162), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 14, (32, 44), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (18, 66), 40, 6, False),
                Wire('NDIF', 68, (32, 44), 4, False),
                Via('NDIF', 'METAL1', 68, 40, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 138), 6, True),
                Device('nmos', 24, 38, 4, 20, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', 24, (54, 124), 4, False),
                Device('pmos', 24, 146, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 48), 104, 4, False),
                Wire('POLY', 48, (108, 120), 4, False),
                Device('pmos', 48, 146, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (40, 58), 74, 4, False),
                Device('nmos', 58, 38, 4, 20, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 58, (50, 74), 4, False),
            ],
            'i2': [
                Wire('POLY', 72, (104, 124), 4, False),
                Device('pmos', 72, 146, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 76, 38, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 76, (54, 62), 4, False),
                Wire('POLY', (72, 80), 104, 4, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Via('POLY', 'METAL1', 80, 100, 2),
                Wire('METAL1', 80, (62, 158), 6, True),
            ],
            'q': [
                Wire('NDIF', 120, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 120, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (160, 174), 8, False),
                Via('NTIE', 'METAL1', 36, 182, 2),
                Wire('NTIE', (30, 66), 184, 8, False),
                Via('NTIE', 'METAL1', 60, 182, 2),
                Wire('PDIF', 84, (130, 162), 4, False),
                Wire('PDIF', 90, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 92, 182, 2),
                Wire('PDIF', 96, (114, 186), 16, False),
                Via('PDIF', 'METAL1', 144, 120, 2),
                Via('PDIF', 'METAL1', 144, 140, 2),
                Wire('METAL1', 144, (122, 178), 6, False),
                Wire('PDIF', 144, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 144, 160, 2),
                Via('PDIF', 'METAL1', 144, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 88, (32, 44), 8, False),
                Wire('NDIF', 94, (16, 44), 12, False),
                Wire('NDIF', 96, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 98, 18, 2),
                Via('NDIF', 'METAL1', 144, 18, 2),
                Wire('METAL1', 144, (22, 38), 6, False),
                Wire('NDIF', 144, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 144, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ao2o22_x2', width=180, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', (18, 106), 40, 6, False),
                Via('NDIF', 'METAL1', 108, 40, 2),
                Wire('NDIF', 108, (34, 46), 12, False),
            ],
            '_net1': [
                Wire('PDIF', 84, (130, 162), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 38, (34, 62), 8, False),
                Via('NDIF', 'METAL1', 38, 64, 2),
                Wire('METAL1', (38, 58), 64, 6, False),
                Wire('METAL1', 60, (64, 158), 6, False),
                Via('PDIF', 'METAL1', 60, 136, 2),
                Wire('PDIF', 60, (130, 162), 12, False),
                Via('PDIF', 'METAL1', 60, 156, 2),
                Wire('METAL1', (66, 118), 156, 6, False),
                Wire('METAL1', 120, (82, 154), 6, False),
                Wire('METAL1', (120, 136), 80, 6, False),
                Via('POLY', 'METAL1', 136, 80, 2),
                Wire('POLY', (140, 146), 80, 8, False),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 148, (56, 104), 4, False),
                Device('pmos', 148, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net3': [
                Wire('PDIF', 36, (130, 162), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 138), 6, True),
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 24, (56, 124), 4, False),
                Device('pmos', 24, 146, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 52), 84, 4, False),
                Wire('POLY', 48, (86, 122), 4, False),
                Device('pmos', 48, 146, 4, 40, 'vertical', source_net='_net3', drain_net='_net2'),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', 52, (56, 82), 4, False),
            ],
            'i2': [
                Wire('POLY', 68, (62, 118), 4, False),
                Wire('POLY', (68, 70), 60, 4, False),
                Wire('POLY', (68, 70), 120, 4, False),
                Device('nmos', 70, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 70, (54, 60), 4, False),
                Device('pmos', 70, 146, 4, 40, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', (70, 80), 84, 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 138), 6, True),
            ],
            'i3': [
                Device('nmos', 98, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 98, (56, 124), 4, False),
                Device('pmos', 98, 146, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 138), 6, True),
            ],
            'q': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (160, 176), 8, False),
                Via('NTIE', 'METAL1', 36, 182, 2),
                Via('NTIE', 'METAL1', 60, 182, 2),
                Wire('NTIE', (30, 90), 184, 8, False),
                Via('NTIE', 'METAL1', 84, 182, 2),
                Wire('PDIF', 114, (130, 186), 12, False),
                Via('PDIF', 'METAL1', 114, 184, 2),
                Wire('PDIF', 136, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 136, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 84, 16, 2),
                Wire('NDIF', 84, (20, 46), 8, False),
                Via('NDIF', 'METAL1', 136, 18, 2),
                Wire('METAL1', 136, (22, 38), 6, False),
                Wire('NDIF', 136, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ao2o22_x4', width=200, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 84, (134, 166), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', (16, 106), 40, 6, False),
                Via('NDIF', 'METAL1', 108, 40, 2),
                Wire('NDIF', 108, (34, 46), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 36, (34, 62), 8, False),
                Via('NDIF', 'METAL1', 36, 64, 2),
                Wire('METAL1', (38, 58), 60, 6, False),
                Wire('METAL1', 60, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (66, 118), 160, 6, False),
                Wire('METAL1', 120, (82, 158), 6, False),
                Wire('METAL1', (120, 134), 80, 6, False),
                Via('POLY', 'METAL1', 134, 80, 2),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 148, (56, 104), 4, False),
                Device('pmos', 148, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (140, 172), 80, 8, False),
                Device('nmos', 172, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 172, (56, 104), 4, False),
                Device('pmos', 172, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net3': [
                Wire('PDIF', 36, (134, 166), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('METAL1', 20, (82, 138), 6, True),
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', 24, (56, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', 40, (104, 120), 4, False),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 48), 96, 4, False),
                Wire('POLY', (40, 48), 122, 4, False),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 48, (56, 92), 4, False),
                Wire('POLY', 48, (122, 128), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net3', drain_net='_net2'),
            ],
            'i2': [
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 72, (56, 74), 4, False),
                Wire('POLY', 72, (122, 126), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', (72, 80), 76, 4, False),
                Wire('POLY', (72, 80), 122, 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 138), 6, True),
                Wire('POLY', 80, (86, 120), 4, False),
            ],
            'i3': [
                Wire('POLY', 96, (120, 128), 4, False),
                Device('pmos', 96, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (96, 100), 120, 4, False),
                Device('nmos', 100, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('POLY', 100, (56, 120), 4, False),
                Wire('METAL1', 100, (62, 138), 6, True),
            ],
            'q': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (160, 176), 8, False),
                Wire('PDIF', 106, (134, 166), 8, False),
                Wire('PDIF', 114, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 114, 182, 2),
                Wire('PDIF', 136, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 136, 182, 2),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Via('PDIF', 'METAL1', 180, 182, 2),
                Wire('PDIF', 184, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 86, 16, 2),
                Wire('NDIF', 86, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 118, 16, 2),
                Wire('NDIF', 136, (18, 46), 8, False),
                Via('NDIF', 'METAL1', 138, 18, 2),
                Wire('METAL1', 140, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 140, 40, 2),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('METAL1', 180, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 184, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='buf_x2', width=80, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (42, 46), 8, False),
                Wire('PDIF', 14, (114, 130), 8, False),
                Via('NDIF', 'METAL1', 16, 44, 2),
                Via('POLY', 'METAL1', 16, 80, 2),
                Wire('METAL1', 16, (46, 118), 6, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Wire('POLY', (14, 50), 80, 8, False),
                Device('nmos', 50, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 50, (56, 104), 4, False),
                Device('pmos', 50, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i': [
                Device('nmos', 24, 44, 4, 12, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (52, 54), 4, False),
                Wire('POLY', 24, (104, 110), 4, False),
                Device('pmos', 24, 122, 4, 24, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 32), 56, 4, False),
                Wire('POLY', (24, 32), 104, 4, False),
                Via('POLY', 'METAL1', 32, 60, 2),
                Via('POLY', 'METAL1', 32, 100, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
            ],
            'q': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 18, 166, 2),
                Wire('NTIE', 18, (164, 184), 12, False),
                Wire('METAL1', 18, (168, 184), 6, False),
                Via('NTIE', 'METAL1', 18, 182, 2),
                Wire('PDIF', 32, (114, 130), 4, False),
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 32, (42, 46), 4, False),
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='buf_x4', width=100, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (114, 146), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('POLY', 'METAL1', 16, 80, 2),
                Wire('METAL1', 16, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('POLY', (12, 72), 80, 8, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (52, 56), 4, False),
                Wire('POLY', 24, (104, 108), 4, False),
                Device('pmos', 24, 130, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 32), 56, 4, False),
                Wire('POLY', (24, 32), 104, 4, False),
                Via('POLY', 'METAL1', 32, 60, 2),
                Via('POLY', 'METAL1', 32, 100, 2),
                Wire('METAL1', (34, 38), 60, 6, False),
                Wire('METAL1', (34, 38), 100, 6, False),
                Wire('METAL1', 40, (42, 158), 6, True),
            ],
            'q': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('NTIE', 18, (170, 184), 12, False),
                Via('NTIE', 'METAL1', 18, 182, 2),
                Wire('PDIF', 34, (114, 146), 8, False),
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 182, 2),
                Via('PDIF', 'METAL1', 84, 120, 2),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('METAL1', 84, (122, 178), 6, False),
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 84, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 34, (34, 46), 4, False),
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 82, 18, 2),
                Wire('METAL1', 82, (16, 32), 6, False),
                Via('NDIF', 'METAL1', 82, 40, 2),
                Wire('NDIF', 84, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='buf_x8', width=160, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('POLY', 'METAL1', 16, 80, 2),
                Wire('METAL1', 16, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (12, 116), 80, 8, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 116, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 116, (56, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i': [
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (52, 56), 4, False),
                Wire('POLY', 24, (104, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 32), 56, 4, False),
                Wire('POLY', (24, 32), 104, 4, False),
                Via('POLY', 'METAL1', 32, 60, 2),
                Via('POLY', 'METAL1', 32, 100, 2),
                Wire('METAL1', (34, 38), 60, 6, False),
                Wire('METAL1', (34, 38), 100, 6, False),
                Wire('METAL1', 40, (42, 158), 6, True),
            ],
            'q': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 80, 6, False),
                Wire('NDIF', 108, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 108, 40, 2),
                Wire('METAL1', 108, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 108, 120, 2),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 36, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Via('PDIF', 'METAL1', 84, 120, 2),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('METAL1', 84, (122, 178), 6, False),
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 84, 184, 2),
                Wire('METAL1', 126, (136, 178), 6, False),
                Via('PDIF', 'METAL1', 126, 160, 2),
                Via('PDIF', 'METAL1', 126, 184, 2),
                Wire('PDIF', 128, (160, 186), 12, False),
                Wire('METAL1', (132, 144), 136, 6, False),
                Via('NTIE', 'METAL1', 144, 116, 2),
                Wire('METAL1', 144, (118, 134), 6, False),
                Wire('NTIE', 144, (114, 138), 12, False),
                Via('NTIE', 'METAL1', 144, 136, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 36, 18, 2),
                Wire('NDIF', 36, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 18, 2),
                Wire('METAL1', 84, (22, 38), 6, False),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 130, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 132, 18, 2),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('METAL1', 132, (22, 66), 6, False),
                Via('PTIE', 'METAL1', 132, 68, 2),
                Wire('PTIE', (132, 144), 68, 12, False),
                Wire('METAL1', (134, 146), 68, 6, False),
                Via('PTIE', 'METAL1', 144, 68, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x1', width=60, height=200,
        nets={
            'i': [
                Wire('METAL1', 20, (62, 158), 6, True),
                Via('POLY', 'METAL1', 24, 80, 2),
                Device('nmos', 30, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 30, (56, 104), 4, False),
                Device('pmos', 30, 130, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (34, 46), 12, False),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Wire('PDIF', 40, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 40, 140, 2),
            ],
            'vdd': [
                Wire('PDIF', 20, (114, 188), 10, False),
                Via('PDIF', 'METAL1', 20, 188, 2),
                Wire('NTIE', 40, (168, 186), 12, False),
                Via('NTIE', 'METAL1', 40, 182, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 20, 14, 2),
                Wire('METAL1', 20, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('NDIF', 20, (34, 46), 10, False),
                Via('PTIE', 'METAL1', 40, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x1m2', width=80, height=200,
        nets={
            'i': [
                Wire('METAL1', 40, (102, 158), 6, True),
                Via('POLY', 'METAL1', 44, 100, 2),
                Device('nmos', 50, 60, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 50, (76, 104), 4, False),
                Device('pmos', 50, 130, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'i2': [
                Device('nmos', 30, 60, 4, 20, 'vertical', source_net='nq2', drain_net='vss'),
                Wire('POLY', 30, (76, 104), 4, False),
                Device('pmos', 30, 130, 4, 40, 'vertical', source_net='nq2', drain_net='vdd'),
                Via('POLY', 'METAL1', 36, 80, 2),
                Wire('METAL1', 40, (42, 78), 6, True),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 60, 60, 2),
                Wire('NDIF', 60, (54, 66), 12, False),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Wire('PDIF', 60, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
            ],
            'nq2': [
                Via('NDIF', 'METAL1', 20, 60, 2),
                Wire('NDIF', 20, (54, 66), 12, False),
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Wire('PDIF', 20, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 20, 140, 2),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 20, 186, 2),
                Wire('PDIF', 40, (114, 186), 10, False),
                Via('PDIF', 'METAL1', 40, 186, 2),
                Via('NTIE', 'METAL1', 60, 186, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 20, 14, 2),
                Via('NDIF', 'METAL1', 40, 14, 2),
                Wire('NDIF', 40, (14, 46), 10, False),
                Via('PTIE', 'METAL1', 60, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x2', width=60, height=200,
        nets={
            'i': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', 26, (76, 84), 6, False),
                Device('nmos', 30, 50, 4, 40, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 30, (76, 104), 4, False),
                Device('pmos', 30, 140, 4, 60, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (34, 66), 12, False),
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 16, (114, 166), 8, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (160, 174), 8, False),
            ],
            'vss': [
                Wire('NDIF', 16, (34, 66), 8, False),
                Wire('METAL1', 20, (22, 40), 8, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x4', width=80, height=200,
        nets={
            'i': [
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('POLY', 'METAL1', 24, 80, 2),
                Device('nmos', 30, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 30, (56, 104), 4, False),
                Device('pmos', 30, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (30, 50), 80, 8, False),
                Device('nmos', 50, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 50, (56, 128), 4, False),
                Device('pmos', 50, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'nq': [
                Wire('NDIF', 40, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 20, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 20, 184, 2),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (122, 178), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Via('PDIF', 'METAL1', 60, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 18, 2),
                Wire('NDIF', 20, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 18, 2),
                Wire('METAL1', 60, (22, 38), 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x4m2', width=120, height=200,
        nets={
            'i': [
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('POLY', 'METAL1', 24, 90, 2),
                Device('nmos', 30, 50, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 30, (56, 104), 4, False),
                Device('pmos', 30, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (30, 50), 90, 8, False),
                Device('nmos', 50, 50, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 50, (56, 128), 4, False),
                Device('pmos', 50, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'i2': [
                Device('nmos', 70, 50, 4, 38, 'vertical', source_net='vss', drain_net='nq2'),
                Wire('POLY', 70, (56, 128), 4, False),
                Device('pmos', 70, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq2'),
                Wire('POLY', (70, 90), 90, 8, False),
                Device('nmos', 90, 50, 4, 38, 'vertical', source_net='nq2', drain_net='vss'),
                Wire('POLY', 90, (56, 104), 4, False),
                Device('pmos', 90, 150, 4, 80, 'vertical', source_net='nq2', drain_net='vdd'),
                Via('POLY', 'METAL1', 96, 90, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
            ],
            'nq2': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('NDIF', 80, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 80, 60, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 80, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 20, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 20, 184, 2),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (122, 178), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Via('PDIF', 'METAL1', 60, 184, 2),
                Wire('PDIF', 100, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 100, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 14, 2),
                Wire('NDIF', 20, (14, 65), 10, False),
                Via('PTIE', 'METAL1', 40, 14, 2),
                Via('NDIF', 'METAL1', 60, 14, 2),
                Wire('NDIF', 60, (14, 65), 10, False),
                Wire('METAL1', 60, (22, 58), 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Via('NDIF', 'METAL1', 60, 60, 2),
                Via('PTIE', 'METAL1', 80, 14, 2),
                Via('NDIF', 'METAL1', 100, 14, 2),
                Wire('NDIF', 100, (14, 65), 10, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='inv_x8', width=140, height=200,
        nets={
            'i': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Wire('POLY', 26, (76, 84), 6, False),
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 28, (56, 104), 4, False),
                Device('pmos', 28, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 52, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 52, (56, 104), 4, False),
                Device('pmos', 52, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (30, 98), 60, 8, False),
                Device('nmos', 76, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 76, (56, 104), 4, False),
                Device('pmos', 76, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 98, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 98, (56, 104), 4, False),
                Device('pmos', 98, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'nq': [
                Wire('NDIF', 40, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (42, 86), 80, 6, False),
                Wire('NDIF', 88, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 88, 40, 2),
                Wire('METAL1', 88, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 88, 120, 2),
                Via('PDIF', 'METAL1', 88, 140, 2),
                Wire('PDIF', 88, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 88, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 16, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 18, 184, 2),
                Via('PDIF', 'METAL1', 64, 120, 2),
                Via('PDIF', 'METAL1', 64, 140, 2),
                Wire('METAL1', 64, (122, 178), 6, False),
                Wire('PDIF', 64, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 64, 160, 2),
                Via('PDIF', 'METAL1', 64, 184, 2),
                Wire('METAL1', 112, (138, 178), 6, False),
                Via('PDIF', 'METAL1', 112, 160, 2),
                Wire('PDIF', 112, (158, 186), 12, False),
                Via('PDIF', 'METAL1', 112, 184, 2),
                Wire('METAL1', (114, 124), 136, 6, False),
                Via('NTIE', 'METAL1', 124, 116, 2),
                Wire('METAL1', 124, (118, 134), 6, False),
                Wire('NTIE', 124, (110, 142), 12, False),
                Via('NTIE', 'METAL1', 124, 136, 2),
            ],
            'vss': [
                Wire('NDIF', 16, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 18, 18, 2),
                Via('NDIF', 'METAL1', 64, 18, 2),
                Wire('METAL1', 64, (22, 38), 6, False),
                Wire('NDIF', 64, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
                Via('NDIF', 'METAL1', 112, 18, 2),
                Wire('NDIF', 112, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 112, 40, 2),
                Wire('METAL1', 112, (22, 66), 6, False),
                Via('PTIE', 'METAL1', 112, 68, 2),
                Wire('PTIE', (106, 120), 68, 12, False),
                Wire('METAL1', (112, 124), 68, 6, False),
                Via('PTIE', 'METAL1', 124, 68, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='mx2_x2', width=180, height=200,
        nets={
            '_net1': [
                Wire('NDIF', 80, (16, 26), 20, False),
                Wire('NDIF', 80, (16, 62), 8, False),
                Via('NDIF', 'METAL1', 80, 60, 2),
                Via('POLY', 'METAL1', 80, 96, 2),
                Wire('METAL1', 80, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('POLY', (78, 152), 92, 4, False),
                Device('nmos', 152, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 152, (56, 104), 4, False),
                Device('pmos', 152, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net3': [
                Wire('PDIF', 60, (134, 166), 4, False),
            ],
            '_net4': [
                Wire('PDIF', 100, (134, 166), 4, False),
            ],
            '_net5': [
                Wire('METAL1', 14, (42, 158), 6, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Wire('NDIF', 16, (16, 40), 8, False),
                Via('NDIF', 'METAL1', 16, 44, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 98), 40, 6, False),
                Via('POLY', 'METAL1', 64, 40, 2),
                Device('nmos', 66, 21, 4, 18, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 66, (32, 38), 4, False),
                Wire('POLY', 88, (122, 126), 4, False),
                Device('pmos', 88, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net4'),
                Wire('POLY', (88, 92), 122, 4, False),
                Wire('POLY', 94, (106, 122), 4, False),
                Wire('METAL1', 100, (42, 106), 6, False),
                Via('POLY', 'METAL1', 100, 108, 2),
            ],
            'cmd': [
                Wire('POLY', 28, (52, 124), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='_net5', drain_net='vdd'),
                Wire('POLY', (28, 30), 48, 4, False),
                Device('nmos', 30, 21, 4, 18, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 30, (32, 48), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 158), 6, True),
                Wire('POLY', (28, 96), 80, 4, False),
                Wire('POLY', 64, (80, 122), 4, False),
                Wire('POLY', (66, 72), 122, 4, False),
                Wire('POLY', 72, (122, 126), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net3', drain_net='_net1'),
                Device('nmos', 96, 21, 4, 18, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 96, (36, 80), 4, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
                Wire('POLY', (38, 48), 56, 4, False),
                Wire('POLY', (38, 48), 124, 4, False),
                Device('nmos', 48, 21, 4, 18, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 48, (34, 56), 4, False),
                Wire('POLY', 48, (126, 130), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Wire('POLY', 112, (124, 128), 4, False),
                Device('pmos', 112, 150, 4, 40, 'vertical', source_net='_net4', drain_net='vdd'),
                Device('nmos', 114, 21, 4, 18, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 114, (36, 56), 4, False),
                Wire('POLY', (112, 122), 124, 4, False),
                Wire('POLY', (114, 122), 58, 4, False),
                Via('POLY', 'METAL1', 120, 60, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('POLY', 'METAL1', 120, 120, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 160), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Wire('NDIF', 164, (16, 46), 8, False),
                Wire('PDIF', 164, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (134, 166), 6, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', 40, (160, 180), 8, False),
                Wire('PDIF', 126, (134, 186), 8, False),
                Wire('PDIF', 136, (134, 186), 12, False),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Wire('PDIF', 140, (114, 130), 12, False),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('METAL1', 140, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
                Via('PDIF', 'METAL1', 140, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 40, 18, 2),
                Wire('NDIF', 40, (16, 26), 8, False),
                Wire('NDIF', 130, (16, 26), 12, False),
                Wire('NDIF', 138, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 140, 18, 2),
                Wire('METAL1', 140, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 140, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='mx3_x2', width=260, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 48, (154, 186), 8, False),
                Via('PDIF', 'METAL1', 50, 160, 2),
                Wire('METAL1', (52, 130), 160, 6, False),
                Via('PDIF', 'METAL1', 132, 160, 2),
                Wire('PDIF', 132, (154, 186), 8, False),
            ],
            '_net1': [
                Wire('NDIF', 44, (26, 38), 12, False),
                Via('NDIF', 'METAL1', 44, 40, 2),
                Wire('METAL1', (46, 128), 40, 6, False),
                Via('NDIF', 'METAL1', 130, 40, 2),
                Wire('NDIF', 132, (26, 42), 8, False),
            ],
            '_net3': [
                Wire('METAL1', 42, (66, 118), 6, False),
                Via('NDIF', 'METAL1', 44, 64, 2),
                Wire('NDIF', 44, (62, 70), 12, False),
                Via('PDIF', 'METAL1', 44, 120, 2),
                Wire('PDIF', 44, (114, 134), 8, False),
                Wire('METAL1', (46, 70), 60, 6, False),
                Via('POLY', 'METAL1', 72, 60, 2),
                Wire('POLY', (68, 76), 60, 8, False),
                Wire('METAL1', (46, 98), 120, 6, False),
                Device('nmos', 76, 34, 4, 24, 'vertical', source_net='_net9', drain_net='_net5'),
                Wire('POLY', 76, (52, 60), 4, False),
                Via('POLY', 'METAL1', 100, 120, 2),
                Wire('POLY', 106, (118, 144), 4, False),
                Device('pmos', 106, 170, 4, 40, 'vertical', source_net='_net5', drain_net='_net6'),
            ],
            '_net4': [
                Wire('POLY', (134, 136), 60, 4, False),
                Via('POLY', 'METAL1', 136, 60, 2),
                Wire('POLY', 140, (58, 140), 4, False),
                Wire('POLY', (140, 144), 142, 4, False),
                Wire('POLY', 144, (142, 146), 4, False),
                Device('pmos', 144, 170, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 164, 26, 4, 24, 'vertical', source_net='vss', drain_net='_net7'),
                Wire('POLY', 164, (44, 62), 4, False),
                Wire('METAL1', (138, 198), 60, 6, False),
                Via('POLY', 'METAL1', 168, 60, 2),
                Via('NDIF', 'METAL1', 196, 64, 2),
                Wire('NDIF', 196, (62, 66), 12, False),
                Via('PDIF', 'METAL1', 196, 120, 2),
                Wire('PDIF', 196, (114, 134), 12, False),
                Wire('METAL1', 200, (62, 118), 6, False),
            ],
            '_net5': [
                Wire('NDIF', 90, (26, 60), 8, False),
                Via('NDIF', 'METAL1', 90, 60, 2),
                Via('PDIF', 'METAL1', 92, 140, 2),
                Wire('PDIF', 92, (142, 186), 12, False),
                Wire('METAL1', (94, 110), 60, 6, False),
                Wire('METAL1', 112, (62, 78), 6, False),
                Wire('METAL1', (114, 118), 80, 6, False),
                Wire('METAL1', 120, (82, 138), 6, False),
                Wire('METAL1', (94, 218), 140, 6, False),
                Wire('NDIF', 196, (18, 40), 8, False),
                Wire('METAL1', 196, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 196, 160, 2),
                Wire('PDIF', 196, (154, 186), 12, False),
                Via('NDIF', 'METAL1', 198, 40, 2),
                Wire('METAL1', (198, 220), 40, 6, False),
                Via('POLY', 'METAL1', 220, 80, 2),
                Wire('METAL1', 220, (42, 138), 6, False),
                Wire('POLY', (220, 232), 80, 4, False),
                Device('nmos', 232, 50, 4, 40, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 232, (76, 104), 4, False),
                Device('pmos', 232, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net8': [
                Wire('PDIF', 68, (154, 186), 8, False),
            ],
            '_net9': [
                Wire('NDIF', 68, (26, 42), 8, False),
            ],
            'cmd0': [
                Wire('METAL1', 140, (82, 118), 6, True),
                Device('nmos', 146, 26, 4, 24, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 146, (40, 46), 4, False),
                Wire('METAL1', (142, 154), 100, 6, False),
                Wire('POLY', (146, 152), 46, 4, False),
                Wire('POLY', 152, (48, 76), 4, False),
                Wire('POLY', (152, 160), 76, 4, False),
                Via('POLY', 'METAL1', 160, 100, 2),
                Wire('POLY', 160, (76, 140), 4, False),
                Wire('POLY', (160, 166), 142, 4, False),
                Wire('POLY', 166, (142, 148), 4, False),
                Device('pmos', 166, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
                Wire('POLY', (160, 204), 100, 4, False),
                Device('nmos', 204, 64, 4, 12, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 204, (76, 104), 4, False),
                Device('pmos', 204, 124, 4, 28, 'vertical', source_net='_net4', drain_net='vdd'),
            ],
            'cmd1': [
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('METAL1', 20, (62, 140), 6, True),
                Wire('POLY', (20, 32), 100, 8, False),
                Device('nmos', 36, 66, 4, 16, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 36, (80, 104), 4, False),
                Device('pmos', 36, 124, 4, 28, 'vertical', source_net='vdd', drain_net='_net3'),
                Wire('METAL1', (22, 70), 140, 6, False),
                Via('POLY', 'METAL1', 72, 140, 2),
                Wire('POLY', 76, (80, 140), 4, False),
                Wire('POLY', 76, (142, 146), 4, False),
                Device('pmos', 76, 170, 4, 40, 'vertical', source_net='_net8', drain_net='_net5'),
                Wire('POLY', (80, 104), 80, 4, False),
                Device('nmos', 104, 34, 4, 24, 'vertical', source_net='_net5', drain_net='_net10'),
                Wire('POLY', 104, (52, 80), 4, False),
            ],
            'i0': [
                Wire('METAL1', (160, 160), 120, 6, True),
                Wire('METAL1', (162, 174), 80, 6, True),
                Wire('METAL1', (162, 174), 120, 6, False),
                Via('POLY', 'METAL1', 178, 120, 2),
                Via('POLY', 'METAL1', 180, 82, 2),
                Wire('METAL1', 180, (80, 120), 6, True),
                Device('nmos', 182, 26, 4, 24, 'vertical', source_net='_net7', drain_net='_net5'),
                Wire('POLY', 182, (44, 80), 4, False),
                Wire('POLY', 182, (118, 146), 4, False),
                Device('pmos', 182, 170, 4, 40, 'vertical', source_net='_net2', drain_net='_net5'),
            ],
            'i1': [
                Wire('METAL1', (82, 98), 100, 6, False),
                Wire('METAL1', (100, 100), 100, 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('POLY', (100, 120), 100, 4, False),
                Device('nmos', 122, 34, 4, 24, 'vertical', source_net='_net10', drain_net='_net1'),
                Wire('POLY', 122, (52, 144), 4, False),
                Device('pmos', 122, 170, 4, 40, 'vertical', source_net='_net6', drain_net='_net0'),
            ],
            'i2': [
                Device('nmos', 58, 34, 4, 24, 'vertical', source_net='_net1', drain_net='_net9'),
                Wire('POLY', 58, (52, 144), 4, False),
                Device('pmos', 58, 170, 4, 40, 'vertical', source_net='_net0', drain_net='_net8'),
                Wire('METAL1', 60, (86, 98), 6, False),
                Wire('METAL1', (60, 60), 100, 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 240, 40, 2),
                Wire('METAL1', 240, (40, 60), 6, True),
                Via('NDIF', 'METAL1', 240, 60, 2),
                Wire('METAL1', 240, (64, 160), 6, True),
                Via('PDIF', 'METAL1', 240, 120, 2),
                Via('PDIF', 'METAL1', 240, 140, 2),
                Via('PDIF', 'METAL1', 240, 160, 2),
                Wire('NDIF', 244, (34, 66), 8, False),
                Wire('PDIF', 244, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 20, (114, 158), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 156, 160, 2),
                Wire('METAL1', 156, (160, 180), 8, False),
                Wire('PDIF', 156, (154, 186), 8, False),
                Wire('PDIF', 220, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 222, 160, 2),
                Wire('METAL1', 222, (160, 180), 8, False),
            ],
            'vss': [
                Wire('METAL1', 20, (18, 38), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('NDIF', 20, (38, 70), 12, False),
                Wire('METAL1', 156, (16, 30), 8, False),
                Wire('NDIF', 156, (18, 34), 8, False),
                Via('NDIF', 'METAL1', 156, 30, 2),
                Via('NDIF', 'METAL1', 218, 16, 2),
                Wire('NDIF', 218, (22, 66), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='mx3_x4', width=280, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 64, (154, 186), 8, False),
            ],
            '_net3': [
                Wire('NDIF', 64, (26, 42), 8, False),
            ],
            '_net5': [
                Wire('NDIF', 40, (26, 42), 8, False),
                Via('NDIF', 'METAL1', 44, 40, 2),
                Wire('METAL1', (42, 126), 40, 6, False),
                Via('NDIF', 'METAL1', 128, 40, 2),
                Wire('NDIF', 130, (18, 42), 8, False),
            ],
            '_net6': [
                Via('NDIF', 'METAL1', 40, 64, 2),
                Wire('NDIF', 40, (62, 70), 12, False),
                Wire('METAL1', 40, (66, 118), 6, False),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Wire('PDIF', 40, (114, 134), 12, False),
                Wire('METAL1', (42, 66), 60, 6, False),
                Via('POLY', 'METAL1', 66, 60, 2),
                Wire('POLY', (66, 70), 60, 8, False),
                Wire('METAL1', (42, 94), 120, 6, False),
                Device('nmos', 70, 34, 4, 24, 'vertical', source_net='_net3', drain_net='_net9'),
                Wire('POLY', 70, (52, 60), 4, False),
                Via('POLY', 'METAL1', 96, 120, 2),
                Wire('POLY', 100, (118, 144), 4, False),
                Device('pmos', 100, 170, 4, 40, 'vertical', source_net='_net9', drain_net='_net4'),
            ],
            '_net7': [
                Wire('POLY', (130, 132), 60, 4, False),
                Via('POLY', 'METAL1', 132, 60, 2),
                Wire('POLY', 136, (58, 140), 4, False),
                Wire('POLY', (136, 140), 142, 4, False),
                Wire('POLY', 140, (142, 148), 4, False),
                Device('pmos', 140, 170, 4, 40, 'vertical', source_net='_net8', drain_net='vdd'),
                Device('nmos', 162, 26, 4, 24, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 162, (44, 60), 4, False),
                Wire('METAL1', (134, 194), 60, 6, False),
                Via('POLY', 'METAL1', 164, 60, 2),
                Wire('PDIF', 194, (114, 134), 8, False),
                Via('NDIF', 'METAL1', 196, 64, 2),
                Wire('METAL1', 196, (62, 120), 6, False),
                Via('PDIF', 'METAL1', 196, 120, 2),
            ],
            '_net8': [
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('PDIF', 40, (154, 186), 12, False),
                Wire('METAL1', (42, 126), 160, 6, False),
                Via('PDIF', 'METAL1', 128, 160, 2),
                Wire('PDIF', 128, (154, 186), 8, False),
            ],
            '_net9': [
                Wire('NDIF', 84, (26, 62), 8, False),
                Via('NDIF', 'METAL1', 84, 60, 2),
                Via('PDIF', 'METAL1', 86, 140, 2),
                Wire('PDIF', 86, (142, 186), 12, False),
                Wire('METAL1', (90, 106), 60, 6, False),
                Wire('METAL1', 108, (62, 78), 6, False),
                Wire('METAL1', (110, 118), 80, 6, False),
                Wire('METAL1', 120, (82, 138), 6, False),
                Wire('METAL1', (90, 218), 140, 6, False),
                Wire('METAL1', 192, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 192, 160, 2),
                Wire('PDIF', 192, (154, 186), 12, False),
                Wire('NDIF', 194, (18, 40), 8, False),
                Via('NDIF', 'METAL1', 196, 40, 2),
                Wire('METAL1', (194, 218), 40, 6, False),
                Via('POLY', 'METAL1', 220, 80, 2),
                Wire('METAL1', 220, (42, 138), 6, False),
                Wire('METAL1', (222, 222), 80, 6, False),
                Device('nmos', 232, 50, 4, 40, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 232, (76, 104), 4, False),
                Device('pmos', 232, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (224, 252), 80, 8, False),
                Device('nmos', 252, 50, 4, 40, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 252, (76, 104), 4, False),
                Device('pmos', 252, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'cmd0': [
                Wire('METAL1', 140, (80, 118), 6, True),
                Device('nmos', 144, 26, 4, 24, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 144, (40, 46), 4, False),
                Wire('POLY', (144, 148), 46, 4, False),
                Wire('POLY', 148, (48, 76), 4, False),
                Wire('METAL1', (142, 154), 100, 12, False),
                Wire('POLY', (148, 156), 76, 4, False),
                Via('POLY', 'METAL1', 152, 100, 2),
                Wire('POLY', 156, (76, 140), 4, False),
                Wire('POLY', (156, 164), 142, 4, False),
                Wire('POLY', 164, (142, 148), 4, False),
                Device('pmos', 164, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
                Wire('POLY', (156, 204), 100, 4, False),
                Device('nmos', 204, 64, 4, 12, 'vertical', source_net='_net7', drain_net='vss'),
                Wire('POLY', 204, (76, 104), 4, False),
                Device('pmos', 204, 124, 4, 28, 'vertical', source_net='_net7', drain_net='vdd'),
            ],
            'cmd1': [
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('METAL1', 20, (62, 140), 6, True),
                Wire('POLY', (16, 28), 100, 8, False),
                Device('nmos', 32, 66, 4, 16, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 32, (80, 104), 4, False),
                Device('pmos', 32, 124, 4, 28, 'vertical', source_net='vdd', drain_net='_net6'),
                Wire('METAL1', (22, 66), 140, 6, False),
                Via('POLY', 'METAL1', 68, 140, 2),
                Wire('POLY', (68, 70), 140, 8, False),
                Wire('POLY', 72, (80, 144), 4, False),
                Device('pmos', 72, 170, 4, 40, 'vertical', source_net='_net0', drain_net='_net9'),
                Wire('POLY', (74, 98), 80, 4, False),
                Device('nmos', 98, 34, 4, 24, 'vertical', source_net='_net9', drain_net='_net10'),
                Wire('POLY', 98, (52, 78), 4, False),
            ],
            'i0': [
                Wire('METAL1', (160, 160), 80, 6, True),
                Wire('METAL1', (160, 160), 120, 6, True),
                Wire('METAL1', (162, 170), 80, 6, False),
                Wire('METAL1', (162, 170), 120, 6, False),
                Via('POLY', 'METAL1', 172, 80, 2),
                Wire('METAL1', 172, (82, 118), 6, False),
                Via('POLY', 'METAL1', 172, 120, 2),
                Wire('METAL1', (174, 178), 100, 6, False),
                Wire('POLY', (172, 180), 124, 4, False),
                Wire('POLY', (174, 180), 76, 4, False),
                Device('nmos', 180, 26, 4, 24, 'vertical', source_net='_net1', drain_net='_net9'),
                Wire('POLY', 180, (40, 76), 4, False),
                Wire('METAL1', (180, 180), 100, 6, True),
                Wire('POLY', 182, (124, 146), 4, False),
                Device('pmos', 182, 170, 4, 40, 'vertical', source_net='_net2', drain_net='_net9'),
            ],
            'i1': [
                Wire('METAL1', (82, 98), 100, 6, False),
                Wire('METAL1', (100, 100), 100, 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('POLY', (98, 116), 100, 8, False),
                Device('nmos', 116, 34, 4, 24, 'vertical', source_net='_net10', drain_net='_net5'),
                Wire('POLY', 116, (52, 140), 4, False),
                Wire('POLY', (116, 120), 142, 4, False),
                Wire('POLY', 120, (142, 146), 4, False),
                Device('pmos', 120, 170, 4, 40, 'vertical', source_net='_net4', drain_net='_net8'),
            ],
            'i2': [
                Device('nmos', 52, 34, 4, 24, 'vertical', source_net='_net5', drain_net='_net3'),
                Wire('POLY', 52, (52, 144), 4, False),
                Device('pmos', 52, 170, 4, 40, 'vertical', source_net='_net8', drain_net='_net0'),
                Wire('POLY', 54, (96, 104), 6, False),
                Wire('POLY', (52, 60), 100, 8, False),
                Wire('METAL1', 60, (86, 98), 6, False),
                Wire('METAL1', (60, 60), 100, 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 240, 40, 2),
                Wire('NDIF', 240, (34, 66), 8, False),
                Wire('METAL1', 240, (42, 60), 6, True),
                Via('NDIF', 'METAL1', 240, 60, 2),
                Via('PDIF', 'METAL1', 240, 120, 2),
                Wire('METAL1', 240, (100, 160), 6, True),
                Via('PDIF', 'METAL1', 240, 140, 2),
                Wire('PDIF', 240, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 240, 160, 2),
                Wire('METAL1', (240, 244), 100, 6, False),
                Wire('METAL1', 244, (60, 100), 6, False),
                Wire('METAL1', (246, 258), 80, 6, False),
                Wire('METAL1', (260, 260), 80, 6, True),
            ],
            'vdd': [
                Wire('PDIF', 16, (114, 158), 12, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', 16, (162, 182), 6, False),
                Wire('PDIF', 152, (154, 186), 8, False),
                Via('PDIF', 'METAL1', 152, 184, 2),
                Wire('PDIF', 218, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 222, 160, 2),
                Wire('METAL1', 222, (160, 176), 8, False),
                Via('PDIF', 'METAL1', 260, 120, 2),
                Via('PDIF', 'METAL1', 260, 140, 2),
                Wire('METAL1', 260, (122, 182), 8, False),
                Via('PDIF', 'METAL1', 260, 160, 2),
                Via('PDIF', 'METAL1', 260, 184, 2),
                Wire('PDIF', 264, (114, 186), 8, False),
            ],
            'vss': [
                Wire('METAL1', 16, (18, 38), 6, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('NDIF', 16, (38, 70), 12, False),
                Wire('NDIF', 152, (18, 34), 8, False),
                Wire('METAL1', 154, (26, 32), 8, False),
                Via('NDIF', 'METAL1', 154, 32, 2),
                Via('NDIF', 'METAL1', 218, 16, 2),
                Wire('NDIF', 218, (22, 66), 8, False),
                Via('PTIE', 'METAL1', 240, 14, 2),
                Wire('PTIE', (234, 258), 14, 12, False),
                Wire('METAL1', 260, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 260, 40, 2),
                Via('NDIF', 'METAL1', 260, 60, 2),
                Wire('NDIF', 264, (34, 66), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na2_x1', width=80, height=200,
        nets={
            'i0': [
                Wire('METAL1', 20, (62, 138), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('POLY', (20, 28), 100, 4, False),
                Wire('POLY', 26, (96, 104), 6, False),
                Device('nmos', 28, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 28, (76, 130), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'i1': [
                Device('nmos', 46, 50, 4, 40, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', 46, (74, 78), 4, False),
                Wire('POLY', 52, (80, 124), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (46, 60), 78, 4, False),
                Wire('POLY', (52, 60), 82, 8, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
            ],
            'nq': [
                Wire('METAL1', 40, (40, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (42, 54), 40, 6, False),
                Via('NDIF', 'METAL1', 56, 40, 2),
                Wire('NDIF', 56, (34, 66), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (160, 174), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', 60, (160, 174), 8, False),
                Wire('PDIF', 64, (134, 166), 8, False),
            ],
            'vss': [
                Wire('NDIF', 16, (34, 66), 8, False),
                Wire('METAL1', 20, (26, 40), 8, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('PTIE', (46, 64), 14, 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na2_x4', width=140, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 36, (34, 66), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 14, (34, 66), 8, False),
                Via('NDIF', 'METAL1', 18, 40, 2),
                Wire('PDIF', 36, (134, 166), 8, False),
                Wire('METAL1', (18, 58), 40, 6, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', 60, (42, 158), 6, False),
                Wire('METAL1', (40, 118), 160, 6, False),
                Device('nmos', 114, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 114, (56, 104), 4, False),
                Device('pmos', 114, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
                Wire('POLY', 114, (154, 158), 4, False),
                Via('POLY', 'METAL1', 116, 160, 2),
            ],
            '_net2': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (74, 98), 80, 8, False),
                Device('nmos', 90, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 90, (56, 104), 4, False),
                Device('pmos', 90, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Via('POLY', 'METAL1', 102, 80, 2),
                Wire('METAL1', (102, 122), 80, 6, False),
                Via('NDIF', 'METAL1', 122, 40, 2),
                Wire('METAL1', 122, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 122, 120, 2),
                Via('PDIF', 'METAL1', 122, 140, 2),
                Wire('PDIF', 124, (114, 146), 12, False),
                Wire('NDIF', 126, (34, 46), 8, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Device('nmos', 26, 50, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 26, (76, 120), 4, False),
                Wire('POLY', (26, 30), 122, 4, False),
                Wire('POLY', 30, (122, 128), 4, False),
                Device('pmos', 30, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Device('nmos', 44, 50, 4, 40, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 44, (74, 86), 4, False),
                Wire('POLY', (44, 48), 88, 4, False),
                Wire('POLY', 48, (88, 124), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'nq': [
                Wire('NDIF', 80, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (42, 140), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (162, 178), 6, False),
                Wire('PDIF', 62, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 64, 182, 2),
                Via('PDIF', 'METAL1', 98, 182, 2),
                Wire('PDIF', 100, (114, 186), 8, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 16, 14, 2),
                Wire('PTIE', (16, 40), 14, 12, False),
                Via('PTIE', 'METAL1', 36, 14, 2),
                Wire('NDIF', 58, (16, 66), 8, False),
                Via('NDIF', 'METAL1', 62, 18, 2),
                Wire('METAL1', 98, (24, 36), 8, False),
                Via('NDIF', 'METAL1', 98, 38, 2),
                Wire('NDIF', 100, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na3_x1', width=100, height=200,
        nets={
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 138), 6, True),
                Wire('POLY', 26, (76, 84), 6, False),
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 28, (56, 124), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Device('nmos', 46, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', 46, (56, 82), 4, False),
                Wire('POLY', (46, 52), 82, 4, False),
                Wire('POLY', 52, (84, 124), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'i2': [
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('METAL1', 60, (42, 118), 6, True),
                Device('nmos', 64, 31, 4, 38, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', 64, (54, 62), 4, False),
                Wire('POLY', (58, 72), 64, 4, False),
                Wire('POLY', 72, (64, 124), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'nq': [
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (134, 166), 12, False),
                Wire('METAL1', (42, 80), 140, 6, False),
                Wire('NDIF', 76, (34, 46), 20, False),
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 86, (134, 166), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (160, 178), 8, False),
                Via('PDIF', 'METAL1', 62, 160, 2),
                Wire('METAL1', 62, (160, 180), 8, False),
                Wire('PDIF', 64, (134, 166), 8, False),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 20, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na3_x4', width=160, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 10, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('NDIF', 14, (34, 66), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (18, 78), 40, 6, False),
                Wire('PDIF', 60, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (14, 138), 160, 6, False),
                Wire('METAL1', 80, (42, 158), 6, False),
                Device('nmos', 136, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 136, (56, 104), 4, False),
                Device('pmos', 136, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
                Wire('POLY', 136, (152, 160), 4, False),
                Via('POLY', 'METAL1', 136, 160, 2),
            ],
            '_net3': [
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (92, 118), 80, 8, False),
                Device('nmos', 114, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 114, (56, 104), 4, False),
                Device('pmos', 114, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', (122, 142), 80, 6, False),
                Via('NDIF', 'METAL1', 144, 40, 2),
                Wire('METAL1', 144, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 144, 120, 2),
                Via('PDIF', 'METAL1', 144, 140, 2),
                Wire('NDIF', 146, (34, 46), 8, False),
                Wire('PDIF', 146, (114, 146), 8, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', 20, (118, 124), 4, False),
                Device('pmos', 20, 146, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (20, 24), 80, 8, False),
                Wire('POLY', (20, 24), 118, 4, False),
                Device('nmos', 24, 50, 4, 40, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 24, (76, 116), 4, False),
            ],
            'i1': [
                Device('nmos', 60, 50, 4, 40, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 60, (72, 78), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
                Wire('POLY', (58, 70), 84, 4, False),
                Wire('POLY', 70, (84, 120), 4, False),
                Device('pmos', 70, 146, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
            ],
            'i2': [
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 42, 50, 4, 40, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 42, (76, 104), 4, False),
                Wire('POLY', (44, 52), 104, 4, False),
                Wire('POLY', 52, (104, 122), 4, False),
                Device('pmos', 52, 146, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'nq': [
                Wire('NDIF', 100, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 140), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Wire('PDIF', 104, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (130, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Via('PDIF', 'METAL1', 80, 184, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
                Wire('PDIF', 124, (114, 180), 4, False),
                Via('PDIF', 'METAL1', 124, 184, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 18, 14, 2),
                Via('PTIE', 'METAL1', 34, 14, 2),
                Wire('PTIE', (20, 56), 14, 12, False),
                Via('PTIE', 'METAL1', 50, 14, 2),
                Wire('NDIF', 74, (16, 66), 8, False),
                Via('NDIF', 'METAL1', 78, 18, 2),
                Wire('NDIF', 78, (16, 66), 8, False),
                Wire('NDIF', 122, (16, 46), 8, False),
                Wire('METAL1', 124, (26, 38), 8, False),
                Via('NDIF', 'METAL1', 124, 38, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na4_x1', width=120, height=200,
        nets={
            'i0': [
                Via('POLY', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (42, 138), 6, True),
                Wire('POLY', (20, 28), 60, 8, False),
                Wire('POLY', 26, (56, 64), 6, False),
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 28, (56, 124), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (42, 138), 6, True),
                Device('nmos', 46, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', 46, (56, 124), 4, False),
                Device('pmos', 46, 150, 4, 40, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'i2': [
                Wire('METAL1', 60, (42, 138), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Device('nmos', 64, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', 64, (56, 100), 4, False),
                Wire('POLY', (58, 72), 102, 4, False),
                Wire('POLY', 74, (102, 124), 4, False),
                Device('pmos', 74, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'i3': [
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (42, 138), 6, True),
                Device('nmos', 82, 31, 4, 38, 'vertical', source_net='_net2', drain_net='nq'),
                Wire('POLY', 82, (56, 76), 4, False),
                Wire('POLY', (78, 92), 84, 4, False),
                Wire('POLY', 92, (84, 124), 4, False),
                Device('pmos', 92, 150, 4, 40, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'nq': [
                Wire('PDIF', 36, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 38, 160, 2),
                Wire('METAL1', (38, 100), 160, 6, False),
                Wire('PDIF', 84, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('NDIF', 100, (34, 46), 16, False),
                Wire('METAL1', 100, (42, 158), 6, True),
            ],
            'vdd': [
                Wire('PDIF', 14, (134, 166), 8, False),
                Wire('METAL1', 18, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 60, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 60, 186, 2),
                Wire('PDIF', 106, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 106, 186, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 20, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='na4_x4', width=200, height=200,
        nets={
            '_net2': [
                Wire('PDIF', 14, (114, 146), 8, False),
                Wire('METAL1', 16, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Wire('METAL1', 16, (122, 138), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', (18, 22), 80, 8, False),
                Wire('METAL1', (18, 24), 40, 6, False),
                Wire('NDIF', 22, (34, 46), 8, False),
                Via('POLY', 'METAL1', 22, 80, 2),
                Via('NDIF', 'METAL1', 24, 40, 2),
                Wire('POLY', (24, 72), 80, 8, False),
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (48, 52), 102, 4, False),
                Device('nmos', 52, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 52, (56, 100), 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net3': [
                Wire('POLY', 24, (102, 106), 4, False),
                Device('pmos', 24, 130, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (24, 32), 100, 8, False),
                Via('POLY', 'METAL1', 32, 60, 2),
                Device('nmos', 34, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 34, (54, 58), 4, False),
                Wire('METAL1', (32, 38), 60, 8, False),
                Wire('METAL1', (32, 38), 100, 8, False),
                Via('POLY', 'METAL1', 36, 100, 2),
                Wire('METAL1', 40, (60, 160), 6, False),
                Wire('METAL1', (44, 180), 160, 6, False),
                Wire('PDIF', 116, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 118, 160, 2),
                Wire('PDIF', 164, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 164, 160, 2),
                Wire('NDIF', 172, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 180, (34, 46), 8, False),
                Wire('METAL1', 180, (42, 158), 6, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 100, 60, 2),
                Wire('METAL1', 100, (42, 138), 6, True),
                Device('nmos', 104, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 104, (56, 62), 4, False),
                Wire('POLY', 106, (62, 124), 4, False),
                Device('pmos', 106, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (42, 138), 6, True),
                Device('nmos', 122, 31, 4, 38, 'vertical', source_net='_net4', drain_net='_net1'),
                Wire('POLY', 122, (56, 120), 4, False),
                Wire('POLY', (122, 126), 122, 4, False),
                Wire('POLY', 126, (122, 128), 4, False),
                Device('pmos', 126, 150, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
            ],
            'i2': [
                Device('nmos', 140, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 140, (56, 104), 4, False),
                Wire('METAL1', 140, (42, 138), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Wire('POLY', (138, 152), 104, 4, False),
                Wire('POLY', 154, (104, 124), 4, False),
                Device('pmos', 154, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i3': [
                Device('nmos', 158, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net3'),
                Wire('POLY', 158, (56, 76), 4, False),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (42, 138), 6, True),
                Wire('POLY', (158, 172), 82, 4, False),
                Wire('POLY', 172, (84, 124), 4, False),
                Device('pmos', 172, 150, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
            ],
            'nq': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 138), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('NTIE', 18, (164, 184), 12, False),
                Via('NTIE', 'METAL1', 18, 182, 2),
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
                Wire('PDIF', 92, (134, 186), 8, False),
                Wire('PDIF', 140, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 140, 188, 2),
                Wire('PDIF', 186, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 186, 188, 2),
            ],
            'vss': [
                Wire('NDIF', 40, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 42, 18, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 88, 18, 2),
                Wire('NDIF', 92, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nao22_x1', width=120, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (18, 58), 40, 6, False),
                Wire('NDIF', 62, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
            ],
            '_net1': [
                Wire('PDIF', 36, (114, 186), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 158), 6, True),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 54), 80, 8, False),
                Wire('POLY', 52, (102, 108), 4, False),
                Device('pmos', 52, 150, 4, 80, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', (52, 56), 102, 4, False),
                Device('nmos', 56, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net0'),
                Wire('POLY', 56, (56, 100), 4, False),
            ],
            'i2': [
                Device('nmos', 74, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 74, (56, 104), 4, False),
                Device('pmos', 74, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (74, 80), 80, 8, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
            ],
            'nq': [
                Wire('NDIF', 40, (16, 62), 12, False),
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('METAL1', (38, 60), 60, 6, False),
                Wire('METAL1', 60, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Via('PDIF', 'METAL1', 82, 184, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('NTIE', 'METAL1', 104, 116, 2),
                Wire('NTIE', 104, (110, 134), 12, False),
                Wire('METAL1', 104, (118, 178), 6, False),
                Wire('NTIE', 104, (164, 184), 12, False),
                Via('NTIE', 'METAL1', 104, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 82, 18, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 104, 18, 2),
                Wire('PTIE', 104, (18, 34), 12, False),
                Wire('METAL1', 104, (22, 66), 6, False),
                Wire('PTIE', 104, (48, 70), 12, False),
                Via('PTIE', 'METAL1', 104, 68, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nao22_x4', width=200, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 64, (134, 166), 8, False),
            ],
            '_net1': [
                Wire('METAL1', 40, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (42, 62), 60, 6, False),
                Wire('NDIF', 64, (34, 62), 12, False),
                Via('NDIF', 'METAL1', 64, 60, 2),
                Wire('METAL1', (46, 110), 160, 6, False),
                Wire('METAL1', 112, (142, 158), 6, False),
                Wire('METAL1', (114, 130), 140, 6, False),
                Device('nmos', 124, 40, 4, 20, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 124, (56, 104), 4, False),
                Device('pmos', 124, 130, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (124, 132), 100, 8, False),
                Wire('METAL1', 132, (102, 138), 6, False),
                Via('POLY', 'METAL1', 136, 100, 2),
            ],
            '_net2': [
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (34, 46), 12, False),
                Wire('METAL1', (42, 86), 40, 6, False),
                Via('NDIF', 'METAL1', 88, 40, 2),
                Wire('NDIF', 88, (34, 46), 12, False),
            ],
            '_net3': [
                Via('NDIF', 'METAL1', 112, 40, 2),
                Wire('NDIF', 112, (34, 46), 12, False),
                Wire('METAL1', 112, (82, 118), 6, False),
                Via('PDIF', 'METAL1', 112, 120, 2),
                Wire('PDIF', 112, (114, 146), 12, False),
                Wire('METAL1', (114, 138), 40, 6, False),
                Wire('METAL1', (114, 138), 80, 6, False),
                Via('POLY', 'METAL1', 136, 80, 2),
                Wire('METAL1', 140, (42, 78), 6, False),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 148, (56, 100), 4, False),
                Wire('POLY', (148, 152), 102, 4, False),
                Wire('POLY', 152, (102, 108), 4, False),
                Device('pmos', 152, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (140, 172), 80, 8, False),
                Device('nmos', 172, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 172, (56, 104), 4, False),
                Device('pmos', 172, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'i0': [
                Wire('POLY', 72, (122, 128), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (72, 80), 122, 4, False),
                Device('nmos', 80, 40, 4, 20, 'vertical', source_net='_net1', drain_net='_net2'),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (56, 120), 4, False),
                Wire('METAL1', 80, (82, 138), 6, True),
            ],
            'i1': [
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 48, (56, 118), 4, False),
                Wire('POLY', (48, 52), 122, 4, False),
                Wire('POLY', 52, (122, 128), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (52, 60), 80, 8, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 138), 6, True),
            ],
            'i2': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Wire('POLY', (20, 28), 80, 8, False),
                Wire('POLY', 26, (76, 84), 6, False),
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 28, (56, 120), 4, False),
                Wire('POLY', (28, 32), 122, 4, False),
                Wire('POLY', 32, (122, 128), 4, False),
                Device('pmos', 32, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'nq': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Wire('PDIF', 88, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 88, 184, 2),
                Wire('NTIE', 112, (166, 188), 12, False),
                Via('NTIE', 'METAL1', 112, 182, 2),
                Wire('PDIF', 138, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 142, 160, 2),
                Wire('METAL1', 144, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 144, 184, 2),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Wire('PDIF', 184, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 14, 16, 2),
                Wire('NDIF', 14, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 100, 16, 2),
                Wire('NDIF', 138, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 140, 18, 2),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('METAL1', 180, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 184, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nao2o22_x1', width=140, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 36, (114, 186), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', (16, 106), 40, 6, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
                Wire('NDIF', 108, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 108, 40, 2),
            ],
            '_net2': [
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 158), 6, True),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
                Wire('POLY', (40, 56), 80, 8, False),
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', (48, 54), 102, 4, False),
                Device('nmos', 56, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net1'),
                Wire('POLY', 56, (56, 102), 4, False),
            ],
            'i2': [
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 158), 6, True),
            ],
            'i3': [
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net2'),
                Wire('POLY', (72, 74), 102, 4, False),
                Device('nmos', 74, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 74, (56, 100), 4, False),
                Wire('POLY', (74, 80), 80, 8, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 158), 6, True),
            ],
            'nq': [
                Wire('NDIF', 40, (16, 62), 12, False),
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('METAL1', (38, 60), 60, 6, False),
                Wire('METAL1', 60, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Wire('PDIF', 104, (114, 146), 12, False),
                Wire('PDIF', 108, (150, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 184, 2),
                Via('NTIE', 'METAL1', 124, 116, 2),
                Wire('NTIE', 124, (110, 134), 12, False),
                Wire('METAL1', 124, (118, 178), 6, False),
            ],
            'vss': [
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 86, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nao2o22_x4', width=220, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', (18, 106), 40, 6, False),
                Via('NDIF', 'METAL1', 62, 40, 2),
                Via('NDIF', 'METAL1', 108, 40, 2),
                Wire('NDIF', 108, (34, 46), 12, False),
            ],
            '_net1': [
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('NDIF', 132, (34, 46), 12, False),
                Wire('METAL1', 132, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 132, 120, 2),
                Wire('PDIF', 132, (114, 146), 12, False),
                Wire('METAL1', (134, 158), 80, 6, False),
                Via('POLY', 'METAL1', 156, 80, 2),
                Device('nmos', 168, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 168, (56, 104), 4, False),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (160, 192), 80, 8, False),
                Device('nmos', 192, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 192, (56, 104), 4, False),
                Device('pmos', 192, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net2': [
                Wire('PDIF', 84, (134, 166), 8, False),
            ],
            '_net3': [
                Wire('PDIF', 36, (134, 166), 8, False),
            ],
            '_net4': [
                Wire('NDIF', 38, (34, 62), 12, False),
                Via('NDIF', 'METAL1', 38, 60, 2),
                Wire('METAL1', (38, 58), 60, 6, False),
                Wire('METAL1', 60, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (66, 130), 160, 6, False),
                Wire('METAL1', 132, (142, 158), 6, False),
                Wire('METAL1', (134, 150), 140, 6, False),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 130, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (144, 152), 100, 8, False),
                Wire('METAL1', 152, (102, 138), 6, False),
                Via('POLY', 'METAL1', 156, 100, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (82, 158), 6, True),
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net4'),
                Wire('POLY', 24, (56, 120), 4, False),
                Wire('POLY', (24, 28), 122, 4, False),
                Wire('POLY', 28, (122, 128), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (82, 160), 6, True),
                Wire('POLY', (44, 52), 80, 8, False),
                Wire('POLY', 48, (122, 128), 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net3', drain_net='_net4'),
                Wire('POLY', (48, 52), 122, 4, False),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='_net4', drain_net='_net0'),
                Wire('POLY', 52, (56, 120), 4, False),
            ],
            'i2': [
                Wire('POLY', 92, (122, 128), 4, False),
                Device('pmos', 92, 150, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (92, 98), 122, 4, False),
                Device('nmos', 98, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 98, (56, 120), 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 138), 6, True),
            ],
            'i3': [
                Device('nmos', 70, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 70, (56, 120), 4, False),
                Wire('POLY', (70, 72), 122, 4, False),
                Wire('POLY', 72, (122, 128), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net4', drain_net='_net2'),
                Wire('POLY', 74, (76, 84), 6, False),
                Wire('POLY', (72, 80), 80, 8, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 138), 6, True),
            ],
            'nq': [
                Wire('NDIF', 180, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('METAL1', 180, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 14, 184, 2),
                Wire('PDIF', 108, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 108, 186, 2),
                Wire('NTIE', 132, (170, 184), 12, False),
                Via('NTIE', 'METAL1', 132, 182, 2),
                Wire('PDIF', 158, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Wire('METAL1', 160, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 160, 184, 2),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('METAL1', 200, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Via('PDIF', 'METAL1', 200, 184, 2),
                Wire('PDIF', 204, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 84, 16, 2),
                Wire('NDIF', 84, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 120, 16, 2),
                Wire('NDIF', 158, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 160, 18, 2),
                Wire('METAL1', 160, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Via('NDIF', 'METAL1', 200, 18, 2),
                Wire('METAL1', 200, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 200, 40, 2),
                Wire('NDIF', 204, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nmx2_x1', width=140, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 58, (16, 46), 4, False),
            ],
            '_net1': [
                Wire('NDIF', 104, (16, 46), 8, False),
            ],
            '_net2': [
                Wire('PDIF', 104, (114, 186), 8, False),
            ],
            '_net3': [
                Wire('PDIF', 58, (114, 186), 4, False),
            ],
            'cmd': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 24, (56, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (24, 92), 80, 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 138), 6, True),
                Wire('POLY', 64, (80, 100), 4, False),
                Wire('POLY', (64, 68), 102, 4, False),
                Wire('POLY', 68, (102, 108), 4, False),
                Device('pmos', 68, 150, 4, 80, 'vertical', source_net='_net3', drain_net='nq'),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net1'),
                Wire('POLY', 92, (56, 80), 4, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', (38, 48), 104, 4, False),
                Wire('POLY', (40, 48), 56, 4, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 48, (50, 56), 4, False),
                Wire('POLY', 48, (104, 110), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i1': [
                Device('nmos', 116, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 116, (54, 62), 4, False),
                Wire('POLY', 116, (98, 106), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
                Via('POLY', 'METAL1', 120, 60, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
            ],
            'nq': [
                Wire('NDIF', 80, (16, 46), 20, False),
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (42, 138), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (114, 186), 20, False),
            ],
            'q': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 60), 40, 6, False),
                Wire('METAL1', (18, 98), 160, 6, False),
                Wire('METAL1', 60, (42, 58), 6, False),
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('POLY', (60, 68), 56, 4, False),
                Device('nmos', 68, 31, 4, 38, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', 68, (52, 56), 4, False),
                Wire('POLY', 92, (106, 108), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net2'),
                Wire('POLY', (92, 102), 104, 4, False),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('METAL1', 100, (102, 158), 6, False),
            ],
            'vdd': [
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Via('PDIF', 'METAL1', 124, 184, 2),
                Wire('PDIF', 126, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 124, 18, 2),
                Wire('NDIF', 126, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nmx2_x4', width=240, height=200,
        nets={
            '_net1': [
                Wire('NDIF', 148, (16, 42), 12, False),
                Via('NDIF', 'METAL1', 148, 40, 2),
                Wire('METAL1', 148, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 148, 136, 2),
                Wire('PDIF', 148, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 148, 160, 2),
                Via('POLY', 'METAL1', 152, 100, 2),
                Wire('POLY', (152, 212), 100, 4, False),
                Device('nmos', 188, 30, 4, 40, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 188, (56, 104), 4, False),
                Device('pmos', 188, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 212, 30, 4, 40, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 212, (56, 104), 4, False),
                Device('pmos', 212, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net2': [
                Wire('NDIF', 80, (18, 26), 20, False),
                Wire('NDIF', 80, (16, 62), 12, False),
                Via('NDIF', 'METAL1', 80, 60, 2),
                Via('POLY', 'METAL1', 80, 96, 2),
                Wire('METAL1', 80, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (134, 166), 20, False),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('POLY', (78, 136), 92, 4, False),
                Device('nmos', 132, 21, 4, 18, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 132, (32, 38), 4, False),
                Wire('POLY', (132, 136), 38, 4, False),
                Wire('POLY', 136, (40, 120), 4, False),
                Wire('POLY', (136, 140), 122, 4, False),
                Wire('POLY', 140, (122, 128), 4, False),
                Device('pmos', 140, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            '_net5': [
                Wire('NDIF', 12, (16, 42), 12, False),
                Via('NDIF', 'METAL1', 12, 40, 2),
                Wire('METAL1', 12, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 12, 140, 2),
                Wire('PDIF', 12, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('METAL1', (14, 98), 40, 6, False),
                Device('nmos', 64, 21, 4, 18, 'vertical', source_net='_net4', drain_net='_net2'),
                Wire('POLY', 64, (34, 38), 4, False),
                Via('POLY', 'METAL1', 64, 40, 2),
                Wire('POLY', 94, (106, 124), 4, False),
                Device('pmos', 94, 150, 4, 40, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('METAL1', 100, (42, 106), 6, False),
                Via('POLY', 'METAL1', 100, 108, 2),
            ],
            'cmd': [
                Wire('POLY', 26, (40, 124), 4, False),
                Device('pmos', 26, 150, 4, 40, 'vertical', source_net='_net5', drain_net='vdd'),
                Wire('POLY', (26, 28), 38, 4, False),
                Device('nmos', 28, 21, 4, 18, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 28, (32, 38), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 158), 6, True),
                Wire('POLY', (26, 96), 80, 4, False),
                Wire('POLY', 66, (80, 120), 4, False),
                Wire('POLY', (66, 72), 122, 4, False),
                Wire('POLY', 72, (122, 128), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net2', drain_net='_net2'),
                Device('nmos', 96, 21, 4, 18, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('POLY', 96, (36, 80), 4, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (62, 158), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
                Wire('POLY', (38, 46), 56, 4, False),
                Device('nmos', 46, 21, 4, 18, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 46, (36, 56), 4, False),
                Wire('POLY', (38, 54), 122, 4, False),
                Wire('POLY', 54, (122, 128), 4, False),
                Device('pmos', 54, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            'i1': [
                Wire('POLY', 112, (124, 130), 4, False),
                Device('pmos', 112, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 114, 21, 4, 18, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 114, (36, 56), 4, False),
                Wire('POLY', (112, 122), 124, 4, False),
                Wire('POLY', (114, 122), 56, 4, False),
                Via('POLY', 'METAL1', 120, 60, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('POLY', 'METAL1', 120, 120, 2),
            ],
            'nq': [
                Wire('NDIF', 200, (14, 46), 12, False),
                Via('NDIF', 'METAL1', 200, 40, 2),
                Wire('METAL1', 200, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('PDIF', 200, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 40, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 40, 186, 2),
                Wire('PDIF', 126, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 126, 186, 2),
                Via('PDIF', 'METAL1', 176, 120, 2),
                Via('PDIF', 'METAL1', 176, 140, 2),
                Wire('METAL1', 176, (122, 178), 6, False),
                Wire('PDIF', 176, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 176, 160, 2),
                Via('PDIF', 'METAL1', 176, 182, 2),
                Via('PDIF', 'METAL1', 220, 120, 2),
                Via('PDIF', 'METAL1', 220, 140, 2),
                Wire('METAL1', 220, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 220, 160, 2),
                Via('PDIF', 'METAL1', 220, 184, 2),
                Wire('PDIF', 224, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 36, 18, 2),
                Wire('NDIF', 36, (16, 26), 12, False),
                Via('NDIF', 'METAL1', 124, 18, 2),
                Wire('NDIF', 124, (16, 26), 12, False),
                Via('NDIF', 'METAL1', 176, 18, 2),
                Wire('METAL1', 176, (22, 38), 6, False),
                Wire('NDIF', 176, (14, 46), 12, False),
                Via('NDIF', 'METAL1', 176, 40, 2),
                Via('NDIF', 'METAL1', 220, 16, 2),
                Wire('METAL1', 220, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Wire('NDIF', 224, (14, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nmx3_x1', width=240, height=200,
        nets={
            '_net1': [
                Wire('NDIF', 44, (30, 42), 12, False),
                Via('NDIF', 'METAL1', 44, 40, 2),
                Wire('METAL1', (46, 130), 40, 6, False),
                Via('NDIF', 'METAL1', 128, 40, 2),
                Wire('NDIF', 130, (26, 42), 8, False),
            ],
            '_net10': [
                Wire('METAL1', 40, (62, 118), 6, False),
                Via('NDIF', 'METAL1', 44, 64, 2),
                Wire('NDIF', 44, (62, 70), 12, False),
                Via('PDIF', 'METAL1', 44, 120, 2),
                Wire('PDIF', 44, (114, 134), 12, False),
                Wire('METAL1', (42, 70), 60, 6, False),
                Wire('METAL1', (42, 98), 120, 6, False),
                Via('POLY', 'METAL1', 72, 60, 2),
                Device('nmos', 74, 34, 4, 24, 'vertical', source_net='_net2', drain_net='nq'),
                Wire('POLY', 74, (52, 60), 4, False),
                Via('POLY', 'METAL1', 100, 120, 2),
                Wire('POLY', 104, (118, 142), 4, False),
                Wire('POLY', (104, 108), 142, 4, False),
                Wire('POLY', 108, (142, 148), 4, False),
                Device('pmos', 108, 170, 4, 40, 'vertical', source_net='nq', drain_net='_net5'),
            ],
            '_net3': [
                Via('PDIF', 'METAL1', 44, 160, 2),
                Wire('PDIF', 44, (154, 186), 12, False),
                Wire('METAL1', (46, 130), 160, 6, False),
                Via('PDIF', 'METAL1', 136, 160, 2),
            ],
            '_net4': [
                Via('POLY', 'METAL1', 136, 60, 2),
                Wire('POLY', 140, (60, 140), 4, False),
                Wire('POLY', (140, 148), 142, 4, False),
                Wire('POLY', 148, (142, 148), 4, False),
                Device('pmos', 148, 170, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Device('nmos', 162, 26, 4, 24, 'vertical', source_net='vss', drain_net='_net7'),
                Wire('POLY', 162, (44, 60), 4, False),
                Wire('METAL1', (138, 198), 60, 6, False),
                Via('POLY', 'METAL1', 168, 60, 2),
                Via('NDIF', 'METAL1', 196, 64, 2),
                Wire('NDIF', 196, (62, 70), 12, False),
                Wire('PDIF', 196, (114, 134), 12, False),
                Wire('METAL1', 200, (62, 118), 6, False),
                Via('PDIF', 'METAL1', 200, 118, 2),
            ],
            '_net6': [
                Device('nmos', 180, 26, 4, 24, 'vertical', source_net='_net7', drain_net='nq'),
                Wire('POLY', 180, (44, 80), 4, False),
                Via('POLY', 'METAL1', 180, 80, 2),
            ],
            '_net9': [
                Wire('PDIF', 68, (154, 186), 8, False),
            ],
            'cmd0': [
                Wire('METAL1', 140, (82, 120), 6, True),
                Device('nmos', 144, 26, 4, 24, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 144, (40, 46), 4, False),
                Wire('POLY', (144, 152), 46, 4, False),
                Wire('METAL1', (142, 154), 100, 6, False),
                Wire('POLY', 152, (48, 76), 4, False),
                Wire('POLY', (152, 160), 76, 4, False),
                Via('POLY', 'METAL1', 156, 100, 2),
                Wire('POLY', 160, (76, 140), 4, False),
                Wire('POLY', (160, 166), 142, 4, False),
                Wire('POLY', 166, (142, 148), 4, False),
                Device('pmos', 166, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net8'),
                Wire('POLY', (160, 206), 100, 4, False),
                Device('nmos', 204, 66, 4, 16, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 204, (80, 100), 4, False),
                Wire('POLY', 208, (100, 108), 4, False),
                Device('pmos', 208, 124, 4, 28, 'vertical', source_net='_net4', drain_net='vdd'),
            ],
            'cmd1': [
                Wire('METAL1', 20, (60, 140), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('POLY', (20, 32), 100, 8, False),
                Device('nmos', 36, 66, 4, 16, 'vertical', source_net='vss', drain_net='_net10'),
                Wire('POLY', 36, (80, 104), 4, False),
                Device('pmos', 36, 124, 4, 28, 'vertical', source_net='vdd', drain_net='_net10'),
                Wire('METAL1', (22, 70), 140, 6, False),
                Via('POLY', 'METAL1', 72, 140, 2),
                Wire('POLY', 76, (80, 140), 4, False),
                Wire('POLY', 76, (142, 148), 4, False),
                Device('pmos', 76, 170, 4, 40, 'vertical', source_net='_net9', drain_net='nq'),
                Wire('POLY', (80, 102), 80, 4, False),
                Device('nmos', 104, 34, 4, 24, 'vertical', source_net='nq', drain_net='_net0'),
                Wire('POLY', 104, (52, 80), 4, False),
            ],
            'i0': [
                Wire('POLY', 178, (120, 140), 4, False),
                Wire('METAL1', 180, (88, 120), 6, True),
                Wire('METAL1', 180, (100, 120), 8, True),
                Via('POLY', 'METAL1', 180, 120, 2),
                Wire('POLY', (178, 184), 142, 4, False),
                Wire('POLY', 184, (142, 148), 4, False),
                Device('pmos', 184, 170, 4, 40, 'vertical', source_net='_net8', drain_net='nq'),
            ],
            'i1': [
                Wire('METAL1', (82, 98), 100, 6, False),
                Wire('METAL1', (100, 100), 100, 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('POLY', (100, 120), 100, 4, False),
                Device('nmos', 120, 34, 4, 24, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', 120, (52, 140), 4, False),
                Wire('POLY', (120, 128), 142, 4, False),
                Wire('POLY', 128, (142, 148), 4, False),
                Device('pmos', 128, 170, 4, 40, 'vertical', source_net='_net5', drain_net='_net3'),
            ],
            'i2': [
                Wire('POLY', 56, (142, 148), 4, False),
                Device('pmos', 56, 170, 4, 40, 'vertical', source_net='_net3', drain_net='_net9'),
                Device('nmos', 58, 34, 4, 24, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', 58, (52, 94), 4, False),
                Wire('POLY', (56, 60), 142, 4, False),
                Wire('METAL1', 60, (86, 98), 6, False),
                Wire('METAL1', (60, 60), 100, 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 60, (102, 140), 4, False),
            ],
            'nq': [
                Wire('NDIF', 90, (26, 62), 12, False),
                Via('NDIF', 'METAL1', 90, 60, 2),
                Wire('METAL1', 92, (62, 78), 6, False),
                Via('PDIF', 'METAL1', 92, 140, 2),
                Wire('PDIF', 92, (142, 186), 12, False),
                Wire('METAL1', (94, 118), 80, 6, False),
                Wire('METAL1', 120, (82, 138), 6, False),
                Wire('METAL1', (94, 218), 140, 6, False),
                Wire('NDIF', 196, (18, 38), 12, False),
                Via('NDIF', 'METAL1', 196, 40, 2),
                Wire('METAL1', 196, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 196, 160, 2),
                Wire('PDIF', 196, (154, 186), 12, False),
                Wire('METAL1', (198, 218), 40, 6, False),
                Wire('METAL1', 220, (40, 140), 6, True),
            ],
            'vdd': [
                Wire('PDIF', 20, (114, 158), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (162, 182), 6, False),
                Wire('PDIF', 156, (154, 186), 8, False),
                Via('PDIF', 'METAL1', 156, 184, 2),
                Wire('PDIF', 222, (114, 158), 8, False),
                Via('PDIF', 'METAL1', 222, 160, 2),
                Wire('METAL1', 222, (162, 186), 6, False),
            ],
            'vss': [
                Wire('METAL1', 20, (18, 38), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('NDIF', 20, (42, 70), 12, False),
                Wire('METAL1', 154, (24, 32), 8, False),
                Via('NDIF', 'METAL1', 154, 32, 2),
                Wire('NDIF', 156, (18, 34), 8, False),
                Via('NDIF', 'METAL1', 220, 18, 2),
                Wire('NDIF', 220, (22, 70), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no2_x1', width=80, height=200,
        nets={
            'i0': [
                Device('nmos', 54, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 54, (56, 106), 4, False),
                Device('pmos', 54, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 34, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 34, (56, 104), 4, False),
                Device('pmos', 34, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('METAL1', 40, (62, 158), 6, True),
            ],
            'nq': [
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 28, (114, 166), 8, False),
                Wire('METAL1', (22, 44), 40, 6, False),
                Via('NDIF', 'METAL1', 42, 40, 2),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 64, 184, 2),
                Wire('PDIF', 66, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 16, 2),
                Wire('NDIF', 20, (22, 46), 8, False),
                Wire('METAL1', 64, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
                Wire('NDIF', 66, (34, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no2_x4', width=140, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 12, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Via('NDIF', 'METAL1', 38, 40, 2),
                Wire('METAL1', (38, 58), 40, 6, False),
                Wire('METAL1', 60, (42, 158), 6, False),
                Wire('METAL1', (14, 106), 160, 6, False),
                Via('POLY', 'METAL1', 104, 100, 2),
                Wire('METAL1', 108, (102, 158), 6, False),
                Wire('POLY', (104, 116), 100, 8, False),
                Device('nmos', 116, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 116, (56, 104), 4, False),
                Device('pmos', 116, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            '_net2': [
                Wire('POLY', 68, (82, 104), 4, False),
                Device('pmos', 68, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 76, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 76, (56, 78), 4, False),
                Wire('POLY', (68, 104), 80, 4, False),
                Wire('POLY', 92, (68, 80), 4, False),
                Wire('POLY', 92, (82, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (92, 94), 66, 4, False),
                Device('nmos', 94, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 94, (54, 66), 4, False),
                Via('POLY', 'METAL1', 104, 80, 2),
                Wire('METAL1', (102, 124), 80, 6, False),
                Via('NDIF', 'METAL1', 124, 40, 2),
                Wire('METAL1', 124, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 124, 120, 2),
                Wire('METAL1', 124, (122, 138), 6, False),
                Via('PDIF', 'METAL1', 124, 140, 2),
                Wire('NDIF', 126, (34, 46), 8, False),
                Wire('PDIF', 128, (114, 146), 8, False),
            ],
            'i0': [
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', 42, (102, 106), 4, False),
                Device('pmos', 42, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (38, 48), 96, 4, False),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 48, (56, 96), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', 24, (58, 106), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (28, 30), 58, 4, False),
                Device('nmos', 30, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 30, (48, 56), 4, False),
            ],
            'nq': [
                Wire('METAL1', 80, (42, 138), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (114, 186), 12, False),
                Wire('NDIF', 84, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
            ],
            'vdd': [
                Wire('PDIF', 52, (114, 186), 12, False),
                Wire('PDIF', 56, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 56, 182, 2),
                Via('PDIF', 'METAL1', 100, 182, 2),
                Wire('PDIF', 102, (114, 186), 8, False),
                Wire('NTIE', 124, (164, 184), 12, False),
                Via('NTIE', 'METAL1', 124, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 14, 16, 2),
                Wire('NDIF', 16, (16, 46), 8, False),
                Wire('METAL1', 20, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('NDIF', 64, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 66, 18, 2),
                Wire('NDIF', 102, (16, 46), 8, False),
                Wire('METAL1', 104, (24, 40), 8, False),
                Via('NDIF', 'METAL1', 104, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no3_x1', width=100, height=200,
        nets={
            'i0': [
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 52, (56, 76), 4, False),
                Wire('POLY', 56, (80, 104), 4, False),
                Device('pmos', 56, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (52, 62), 76, 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 28, (56, 96), 4, False),
                Wire('POLY', (28, 42), 98, 4, False),
                Wire('POLY', 38, (102, 106), 4, False),
                Device('pmos', 38, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
            ],
            'i2': [
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 72, (50, 54), 4, False),
                Wire('POLY', 74, (60, 104), 4, False),
                Device('pmos', 74, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (72, 82), 56, 4, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
            ],
            'nq': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 28, (114, 166), 8, False),
                Wire('METAL1', (20, 60), 60, 6, False),
                Via('NDIF', 'METAL1', 62, 40, 2),
                Wire('NDIF', 62, (34, 46), 12, False),
                Wire('METAL1', 62, (40, 60), 6, False),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 82, 184, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 38, (34, 46), 8, False),
                Wire('METAL1', 40, (24, 38), 6, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Via('NDIF', 'METAL1', 84, 16, 2),
                Wire('NDIF', 86, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no3_x4', width=160, height=200,
        nets={
            '_net1': [
                Wire('NDIF', 12, (34, 46), 8, False),
                Wire('PDIF', 12, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Via('NDIF', 'METAL1', 14, 40, 2),
                Wire('METAL1', (14, 76), 40, 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', (14, 126), 160, 6, False),
                Wire('METAL1', 76, (42, 158), 6, False),
                Via('POLY', 'METAL1', 124, 100, 2),
                Wire('METAL1', 128, (102, 158), 6, False),
                Wire('POLY', (124, 136), 100, 8, False),
                Device('nmos', 136, 40, 4, 20, 'vertical', source_net='_net3', drain_net='_net2'),
                Wire('POLY', 136, (56, 104), 4, False),
                Device('pmos', 136, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            '_net2': [
                Wire('POLY', 88, (82, 104), 4, False),
                Device('pmos', 88, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 96, (56, 78), 4, False),
                Wire('POLY', (88, 124), 80, 8, False),
                Wire('POLY', 112, (56, 78), 4, False),
                Wire('POLY', 112, (80, 104), 4, False),
                Device('pmos', 112, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (112, 114), 56, 4, False),
                Device('nmos', 114, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net3'),
                Via('POLY', 'METAL1', 124, 80, 2),
                Wire('METAL1', (122, 142), 80, 6, False),
                Via('NDIF', 'METAL1', 144, 40, 2),
                Wire('METAL1', 144, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 144, 120, 2),
                Wire('NDIF', 146, (34, 46), 8, False),
                Wire('PDIF', 148, (114, 146), 8, False),
            ],
            '_net3': [
                Wire('NDIF', 122, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 124, 40, 2),
            ],
            'i0': [
                Wire('METAL1', 60, (62, 138), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 60, (102, 106), 4, False),
                Device('pmos', 60, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (58, 72), 96, 4, False),
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 72, (56, 96), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (60, 104), 4, False),
                Wire('METAL1', 40, (62, 138), 6, True),
                Device('pmos', 40, 150, 4, 80, 'vertical', source_net='_net4', drain_net='_net0'),
                Wire('POLY', (40, 52), 58, 4, False),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 52, (52, 58), 4, False),
            ],
            'i2': [
                Via('POLY', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Device('nmos', 22, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 22, (54, 104), 4, False),
                Device('pmos', 22, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net4'),
            ],
            'nq': [
                Wire('METAL1', 100, (40, 138), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Wire('PDIF', 100, (114, 186), 12, False),
                Wire('NDIF', 104, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 104, 40, 2),
            ],
            'vdd': [
                Wire('PDIF', 68, (114, 186), 12, False),
                Wire('PDIF', 76, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 76, 182, 2),
                Via('PDIF', 'METAL1', 120, 182, 2),
                Wire('PDIF', 122, (114, 186), 8, False),
                Wire('NTIE', 144, (168, 180), 12, False),
                Via('NTIE', 'METAL1', 144, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 34, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 38, 16, 2),
                Wire('NDIF', 38, (18, 46), 8, False),
                Wire('NDIF', 86, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 88, 18, 2),
                Wire('METAL1', 122, (16, 32), 6, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no4_x1', width=120, height=200,
        nets={
            'i0': [
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 52, (56, 76), 4, False),
                Wire('POLY', 54, (80, 104), 4, False),
                Device('pmos', 54, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (52, 62), 76, 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 28, (56, 96), 4, False),
                Wire('POLY', (28, 40), 96, 4, False),
                Wire('POLY', 38, (102, 106), 4, False),
                Device('pmos', 38, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('METAL1', 40, (82, 158), 6, True),
            ],
            'i2': [
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', (72, 74), 102, 4, False),
                Device('nmos', 74, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 74, (54, 102), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (82, 158), 6, True),
            ],
            'i3': [
                Wire('POLY', 90, (102, 108), 4, False),
                Device('pmos', 90, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (90, 96), 102, 4, False),
                Device('nmos', 96, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 96, (56, 100), 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 158), 6, True),
            ],
            'nq': [
                Wire('METAL1', 20, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', (20, 32), 60, 6, False),
                Wire('PDIF', 28, (114, 166), 12, False),
                Wire('NDIF', 36, (34, 46), 12, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (40, 60), 6, False),
                Wire('METAL1', (36, 82), 60, 6, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 84, (34, 46), 12, False),
                Wire('METAL1', 84, (40, 60), 6, False),
            ],
            'vdd': [
                Wire('PDIF', 100, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 100, 182, 2),
            ],
            'vss': [
                Wire('METAL1', 20, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('METAL1', 64, (26, 40), 6, False),
                Via('NDIF', 'METAL1', 64, 40, 2),
                Wire('NDIF', 64, (34, 46), 8, False),
                Wire('METAL1', 104, (24, 38), 8, False),
                Via('NDIF', 'METAL1', 104, 38, 2),
                Wire('NDIF', 106, (34, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='no4_x4', width=200, height=200,
        nets={
            '_net2': [
                Wire('METAL1', 20, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Wire('METAL1', 20, (122, 158), 6, False),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 28, (114, 166), 12, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', (22, 158), 40, 6, False),
                Via('NDIF', 'METAL1', 90, 40, 2),
                Wire('METAL1', 160, (42, 98), 6, False),
                Wire('METAL1', (162, 166), 60, 6, False),
                Wire('METAL1', (162, 166), 100, 6, False),
                Via('POLY', 'METAL1', 168, 60, 2),
                Via('POLY', 'METAL1', 168, 100, 2),
                Wire('POLY', (168, 176), 56, 4, False),
                Wire('POLY', (168, 176), 102, 8, False),
                Device('nmos', 176, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 176, (54, 56), 4, False),
                Wire('POLY', 176, (102, 106), 4, False),
                Device('pmos', 176, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net4'),
            ],
            '_net4': [
                Device('nmos', 124, 29, 4, 34, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 124, (50, 104), 4, False),
                Wire('POLY', (124, 128), 104, 4, False),
                Device('pmos', 128, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 152, 29, 4, 34, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 152, (50, 104), 4, False),
                Device('pmos', 152, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (128, 188), 80, 8, False),
                Via('NDIF', 'METAL1', 184, 40, 2),
                Wire('METAL1', 184, (42, 118), 6, False),
                Via('POLY', 'METAL1', 184, 80, 2),
                Via('PDIF', 'METAL1', 184, 120, 2),
                Wire('METAL1', 184, (122, 138), 6, False),
                Via('PDIF', 'METAL1', 184, 140, 2),
                Wire('NDIF', 186, (34, 46), 8, False),
                Wire('PDIF', 186, (114, 146), 8, False),
            ],
            'i0': [
                Device('nmos', 50, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 50, (56, 76), 4, False),
                Wire('POLY', (52, 60), 76, 4, False),
                Wire('POLY', 56, (80, 104), 4, False),
                Device('pmos', 56, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 32, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 32, (56, 96), 4, False),
                Wire('POLY', (34, 42), 96, 4, False),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', 40, (102, 106), 4, False),
                Wire('METAL1', 40, (62, 158), 6, True),
                Device('pmos', 40, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
            ],
            'i2': [
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net3'),
                Wire('POLY', (72, 76), 102, 4, False),
                Wire('POLY', 76, (60, 100), 4, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Wire('METAL1', 80, (62, 158), 6, True),
                Device('nmos', 82, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 82, (54, 58), 4, False),
            ],
            'i3': [
                Wire('POLY', 88, (102, 108), 4, False),
                Device('pmos', 88, 150, 4, 80, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (88, 96), 102, 4, False),
                Wire('POLY', 96, (60, 100), 4, False),
                Wire('POLY', (96, 100), 58, 4, False),
                Device('nmos', 100, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 100, (52, 58), 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 158), 6, True),
            ],
            'nq': [
                Wire('NDIF', 138, (16, 62), 8, False),
                Via('NDIF', 'METAL1', 140, 60, 2),
                Wire('METAL1', 140, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('PDIF', 140, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 100, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 100, 182, 2),
                Wire('PDIF', 112, (114, 186), 16, False),
                Wire('PDIF', 116, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 116, 182, 2),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', 160, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Via('PDIF', 'METAL1', 160, 184, 2),
                Wire('PDIF', 162, (114, 186), 8, False),
                Wire('NTIE', 184, (166, 184), 12, False),
                Via('NTIE', 'METAL1', 184, 182, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('NDIF', 18, (18, 46), 8, False),
                Via('NDIF', 'METAL1', 66, 18, 2),
                Wire('NDIF', 66, (16, 46), 12, False),
                Wire('NDIF', 114, (16, 42), 8, False),
                Via('NDIF', 'METAL1', 116, 18, 2),
                Via('NDIF', 'METAL1', 160, 18, 2),
                Wire('NDIF', 162, (16, 42), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa22_x1', width=120, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            '_net1': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (18, 58), 160, 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'i0': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net1', drain_net='nq'),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (56, 104), 4, False),
                Wire('POLY', (40, 48), 56, 4, False),
                Wire('POLY', (40, 48), 104, 4, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net0', drain_net='nq'),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net1'),
            ],
            'i2': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (72, 80), 56, 4, False),
                Wire('POLY', (72, 80), 104, 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (56, 104), 4, False),
                Wire('METAL1', 80, (42, 158), 6, True),
            ],
            'nq': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', (38, 58), 140, 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 138), 6, True),
            ],
            'vdd': [
                Wire('PDIF', 84, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 182, 2),
                Via('NTIE', 'METAL1', 104, 118, 2),
                Wire('NTIE', 104, (112, 136), 12, False),
                Wire('METAL1', 104, (114, 174), 6, False),
                Wire('NTIE', 104, (146, 166), 12, False),
                Via('NTIE', 'METAL1', 104, 160, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Via('NDIF', 'METAL1', 80, 18, 2),
                Wire('NDIF', 84, (16, 46), 8, False),
                Via('PTIE', 'METAL1', 104, 18, 2),
                Wire('PTIE', 104, (20, 34), 12, False),
                Wire('METAL1', 104, (22, 66), 6, False),
                Wire('PTIE', 104, (42, 66), 12, False),
                Via('PTIE', 'METAL1', 104, 70, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa22_x4', width=200, height=200,
        nets={
            '_net0': [
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('NDIF', 40, (34, 46), 12, False),
                Wire('METAL1', 40, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 64, 140, 2),
                Wire('PDIF', 64, (134, 166), 8, False),
                Wire('METAL1', (42, 130), 140, 6, False),
                Device('nmos', 124, 40, 4, 20, 'vertical', source_net='_net3', drain_net='vss'),
                Device('pmos', 124, 130, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (124, 128), 56, 4, False),
                Wire('POLY', (124, 128), 104, 4, False),
                Wire('POLY', 128, (56, 104), 4, False),
                Via('POLY', 'METAL1', 132, 100, 2),
                Wire('METAL1', 132, (102, 138), 6, False),
            ],
            '_net1': [
                Wire('PDIF', 40, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (42, 86), 160, 6, False),
                Wire('PDIF', 88, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 88, 160, 2),
            ],
            '_net2': [
                Wire('NDIF', 64, (34, 46), 12, False),
            ],
            '_net3': [
                Via('NDIF', 'METAL1', 112, 40, 2),
                Wire('NDIF', 112, (34, 46), 12, False),
                Wire('METAL1', 112, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 112, 120, 2),
                Wire('PDIF', 112, (114, 146), 12, False),
                Wire('METAL1', (114, 138), 80, 6, False),
                Via('POLY', 'METAL1', 140, 80, 2),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Device('pmos', 148, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (148, 152), 56, 4, False),
                Wire('POLY', (148, 152), 104, 4, False),
                Wire('POLY', 152, (56, 104), 4, False),
                Wire('POLY', (140, 172), 80, 8, False),
                Device('nmos', 172, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 172, (56, 104), 4, False),
                Device('pmos', 172, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'i0': [
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (72, 80), 56, 4, False),
                Wire('POLY', (72, 80), 124, 4, False),
                Wire('METAL1', 80, (42, 118), 6, True),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (56, 124), 4, False),
            ],
            'i1': [
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net2'),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (52, 60), 56, 4, False),
                Wire('POLY', (52, 60), 124, 4, False),
                Wire('METAL1', 60, (42, 118), 6, True),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('POLY', 60, (56, 124), 4, False),
            ],
            'i2': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Wire('POLY', (20, 28), 80, 8, False),
                Device('nmos', 32, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 32, (56, 124), 4, False),
                Device('pmos', 32, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'nq': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 18, (134, 178), 8, False),
                Via('PDIF', 'METAL1', 18, 186, 2),
                Via('NTIE', 'METAL1', 92, 184, 2),
                Wire('NTIE', (90, 114), 184, 12, False),
                Via('NTIE', 'METAL1', 112, 184, 2),
                Wire('PDIF', 138, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
                Wire('METAL1', 140, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 140, 184, 2),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Wire('PDIF', 184, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('NDIF', 16, (26, 46), 12, False),
                Via('NDIF', 'METAL1', 88, 18, 2),
                Wire('NDIF', 88, (26, 46), 12, False),
                Wire('NDIF', 138, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 140, 18, 2),
                Wire('METAL1', 140, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 140, 40, 2),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('METAL1', 180, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 184, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a22_x1', width=140, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (20, 106), 160, 6, False),
                Wire('PDIF', 104, (114, 146), 8, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
                Wire('PDIF', 108, (150, 186), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 84, (16, 46), 12, False),
            ],
            'i0': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (56, 104), 4, False),
                Wire('POLY', (40, 48), 56, 4, False),
                Wire('POLY', (40, 48), 104, 4, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net1', drain_net='nq'),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
            ],
            'i2': [
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net0'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (42, 138), 6, True),
            ],
            'i3': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net2'),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (72, 80), 56, 4, False),
                Wire('POLY', (72, 80), 104, 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (56, 104), 4, False),
                Wire('METAL1', 80, (42, 138), 6, True),
            ],
            'nq': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', (38, 60), 140, 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 138), 6, True),
            ],
            'vdd': [
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 182, 2),
                Via('NTIE', 'METAL1', 124, 116, 2),
                Wire('NTIE', 124, (114, 134), 12, False),
                Via('NTIE', 'METAL1', 124, 132, 2),
                Wire('METAL1', 124, (118, 178), 6, False),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Via('NDIF', 'METAL1', 108, 18, 2),
                Wire('NDIF', 108, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a22_x4', width=220, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 38, (134, 166), 4, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('METAL1', (38, 150), 140, 6, False),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 130, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (144, 152), 100, 8, False),
                Wire('METAL1', 152, (102, 138), 6, False),
                Via('POLY', 'METAL1', 156, 100, 2),
            ],
            '_net1': [
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (16, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net2': [
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('NDIF', 132, (34, 46), 12, False),
                Wire('METAL1', 132, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 132, 120, 2),
                Wire('PDIF', 132, (114, 146), 12, False),
                Wire('METAL1', (134, 158), 80, 6, False),
                Via('POLY', 'METAL1', 156, 80, 2),
                Device('nmos', 168, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 168, (56, 104), 4, False),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (160, 192), 80, 8, False),
                Device('nmos', 192, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 192, (56, 104), 4, False),
                Device('pmos', 192, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net3': [
                Wire('NDIF', 36, (34, 46), 12, False),
            ],
            '_net4': [
                Wire('NDIF', 84, (34, 46), 12, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (60, 118), 6, True),
                Device('nmos', 26, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 26, (56, 124), 4, False),
                Device('pmos', 26, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (56, 124), 4, False),
                Wire('POLY', (40, 48), 56, 4, False),
                Wire('POLY', (40, 48), 124, 4, False),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net3', drain_net='_net0'),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net0', drain_net='_net1'),
            ],
            'i2': [
                Device('nmos', 92, 40, 4, 20, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', (92, 100), 56, 4, False),
                Wire('METAL1', 100, (42, 118), 6, True),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('POLY', 100, (56, 128), 4, False),
                Device('pmos', 100, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i3': [
                Wire('POLY', 68, (122, 128), 4, False),
                Device('pmos', 68, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net4'),
                Wire('POLY', (68, 80), 122, 4, False),
                Wire('POLY', (72, 80), 56, 4, False),
                Wire('METAL1', 80, (42, 118), 6, True),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (56, 120), 4, False),
            ],
            'nq': [
                Wire('NDIF', 180, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('METAL1', 180, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 84, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 84, 186, 2),
                Wire('NTIE', (124, 142), 184, 8, False),
                Via('NTIE', 'METAL1', 136, 182, 2),
                Wire('PDIF', 158, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Wire('METAL1', 160, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 160, 184, 2),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('METAL1', 200, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Via('PDIF', 'METAL1', 200, 184, 2),
                Wire('PDIF', 204, (114, 186), 8, False),
            ],
            'vss': [
                Wire('METAL1', 18, (20, 38), 8, False),
                Via('NDIF', 'METAL1', 18, 38, 2),
                Via('NDIF', 'METAL1', 108, 18, 2),
                Wire('NDIF', 108, (18, 46), 12, False),
                Wire('NDIF', 158, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 160, 18, 2),
                Wire('METAL1', 160, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Via('NDIF', 'METAL1', 204, 18, 2),
                Wire('METAL1', 204, (22, 38), 6, False),
                Wire('NDIF', 204, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 204, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a2a23_x1', width=200, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (16, 106), 160, 6, False),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net2': [
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (86, 162), 140, 6, False),
                Wire('METAL1', 164, (142, 158), 6, False),
                Wire('PDIF', 164, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 164, 160, 2),
            ],
            'i0': [
                Device('nmos', 176, 31, 4, 38, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 176, (56, 104), 4, False),
                Device('pmos', 176, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('METAL1', 180, (62, 118), 6, True),
                Via('POLY', 'METAL1', 180, 100, 2),
            ],
            'i1': [
                Wire('POLY', 152, (104, 110), 4, False),
                Device('pmos', 152, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net2'),
                Wire('POLY', (152, 162), 104, 4, False),
                Device('nmos', 158, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net3'),
                Wire('POLY', 158, (56, 100), 4, False),
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
            ],
            'i2': [
                Device('nmos', 90, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 90, (52, 58), 4, False),
                Wire('POLY', (90, 96), 58, 4, False),
                Wire('POLY', 96, (60, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'i3': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net0'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', 72, (104, 110), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net2'),
                Wire('POLY', (72, 76), 58, 4, False),
                Wire('POLY', 76, (60, 102), 4, False),
                Wire('POLY', (72, 82), 104, 4, False),
                Wire('METAL1', 80, (62, 118), 6, True),
                Via('POLY', 'METAL1', 80, 100, 2),
            ],
            'i4': [
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net1'),
                Device('nmos', 50, 31, 4, 38, 'vertical', source_net='_net4', drain_net='nq'),
                Wire('POLY', 50, (52, 58), 4, False),
                Wire('POLY', (48, 56), 102, 4, False),
                Wire('POLY', (50, 56), 58, 4, False),
                Wire('POLY', 56, (60, 100), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
            ],
            'i5': [
                Wire('POLY', 24, (102, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', (24, 36), 102, 4, False),
                Device('nmos', 32, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 32, (54, 58), 4, False),
                Wire('POLY', (32, 36), 58, 4, False),
                Wire('POLY', 36, (60, 100), 4, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 118), 6, True),
            ],
            'nq': [
                Wire('METAL1', 20, (42, 138), 6, True),
                Wire('METAL1', (20, 34), 140, 6, False),
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (20, 146), 40, 6, False),
                Wire('NDIF', 148, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 148, 40, 2),
            ],
            'vdd': [
                Wire('PDIF', 140, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
                Wire('METAL1', 140, (162, 186), 6, False),
                Via('PDIF', 'METAL1', 184, 140, 2),
                Via('PDIF', 'METAL1', 184, 160, 2),
                Wire('METAL1', 184, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 184, 184, 2),
                Wire('PDIF', 186, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 20, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 24, 18, 2),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 124, 16, 2),
                Wire('PTIE', 124, (20, 34), 12, False),
                Via('NDIF', 'METAL1', 184, 18, 2),
                Wire('METAL1', 184, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 184, 40, 2),
                Wire('NDIF', 186, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a2a23_x4', width=260, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 12, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Wire('METAL1', (14, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('PDIF', 108, (114, 160), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net1': [
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (86, 150), 140, 6, False),
                Wire('METAL1', 152, (142, 158), 6, False),
                Wire('PDIF', 152, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 152, 160, 2),
            ],
            '_net3': [
                Wire('METAL1', 20, (42, 136), 6, False),
                Wire('METAL1', (22, 34), 138, 6, False),
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (22, 226), 40, 6, False),
                Wire('NDIF', 136, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 40, 2),
                Wire('METAL1', 228, (42, 58), 6, False),
                Via('POLY', 'METAL1', 228, 60, 2),
                Wire('POLY', (228, 236), 60, 8, False),
                Device('nmos', 240, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 240, (56, 104), 4, False),
                Device('pmos', 240, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net6'),
            ],
            '_net6': [
                Device('nmos', 184, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 184, (56, 104), 4, False),
                Device('pmos', 184, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (188, 212), 80, 4, False),
                Device('nmos', 216, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 216, (56, 104), 4, False),
                Device('pmos', 216, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (216, 220), 80, 8, False),
                Via('POLY', 'METAL1', 220, 80, 2),
                Wire('METAL1', (222, 246), 80, 6, False),
                Via('NDIF', 'METAL1', 248, 40, 2),
                Wire('METAL1', 248, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 248, 120, 2),
                Via('PDIF', 'METAL1', 248, 140, 2),
                Wire('NDIF', 250, (34, 46), 8, False),
                Wire('PDIF', 250, (114, 146), 8, False),
            ],
            'i0': [
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Wire('POLY', 164, (100, 108), 4, False),
                Device('pmos', 164, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Device('nmos', 166, 31, 4, 38, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 166, (56, 102), 4, False),
            ],
            'i1': [
                Wire('POLY', 140, (60, 108), 4, False),
                Wire('METAL1', 140, (62, 118), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('pmos', 140, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
                Wire('POLY', (140, 148), 58, 4, False),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='_net3', drain_net='_net5'),
                Wire('POLY', 148, (52, 58), 4, False),
            ],
            'i2': [
                Device('nmos', 90, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 90, (52, 58), 4, False),
                Wire('POLY', (90, 96), 58, 4, False),
                Wire('POLY', 96, (60, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'i3': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net3', drain_net='_net2'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (72, 76), 58, 4, False),
                Wire('POLY', (72, 76), 102, 4, False),
                Wire('POLY', 76, (60, 102), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 118), 6, True),
            ],
            'i4': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net4', drain_net='_net3'),
                Wire('POLY', 48, (52, 58), 4, False),
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net0'),
                Wire('POLY', (48, 56), 58, 4, False),
                Wire('POLY', (48, 56), 102, 4, False),
                Wire('POLY', 56, (60, 102), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
            ],
            'i5': [
                Wire('POLY', 24, (102, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net3'),
                Device('nmos', 30, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 30, (52, 58), 4, False),
                Wire('POLY', (24, 36), 102, 4, False),
                Wire('POLY', (30, 36), 58, 4, False),
                Wire('POLY', 36, (60, 102), 4, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 118), 6, True),
            ],
            'nq': [
                Wire('NDIF', 200, (16, 58), 12, False),
                Via('NDIF', 'METAL1', 200, 60, 2),
                Wire('METAL1', 200, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('PDIF', 200, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 124, 184, 2),
                Wire('PDIF', 128, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 176, 140, 2),
                Wire('PDIF', 176, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 176, 160, 2),
                Wire('METAL1', 176, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 176, 184, 2),
                Via('PDIF', 'METAL1', 224, 140, 2),
                Wire('PDIF', 224, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 224, 160, 2),
                Wire('METAL1', 224, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 224, 184, 2),
                Wire('NTIE', 244, (166, 184), 12, False),
                Via('NTIE', 'METAL1', 244, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 18, 2),
                Wire('NDIF', 20, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 176, 18, 2),
                Wire('NDIF', 176, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 224, 18, 2),
                Wire('NDIF', 224, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a2a2a24_x1', width=280, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 58), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 140, 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
            ],
            '_net1': [
                Via('PDIF', 'METAL1', 156, 140, 2),
                Wire('PDIF', 156, (114, 186), 12, False),
                Wire('METAL1', (158, 198), 140, 6, False),
                Wire('METAL1', 200, (142, 158), 6, False),
                Wire('METAL1', (202, 226), 160, 6, False),
                Wire('PDIF', 228, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 228, 160, 2),
            ],
            '_net2': [
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 132, 140, 2),
                Wire('METAL1', 132, (142, 158), 6, False),
                Wire('PDIF', 132, (114, 186), 12, False),
                Wire('METAL1', (86, 178), 160, 6, False),
                Via('PDIF', 'METAL1', 132, 160, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            '_net3': [
                Wire('NDIF', 38, (18, 46), 12, False),
            ],
            '_net4': [
                Wire('NDIF', 156, (18, 46), 12, False),
            ],
            '_net5': [
                Wire('NDIF', 108, (18, 46), 12, False),
            ],
            '_net6': [
                Wire('NDIF', 228, (18, 46), 12, False),
            ],
            'i0': [
                Device('nmos', 240, 32, 4, 36, 'vertical', source_net='_net6', drain_net='vss'),
                Wire('POLY', 240, (56, 104), 4, False),
                Wire('METAL1', 240, (62, 138), 6, True),
                Via('POLY', 'METAL1', 240, 100, 2),
                Device('pmos', 240, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'i1': [
                Device('nmos', 216, 32, 4, 36, 'vertical', source_net='nq', drain_net='_net6'),
                Wire('POLY', 216, (56, 104), 4, False),
                Device('pmos', 216, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
                Wire('METAL1', 220, (62, 138), 6, True),
                Via('POLY', 'METAL1', 220, 100, 2),
            ],
            'i2': [
                Wire('POLY', 160, (56, 104), 4, False),
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Wire('POLY', (160, 168), 56, 4, False),
                Wire('POLY', (160, 168), 104, 4, False),
                Device('nmos', 168, 32, 4, 36, 'vertical', source_net='_net4', drain_net='vss'),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net2'),
            ],
            'i3': [
                Wire('METAL1', 140, (62, 118), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('nmos', 144, 32, 4, 36, 'vertical', source_net='nq', drain_net='_net4'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            'i4': [
                Device('nmos', 120, 32, 4, 36, 'vertical', source_net='_net5', drain_net='nq'),
                Wire('POLY', 120, (56, 104), 4, False),
                Wire('METAL1', 120, (62, 118), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net2'),
            ],
            'i5': [
                Device('nmos', 96, 32, 4, 36, 'vertical', source_net='vss', drain_net='_net5'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'i6': [
                Device('nmos', 48, 32, 4, 36, 'vertical', source_net='_net3', drain_net='nq'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
                Wire('POLY', (48, 60), 100, 8, False),
                Wire('METAL1', 60, (62, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'i7': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('POLY', 24, (60, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', (24, 30), 58, 4, False),
                Device('nmos', 30, 32, 4, 36, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 30, (52, 58), 4, False),
            ],
            'nq': [
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', 40, (42, 138), 6, True),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('NDIF', 60, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (40, 202), 40, 6, False),
                Wire('NDIF', 132, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('NDIF', 204, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 204, 40, 2),
            ],
            'vdd': [
                Wire('PDIF', 204, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 208, 182, 2),
                Wire('PDIF', 252, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 252, 160, 2),
                Wire('METAL1', 252, (162, 182), 6, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('NDIF', 16, (18, 46), 8, False),
                Via('NDIF', 'METAL1', 82, 18, 2),
                Wire('NDIF', 84, (22, 46), 12, False),
                Wire('NDIF', 180, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 182, 18, 2),
                Wire('METAL1', 252, (14, 38), 6, False),
                Wire('NDIF', 252, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 252, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2a2a2a24_x4', width=340, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (16, 58), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 140, 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            '_net3': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', (38, 38), 140, 6, False),
                Wire('METAL1', 40, (42, 138), 6, False),
                Via('NDIF', 'METAL1', 56, 40, 2),
                Wire('NDIF', 60, (16, 46), 12, False),
                Wire('METAL1', (42, 214), 40, 6, False),
                Wire('NDIF', 132, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('NDIF', 216, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 216, 40, 2),
                Wire('METAL1', (218, 306), 40, 6, False),
                Wire('METAL1', 308, (42, 58), 6, False),
                Via('POLY', 'METAL1', 308, 60, 2),
                Wire('POLY', 314, (56, 64), 6, False),
                Device('nmos', 316, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net7'),
                Wire('POLY', 316, (56, 104), 4, False),
                Device('pmos', 316, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net7'),
            ],
            '_net4': [
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 132, 140, 2),
                Wire('METAL1', 132, (142, 158), 6, False),
                Wire('PDIF', 132, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 132, 160, 2),
                Wire('METAL1', (86, 178), 160, 6, False),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            '_net6': [
                Via('PDIF', 'METAL1', 156, 140, 2),
                Wire('PDIF', 156, (114, 186), 12, False),
                Wire('METAL1', (158, 230), 140, 6, False),
                Wire('METAL1', 232, (142, 158), 6, False),
                Wire('PDIF', 232, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 232, 160, 2),
            ],
            '_net7': [
                Device('nmos', 266, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 266, (56, 104), 4, False),
                Device('pmos', 266, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (268, 300), 80, 4, False),
                Wire('POLY', 292, (56, 80), 4, False),
                Wire('POLY', 292, (82, 106), 4, False),
                Device('pmos', 292, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Wire('POLY', (292, 294), 56, 4, False),
                Device('nmos', 294, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', (296, 300), 80, 8, False),
                Via('POLY', 'METAL1', 304, 80, 2),
                Wire('METAL1', (302, 326), 80, 6, False),
                Via('NDIF', 'METAL1', 324, 40, 2),
                Wire('METAL1', 324, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 324, 116, 2),
                Via('PDIF', 'METAL1', 324, 140, 2),
                Wire('NDIF', 326, (34, 46), 8, False),
                Wire('PDIF', 326, (114, 146), 8, False),
            ],
            '_net9': [
                Via('POLY', 'METAL1', 240, 80, 2),
                Device('nmos', 244, 31, 4, 38, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 244, (56, 104), 4, False),
                Device('pmos', 244, 150, 4, 80, 'vertical', source_net='_net6', drain_net='vdd'),
            ],
            'i0': [
                Wire('METAL1', (248, 256), 80, 8, False),
                Wire('METAL1', 260, (62, 140), 6, True),
            ],
            'i1': [
                Via('POLY', 'METAL1', 220, 80, 2),
                Wire('POLY', 220, (58, 104), 4, False),
                Wire('METAL1', 220, (62, 118), 6, True),
                Device('pmos', 220, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net6'),
                Wire('POLY', (220, 226), 58, 4, False),
                Device('nmos', 226, 31, 4, 38, 'vertical', source_net='_net3', drain_net='_net5'),
                Wire('POLY', 226, (54, 58), 4, False),
            ],
            'i2': [
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Device('nmos', 162, 31, 4, 38, 'vertical', source_net='_net8', drain_net='vss'),
                Wire('POLY', 162, (56, 102), 4, False),
                Wire('POLY', (160, 168), 104, 4, False),
                Wire('POLY', 168, (104, 110), 4, False),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='_net6', drain_net='_net4'),
            ],
            'i3': [
                Wire('METAL1', 140, (62, 118), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('nmos', 144, 31, 4, 38, 'vertical', source_net='_net3', drain_net='_net8'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 150, 4, 80, 'vertical', source_net='_net4', drain_net='_net6'),
            ],
            'i4': [
                Wire('METAL1', 120, (62, 118), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
                Wire('POLY', 120, (102, 106), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net4'),
                Device('nmos', 122, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net3'),
                Wire('POLY', 122, (56, 102), 4, False),
            ],
            'i5': [
                Wire('POLY', 96, (102, 108), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net4', drain_net='_net1'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('POLY', (96, 104), 102, 4, False),
                Device('nmos', 104, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 104, (56, 102), 4, False),
            ],
            'i6': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net1'),
                Wire('POLY', (48, 60), 100, 8, False),
                Wire('METAL1', 60, (62, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'i7': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net3'),
            ],
            'nq': [
                Wire('NDIF', 280, (16, 56), 8, False),
                Via('NDIF', 'METAL1', 280, 54, 2),
                Wire('METAL1', 280, (60, 158), 6, True),
                Via('PDIF', 'METAL1', 280, 120, 2),
                Via('PDIF', 'METAL1', 280, 140, 2),
                Wire('PDIF', 280, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 280, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 208, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 208, 160, 2),
                Wire('METAL1', 208, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 208, 184, 2),
                Wire('PDIF', 256, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 256, 160, 2),
                Wire('METAL1', 256, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 256, 184, 2),
                Via('PDIF', 'METAL1', 300, 140, 2),
                Via('PDIF', 'METAL1', 300, 160, 2),
                Wire('METAL1', 300, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 300, 184, 2),
                Wire('PDIF', 302, (114, 186), 8, False),
                Wire('NTIE', 324, (166, 184), 12, False),
                Via('NTIE', 'METAL1', 324, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('NDIF', 92, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 96, 18, 2),
                Via('NDIF', 'METAL1', 170, 18, 2),
                Wire('NDIF', 172, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 256, 18, 2),
                Wire('NDIF', 256, (16, 46), 12, False),
                Wire('NDIF', 302, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 306, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2ao222_x1', width=140, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 12, (114, 164), 8, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('PDIF', 60, (114, 164), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (14, 122), 160, 6, False),
                Via('PDIF', 'METAL1', 124, 160, 2),
                Wire('PDIF', 126, (114, 186), 8, False),
            ],
            '_net1': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('NDIF', 80, (38, 66), 8, False),
                Wire('METAL1', (82, 122), 40, 6, False),
                Via('NDIF', 'METAL1', 124, 40, 2),
                Wire('NDIF', 126, (38, 66), 8, False),
            ],
            '_net2': [
                Wire('NDIF', 34, (38, 66), 4, False),
            ],
            '_net3': [
                Wire('PDIF', 108, (114, 186), 8, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('POLY', 20, (80, 104), 4, False),
                Wire('METAL1', 20, (62, 138), 6, True),
                Device('pmos', 20, 139, 4, 58, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 22, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 22, (74, 78), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Device('nmos', 44, 52, 4, 36, 'vertical', source_net='_net2', drain_net='nq'),
                Wire('POLY', 44, (76, 100), 4, False),
                Wire('POLY', (44, 52), 102, 4, False),
                Wire('POLY', 52, (102, 108), 4, False),
                Device('pmos', 52, 139, 4, 58, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'i2': [
                Device('nmos', 88, 52, 4, 36, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 88, (72, 78), 4, False),
                Wire('POLY', (88, 96), 78, 4, False),
                Wire('POLY', 96, (78, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net3'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 124), 6, True),
            ],
            'i3': [
                Device('nmos', 116, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 116, (74, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net0'),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (62, 138), 6, True),
            ],
            'i4': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (80, 138), 6, True),
                Wire('POLY', 66, (76, 84), 6, False),
                Device('nmos', 68, 52, 4, 36, 'vertical', source_net='nq', drain_net='_net1'),
                Wire('POLY', 68, (74, 86), 4, False),
                Wire('POLY', (68, 74), 86, 4, False),
                Wire('POLY', 74, (88, 100), 4, False),
                Wire('POLY', 74, (102, 108), 4, False),
                Device('pmos', 74, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 56, 40, 2),
                Wire('NDIF', 56, (38, 66), 8, False),
                Wire('METAL1', 60, (40, 60), 6, True),
                Wire('METAL1', (60, 80), 60, 6, False),
                Wire('METAL1', 80, (62, 140), 6, True),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (114, 184), 12, False),
                Via('PDIF', 'METAL1', 36, 188, 2),
            ],
            'vss': [
                Wire('NDIF', 12, (38, 66), 8, False),
                Wire('METAL1', 14, (20, 40), 8, False),
                Via('NDIF', 'METAL1', 14, 40, 2),
                Via('PTIE', 'METAL1', 48, 16, 2),
                Wire('PTIE', (46, 82), 16, 12, False),
                Via('PTIE', 'METAL1', 64, 16, 2),
                Via('PTIE', 'METAL1', 80, 16, 2),
                Via('NDIF', 'METAL1', 102, 18, 2),
                Wire('NDIF', 102, (22, 66), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa2ao222_x4', width=240, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 152, (114, 146), 12, False),
                Via('NDIF', 'METAL1', 156, 60, 2),
                Wire('NDIF', 156, (54, 66), 12, False),
                Wire('METAL1', 156, (62, 118), 6, False),
                Via('PDIF', 'METAL1', 156, 120, 2),
                Wire('METAL1', (158, 178), 80, 6, False),
                Via('POLY', 'METAL1', 176, 80, 2),
                Wire('POLY', 188, (80, 104), 4, False),
                Device('pmos', 188, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Device('nmos', 192, 50, 4, 40, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 192, (74, 78), 4, False),
                Wire('POLY', (180, 212), 80, 8, False),
                Device('nmos', 212, 50, 4, 40, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 212, (76, 104), 4, False),
                Device('pmos', 212, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net1': [
                Wire('METAL1', (54, 56), 40, 6, False),
                Wire('METAL1', 58, (42, 58), 6, False),
                Wire('METAL1', (62, 78), 60, 6, False),
                Wire('METAL1', 80, (62, 138), 6, False),
                Wire('METAL1', (82, 82), 140, 6, False),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
                Wire('METAL1', (86, 170), 140, 6, False),
                Device('nmos', 164, 60, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 164, (76, 108), 4, False),
                Device('pmos', 164, 130, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', 166, (96, 104), 6, False),
                Via('POLY', 'METAL1', 172, 100, 2),
                Wire('METAL1', 172, (102, 138), 6, False),
            ],
            '_net2': [
                Wire('PDIF', 12, (114, 164), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('PDIF', 60, (114, 164), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (14, 126), 160, 6, False),
                Wire('PDIF', 128, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 128, 160, 2),
            ],
            '_net3': [
                Wire('NDIF', 34, (38, 66), 4, False),
            ],
            '_net4': [
                Wire('PDIF', 108, (114, 186), 8, False),
            ],
            '_net5': [
                Via('NDIF', 'METAL1', 78, 40, 2),
                Wire('NDIF', 78, (38, 66), 12, False),
                Wire('METAL1', (82, 130), 40, 6, False),
                Via('NDIF', 'METAL1', 130, 60, 2),
                Wire('METAL1', 132, (42, 60), 6, False),
                Wire('NDIF', 134, (50, 66), 8, False),
            ],
            '_net6': [
                Via('NDIF', 'METAL1', 46, 40, 2),
                Wire('NDIF', 48, (38, 66), 8, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', 20, (94, 108), 4, False),
                Device('pmos', 20, 139, 4, 58, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (20, 22), 94, 4, False),
                Device('nmos', 22, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 22, (76, 94), 4, False),
            ],
            'i1': [
                Device('nmos', 38, 52, 4, 36, 'vertical', source_net='_net3', drain_net='_net6'),
                Wire('POLY', 38, (72, 102), 4, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Wire('POLY', (40, 52), 102, 4, False),
                Wire('POLY', 52, (102, 108), 4, False),
                Device('pmos', 52, 139, 4, 58, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            'i2': [
                Device('nmos', 94, 58, 4, 24, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 94, (74, 82), 4, False),
                Wire('POLY', 96, (82, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net4'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 118), 6, True),
            ],
            'i3': [
                Wire('POLY', 116, (78, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='_net4', drain_net='_net2'),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (82, 118), 6, True),
                Device('nmos', 122, 58, 4, 24, 'vertical', source_net='vss', drain_net='_net5'),
                Wire('POLY', 122, (72, 80), 4, False),
            ],
            'i4': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 138), 6, True),
                Device('nmos', 62, 58, 4, 24, 'vertical', source_net='_net6', drain_net='_net5'),
                Wire('POLY', 62, (72, 80), 4, False),
                Wire('POLY', (60, 68), 86, 4, False),
                Wire('POLY', 68, (88, 100), 4, False),
                Wire('POLY', (68, 74), 102, 4, False),
                Wire('POLY', 74, (102, 108), 4, False),
                Device('pmos', 74, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 200, 40, 2),
                Via('NDIF', 'METAL1', 200, 60, 2),
                Wire('METAL1', 200, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('PDIF', 200, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Wire('NDIF', 202, (34, 66), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 188, 2),
                Wire('NTIE', 152, (166, 182), 12, False),
                Via('NTIE', 'METAL1', 152, 184, 2),
                Wire('PDIF', 178, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Wire('METAL1', 180, (162, 186), 6, False),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Via('PDIF', 'METAL1', 220, 120, 2),
                Via('PDIF', 'METAL1', 220, 140, 2),
                Wire('METAL1', 220, (122, 186), 6, False),
                Via('PDIF', 'METAL1', 220, 160, 2),
                Via('PDIF', 'METAL1', 220, 184, 2),
                Wire('PDIF', 222, (114, 186), 8, False),
            ],
            'vss': [
                Wire('METAL1', 12, (22, 40), 8, False),
                Wire('NDIF', 12, (38, 66), 8, False),
                Via('NDIF', 'METAL1', 14, 40, 2),
                Via('PTIE', 'METAL1', 48, 16, 2),
                Wire('PTIE', (46, 82), 16, 12, False),
                Via('PTIE', 'METAL1', 64, 16, 2),
                Via('PTIE', 'METAL1', 80, 16, 2),
                Via('NDIF', 'METAL1', 108, 16, 2),
                Wire('NDIF', 108, (22, 66), 8, False),
                Via('PTIE', 'METAL1', 132, 16, 2),
                Wire('PTIE', (126, 178), 16, 12, False),
                Via('PTIE', 'METAL1', 152, 16, 2),
                Via('PTIE', 'METAL1', 172, 16, 2),
                Wire('NDIF', 178, (34, 66), 8, False),
                Wire('METAL1', 180, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Via('NDIF', 'METAL1', 180, 60, 2),
                Wire('METAL1', 220, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Via('NDIF', 'METAL1', 220, 60, 2),
                Wire('NDIF', 224, (34, 66), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa3ao322_x1', width=180, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 128, (114, 186), 8, False),
            ],
            '_net1': [
                Wire('PDIF', 146, (114, 186), 4, False),
            ],
            '_net2': [
                Wire('NDIF', 54, (26, 66), 4, False),
            ],
            '_net3': [
                Wire('NDIF', 34, (26, 66), 4, False),
            ],
            '_net4': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('NDIF', 100, (38, 66), 8, False),
                Wire('METAL1', (102, 142), 40, 6, False),
                Via('NDIF', 'METAL1', 144, 40, 2),
                Wire('NDIF', 144, (38, 66), 12, False),
            ],
            '_net5': [
                Via('PDIF', 'METAL1', 32, 160, 2),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('PDIF', 82, (114, 166), 8, False),
                Wire('METAL1', (38, 166), 160, 6, False),
                Wire('PDIF', 168, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 168, 160, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Device('nmos', 24, 46, 4, 48, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 24, (76, 104), 4, False),
                Device('pmos', 24, 140, 4, 60, 'vertical', source_net='vdd', drain_net='_net5'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (42, 138), 6, True),
                Wire('POLY', 42, (102, 108), 4, False),
                Device('pmos', 42, 140, 4, 60, 'vertical', source_net='_net5', drain_net='vdd'),
                Wire('POLY', (42, 44), 102, 4, False),
                Device('nmos', 44, 46, 4, 48, 'vertical', source_net='_net3', drain_net='_net2'),
                Wire('POLY', 44, (76, 100), 4, False),
            ],
            'i2': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
                Device('nmos', 64, 46, 4, 48, 'vertical', source_net='_net2', drain_net='nq'),
                Wire('POLY', 64, (76, 102), 4, False),
                Wire('POLY', (64, 72), 102, 4, False),
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 140, 4, 60, 'vertical', source_net='vdd', drain_net='_net5'),
            ],
            'i3': [
                Device('nmos', 108, 52, 4, 36, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 108, (72, 78), 4, False),
                Wire('POLY', (108, 112), 78, 4, False),
                Wire('POLY', 116, (78, 106), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
                Wire('METAL1', 120, (62, 118), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
            ],
            'i4': [
                Device('nmos', 136, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 136, (76, 104), 4, False),
                Device('pmos', 136, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('METAL1', 140, (62, 138), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
            ],
            'i5': [
                Device('nmos', 156, 52, 4, 36, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 156, (76, 104), 4, False),
                Device('pmos', 156, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net5'),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (62, 138), 6, True),
            ],
            'i6': [
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (80, 138), 6, True),
                Wire('POLY', (80, 88), 76, 4, False),
                Device('nmos', 88, 52, 4, 36, 'vertical', source_net='nq', drain_net='_net4'),
                Wire('POLY', (80, 96), 78, 4, False),
                Wire('POLY', 96, (80, 108), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net5', drain_net='nq'),
            ],
            'nq': [
                Wire('NDIF', 74, (26, 66), 8, False),
                Via('NDIF', 'METAL1', 76, 40, 2),
                Wire('METAL1', 80, (40, 58), 6, False),
                Wire('METAL1', (80, 100), 60, 6, False),
                Wire('METAL1', 100, (62, 138), 6, True),
                Via('PDIF', 'METAL1', 104, 140, 2),
                Wire('PDIF', 104, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 12, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('METAL1', 12, (162, 186), 6, False),
                Wire('PDIF', 54, (114, 166), 12, False),
                Wire('PDIF', 58, (114, 184), 8, False),
                Via('PDIF', 'METAL1', 58, 188, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (26, 66), 8, False),
                Wire('METAL1', 16, (26, 38), 6, False),
                Via('NDIF', 'METAL1', 16, 38, 2),
                Via('NDIF', 'METAL1', 122, 18, 2),
                Wire('NDIF', 122, (20, 66), 8, False),
                Via('PTIE', 'METAL1', 148, 16, 2),
                Wire('PTIE', (146, 166), 16, 12, False),
                Via('PTIE', 'METAL1', 164, 16, 2),
                Wire('METAL1', 168, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 168, 40, 2),
                Wire('NDIF', 168, (38, 66), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='noa3ao322_x4', width=260, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 108, (130, 166), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
                Via('PDIF', 'METAL1', 156, 160, 2),
                Wire('PDIF', 158, (126, 166), 8, False),
                Wire('METAL1', (110, 246), 160, 6, False),
                Via('PDIF', 'METAL1', 244, 160, 2),
                Wire('PDIF', 246, (114, 166), 8, False),
            ],
            '_net1': [
                Wire('NDIF', 14, (34, 54), 8, False),
                Wire('METAL1', 14, (50, 138), 6, False),
                Wire('PDIF', 14, (114, 154), 8, False),
                Via('NDIF', 'METAL1', 16, 48, 2),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', (14, 38), 68, 6, False),
                Wire('METAL1', (14, 38), 100, 6, False),
                Via('POLY', 'METAL1', 40, 68, 2),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 48, 38, 4, 40, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 48, (60, 64), 4, False),
                Wire('POLY', 48, (104, 106), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (40, 72), 64, 4, False),
                Wire('POLY', (40, 72), 104, 4, False),
                Device('nmos', 72, 38, 4, 40, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 72, (60, 62), 4, False),
                Wire('POLY', 72, (104, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net2': [
                Wire('NDIF', 130, (38, 62), 4, False),
            ],
            '_net3': [
                Wire('NDIF', 110, (38, 62), 4, False),
            ],
            '_net4': [
                Wire('NDIF', 170, (38, 54), 8, False),
                Via('NDIF', 'METAL1', 176, 40, 2),
                Wire('NDIF', 176, (38, 46), 12, False),
                Wire('METAL1', (178, 222), 40, 6, False),
                Via('NDIF', 'METAL1', 226, 40, 2),
            ],
            '_net5': [
                Device('nmos', 24, 44, 4, 28, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 24, (64, 104), 4, False),
                Device('pmos', 24, 134, 4, 48, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (24, 80), 84, 4, False),
                Wire('METAL1', 80, (42, 78), 6, False),
                Via('POLY', 'METAL1', 80, 82, 2),
                Wire('METAL1', (82, 150), 40, 6, False),
                Via('NDIF', 'METAL1', 152, 40, 2),
                Wire('NDIF', 152, (38, 54), 8, False),
                Wire('METAL1', 152, (42, 58), 6, False),
                Wire('METAL1', (154, 178), 60, 6, False),
                Wire('METAL1', 180, (62, 138), 6, False),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 182, (114, 166), 8, False),
                Wire('PDIF', 188, (114, 166), 4, False),
            ],
            '_net6': [
                Wire('PDIF', 206, (114, 166), 4, False),
            ],
            '_net7': [
                Wire('PDIF', 226, (114, 166), 4, False),
            ],
            'i0': [
                Wire('POLY', 96, (76, 120), 4, False),
                Device('pmos', 96, 148, 4, 44, 'vertical', source_net='vdd', drain_net='_net0'),
                Wire('POLY', (96, 100), 76, 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 138), 6, True),
                Device('nmos', 104, 50, 4, 32, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 104, (72, 80), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (62, 138), 6, True),
                Wire('POLY', 120, (82, 120), 4, False),
                Device('pmos', 120, 148, 4, 44, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 122, 50, 4, 32, 'vertical', source_net='_net3', drain_net='_net2'),
                Wire('POLY', 122, (72, 80), 4, False),
            ],
            'i2': [
                Device('nmos', 140, 50, 4, 32, 'vertical', source_net='_net2', drain_net='_net5'),
                Wire('POLY', 140, (72, 80), 4, False),
                Via('POLY', 'METAL1', 140, 80, 2),
                Wire('METAL1', 140, (82, 138), 6, True),
                Wire('POLY', 144, (80, 114), 4, False),
                Wire('POLY', (144, 148), 114, 4, False),
                Wire('POLY', 148, (114, 118), 4, False),
                Device('pmos', 148, 146, 4, 48, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'i3': [
                Device('nmos', 186, 42, 4, 16, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 186, (56, 76), 4, False),
                Wire('POLY', (188, 196), 76, 4, False),
                Wire('POLY', 196, (76, 104), 4, False),
                Device('pmos', 196, 140, 4, 60, 'vertical', source_net='_net5', drain_net='_net6'),
                Wire('METAL1', 200, (62, 138), 6, True),
                Via('POLY', 'METAL1', 200, 100, 2),
            ],
            'i4': [
                Device('nmos', 218, 42, 4, 16, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 218, (56, 92), 4, False),
                Wire('POLY', 218, (96, 104), 4, False),
                Device('pmos', 218, 140, 4, 60, 'vertical', source_net='_net6', drain_net='_net7'),
                Wire('METAL1', 220, (62, 138), 6, True),
                Via('POLY', 'METAL1', 220, 100, 2),
            ],
            'i5': [
                Device('nmos', 236, 42, 4, 16, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 236, (56, 104), 4, False),
                Device('pmos', 236, 140, 4, 60, 'vertical', source_net='_net7', drain_net='_net0'),
                Via('POLY', 'METAL1', 240, 80, 2),
                Wire('METAL1', 240, (62, 138), 6, True),
            ],
            'i6': [
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (82, 138), 6, True),
                Device('nmos', 164, 46, 4, 24, 'vertical', source_net='_net5', drain_net='_net4'),
                Wire('POLY', 164, (64, 76), 4, False),
                Wire('POLY', (160, 168), 82, 8, False),
                Wire('POLY', 168, (80, 116), 4, False),
                Device('pmos', 168, 140, 4, 60, 'vertical', source_net='_net0', drain_net='_net5'),
            ],
            'nq': [
                Wire('NDIF', 60, (22, 54), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('NTIE', 14, (172, 180), 12, False),
                Via('NTIE', 'METAL1', 14, 182, 2),
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('METAL1', 40, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Wire('METAL1', 84, (162, 186), 6, False),
                Wire('PDIF', 134, (130, 178), 8, False),
                Via('PDIF', 'METAL1', 134, 186, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 40, 28, 2),
                Wire('METAL1', 40, (26, 46), 6, False),
                Wire('NDIF', 40, (22, 54), 12, False),
                Via('NDIF', 'METAL1', 40, 48, 2),
                Wire('NDIF', 80, (22, 54), 4, False),
                Via('NDIF', 'METAL1', 88, 16, 2),
                Wire('NDIF', 88, (18, 62), 12, False),
                Wire('PTIE', (110, 174), 16, 12, False),
                Via('PTIE', 'METAL1', 152, 16, 2),
                Via('NDIF', 'METAL1', 202, 16, 2),
                Wire('NDIF', 202, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 244, 40, 2),
                Wire('NDIF', 246, (38, 46), 8, False),
                Wire('METAL1', 248, (14, 38), 6, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nsnrlatch_x1', width=120, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 40, (34, 66), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 80, (34, 66), 12, False),
            ],
            'nq': [
                Device('nmos', 50, 50, 4, 40, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 50, (76, 130), 4, False),
                Device('pmos', 50, 150, 4, 40, 'vertical', source_net='q', drain_net='vdd'),
                Via('POLY', 'METAL1', 54, 90, 2),
                Wire('METAL1', (54, 80), 90, 6, False),
                Wire('METAL1', 80, (40, 158), 6, True),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('METAL1', (82, 100), 40, 6, False),
                Via('NDIF', 'METAL1', 102, 40, 2),
                Wire('NDIF', 102, (34, 66), 12, False),
            ],
            'nrst': [
                Device('nmos', 92, 50, 4, 40, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', 92, (74, 124), 4, False),
                Device('pmos', 92, 150, 4, 40, 'vertical', source_net='nq', drain_net='vdd'),
                Via('POLY', 'METAL1', 98, 110, 2),
                Wire('METAL1', 100, (62, 138), 6, True),
            ],
            'nset': [
                Wire('METAL1', 20, (62, 138), 6, True),
                Via('POLY', 'METAL1', 22, 90, 2),
                Device('nmos', 28, 50, 4, 40, 'vertical', source_net='q', drain_net='_net0'),
                Wire('POLY', 28, (74, 124), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 18, 40, 2),
                Wire('NDIF', 18, (34, 66), 12, False),
                Wire('METAL1', (20, 38), 40, 6, False),
                Wire('METAL1', 40, (40, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (40, 66), 110, 6, False),
                Via('POLY', 'METAL1', 66, 110, 2),
                Device('nmos', 70, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 70, (76, 130), 4, False),
                Device('pmos', 70, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq'),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (160, 174), 8, False),
                Via('NTIE', 'METAL1', 20, 186, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', 60, (160, 174), 8, False),
                Wire('NTIE', (20, 100), 186, 12, False),
                Via('NTIE', 'METAL1', 60, 186, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('METAL1', 100, (160, 174), 8, False),
                Via('NTIE', 'METAL1', 100, 186, 2),
                Wire('PDIF', 104, (134, 166), 8, False),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 20, 14, 2),
                Wire('PTIE', (20, 100), 14, 12, False),
                Via('PTIE', 'METAL1', 60, 14, 2),
                Wire('METAL1', 60, (26, 40), 8, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 66), 12, False),
                Via('PTIE', 'METAL1', 100, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nsnrlatch_x4', width=220, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 40, (34, 66), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 80, (34, 66), 12, False),
            ],
            'nq': [
                Wire('NDIF', 180, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 180, 60, 2),
                Wire('METAL1', 180, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'nq_i': [
                Device('nmos', 50, 50, 4, 40, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 50, (76, 130), 4, False),
                Device('pmos', 50, 150, 4, 40, 'vertical', source_net='q_i', drain_net='vdd'),
                Via('POLY', 'METAL1', 54, 90, 2),
                Wire('METAL1', (54, 80), 90, 6, False),
                Wire('METAL1', 80, (60, 158), 6, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('PDIF', 80, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Via('NDIF', 'METAL1', 98, 60, 2),
                Wire('NDIF', 100, (34, 66), 8, False),
                Wire('METAL1', (82, 120), 60, 6, False),
                Wire('METAL1', 120, (62, 90), 6, False),
                Via('POLY', 'METAL1', 124, 90, 2),
                Device('nmos', 130, 50, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 130, (56, 104), 4, False),
                Device('pmos', 130, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (130, 150), 90, 8, False),
                Device('nmos', 150, 50, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 150, (56, 128), 4, False),
                Device('pmos', 150, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'nrst': [
                Device('nmos', 90, 50, 4, 40, 'vertical', source_net='_net1', drain_net='nq_i'),
                Wire('POLY', 90, (74, 124), 4, False),
                Device('pmos', 90, 150, 4, 40, 'vertical', source_net='nq_i', drain_net='vdd'),
                Via('POLY', 'METAL1', 96, 110, 2),
                Wire('METAL1', 100, (82, 138), 6, True),
            ],
            'nset': [
                Wire('METAL1', 20, (62, 138), 6, True),
                Via('POLY', 'METAL1', 22, 90, 2),
                Device('nmos', 28, 50, 4, 40, 'vertical', source_net='q_i', drain_net='_net0'),
                Wire('POLY', 28, (74, 124), 4, False),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='vdd', drain_net='q_i'),
            ],
            'q': [
                Wire('NDIF', 140, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 140, 60, 2),
                Wire('METAL1', 140, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('PDIF', 140, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
            ],
            'q_i': [
                Via('NDIF', 'METAL1', 18, 40, 2),
                Wire('NDIF', 18, (34, 66), 12, False),
                Wire('METAL1', 40, (40, 158), 6, False),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
                Wire('METAL1', (40, 66), 110, 6, False),
                Via('POLY', 'METAL1', 66, 110, 2),
                Device('nmos', 70, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 70, (76, 130), 4, False),
                Device('pmos', 70, 150, 4, 40, 'vertical', source_net='vdd', drain_net='nq_i'),
                Wire('METAL1', (20, 200), 40, 6, False),
                Device('nmos', 170, 50, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 170, (56, 128), 4, False),
                Device('pmos', 170, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (170, 190), 90, 8, False),
                Device('nmos', 190, 50, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 190, (56, 104), 4, False),
                Device('pmos', 190, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
                Via('POLY', 'METAL1', 196, 90, 2),
                Wire('METAL1', 200, (40, 90), 6, False),
            ],
            'vdd': [
                Wire('PDIF', 16, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', 20, (160, 174), 8, False),
                Via('NTIE', 'METAL1', 20, 186, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', 60, (160, 174), 8, False),
                Wire('NTIE', (20, 100), 186, 12, False),
                Via('NTIE', 'METAL1', 60, 186, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('METAL1', 100, (160, 174), 8, False),
                Via('NTIE', 'METAL1', 100, 186, 2),
                Wire('PDIF', 110, (134, 166), 32, False),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 120, 184, 2),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', 160, (122, 178), 6, False),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Via('PDIF', 'METAL1', 160, 184, 2),
                Wire('PDIF', 200, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 200, 184, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 30, 14, 2),
                Via('NDIF', 'METAL1', 60, 14, 2),
                Wire('NDIF', 60, (14, 66), 10, False),
                Via('PTIE', 'METAL1', 90, 14, 2),
                Via('NDIF', 'METAL1', 120, 14, 2),
                Wire('NDIF', 120, (14, 65), 10, False),
                Via('NDIF', 'METAL1', 160, 14, 2),
                Wire('NDIF', 160, (14, 65), 10, False),
                Via('NDIF', 'METAL1', 200, 14, 2),
                Wire('NDIF', 200, (14, 65), 10, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nts_x1', width=120, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 36, (114, 186), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            '_net2': [
                Wire('POLY', 48, (104, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', (48, 80), 102, 4, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 84, (34, 46), 12, False),
                Wire('METAL1', 84, (42, 138), 6, False),
                Via('POLY', 'METAL1', 84, 102, 2),
                Via('PDIF', 'METAL1', 84, 120, 2),
                Wire('PDIF', 84, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 84, 140, 2),
            ],
            'cmd': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Device('nmos', 46, 31, 4, 38, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', 46, (56, 80), 4, False),
                Wire('POLY', (40, 96), 80, 4, False),
                Device('nmos', 96, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 130, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
            ],
            'i': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'nq': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Via('NTIE', 'METAL1', 86, 184, 2),
                Wire('NTIE', (78, 102), 184, 12, False),
                Via('NTIE', 'METAL1', 102, 184, 2),
                Via('PDIF', 'METAL1', 104, 120, 2),
                Via('PDIF', 'METAL1', 104, 140, 2),
                Wire('METAL1', 104, (122, 186), 6, False),
                Wire('PDIF', 106, (114, 146), 8, False),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('METAL1', 104, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 104, 40, 2),
                Wire('NDIF', 106, (34, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nts_x2', width=160, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 36, (114, 186), 12, False),
            ],
            '_net1': [
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net0', drain_net='nq'),
                Wire('POLY', (48, 80), 102, 4, False),
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net3'),
                Via('POLY', 'METAL1', 80, 98, 2),
                Wire('METAL1', 80, (102, 158), 6, False),
                Wire('METAL1', (82, 146), 160, 6, False),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Via('NDIF', 'METAL1', 142, 40, 2),
                Wire('NDIF', 142, (34, 46), 8, False),
                Wire('METAL1', 146, (42, 158), 6, False),
                Wire('PDIF', 146, (114, 146), 8, False),
            ],
            '_net2': [
                Wire('NDIF', 84, (16, 46), 12, False),
            ],
            '_net3': [
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            '_net4': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            'cmd': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net4', drain_net='nq'),
                Wire('POLY', 48, (50, 58), 4, False),
                Wire('POLY', (48, 80), 58, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net2'),
                Wire('POLY', 72, (52, 58), 4, False),
                Via('POLY', 'METAL1', 84, 60, 2),
                Wire('METAL1', (82, 118), 60, 6, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (42, 138), 6, True),
                Wire('POLY', (120, 132), 80, 8, False),
                Device('nmos', 128, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 128, (54, 58), 4, False),
                Wire('POLY', (128, 132), 58, 4, False),
                Wire('POLY', 132, (60, 104), 4, False),
                Device('pmos', 132, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i': [
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net0'),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Wire('POLY', (24, 96), 80, 4, False),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net3', drain_net='vdd'),
            ],
            'nq': [
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 120, 2),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Via('PDIF', 'METAL1', 104, 184, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
                Wire('PDIF', 118, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 120, 184, 2),
                Wire('NTIE', 144, (166, 180), 12, False),
                Via('NTIE', 'METAL1', 144, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('METAL1', 16, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('NDIF', 'METAL1', 108, 18, 2),
                Wire('NDIF', 112, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nxr2_x1', width=180, height=200,
        nets={
            '_net0': [
                Via('POLY', 'METAL1', 12, 80, 2),
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('POLY', (12, 96), 80, 4, False),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='nq', drain_net='_net2'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net1'),
            ],
            '_net1': [
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 108, 120, 2),
                Wire('METAL1', 108, (122, 158), 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net2': [
                Wire('NDIF', 108, (16, 46), 12, False),
            ],
            '_net3': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net4', drain_net='nq'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', (72, 82), 58, 4, False),
                Via('POLY', 'METAL1', 84, 60, 2),
                Wire('METAL1', (82, 98), 60, 6, False),
                Wire('METAL1', 100, (62, 78), 6, False),
                Wire('METAL1', (102, 118), 80, 6, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('POLY', 120, (80, 104), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (120, 160), 80, 4, False),
                Wire('NDIF', 152, (34, 46), 4, False),
                Wire('PDIF', 152, (134, 166), 4, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('NDIF', 160, (34, 46), 12, False),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', 160, (142, 158), 6, False),
                Wire('PDIF', 160, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            '_net4': [
                Wire('NDIF', 60, (16, 46), 12, False),
            ],
            'i0': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (50, 56), 4, False),
                Wire('POLY', 24, (104, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 48), 56, 4, False),
                Wire('POLY', (24, 48), 104, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 48, (50, 56), 4, False),
                Wire('POLY', 48, (104, 110), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='nq'),
                Wire('POLY', (72, 82), 102, 4, False),
                Via('POLY', 'METAL1', 84, 100, 2),
                Wire('METAL1', (82, 138), 100, 6, False),
                Device('nmos', 120, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 120, (54, 56), 4, False),
                Wire('POLY', (120, 148), 56, 4, False),
                Via('POLY', 'METAL1', 140, 60, 2),
                Wire('METAL1', 140, (42, 158), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Wire('POLY', (138, 148), 104, 4, False),
                Device('nmos', 148, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 148, (52, 54), 4, False),
                Wire('POLY', 148, (104, 124), 4, False),
                Device('pmos', 148, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'nq': [
                Wire('METAL1', 60, (42, 138), 6, True),
                Wire('METAL1', (60, 82), 40, 6, False),
                Wire('METAL1', (60, 82), 140, 6, False),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Wire('PDIF', 132, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 132, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 132, 18, 2),
                Wire('NDIF', 132, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='nxr2_x4', width=240, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 60, (16, 46), 12, False),
            ],
            '_net1': [
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 160, 6, False),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net2': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (114, 146), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (42, 118), 6, False),
                Via('POLY', 'METAL1', 16, 80, 2),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Wire('POLY', (14, 96), 80, 4, False),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='_net3', drain_net='_net5'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net1'),
            ],
            '_net3': [
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('METAL1', (62, 82), 140, 6, False),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (62, 178), 40, 6, False),
                Wire('METAL1', 180, (42, 78), 6, False),
                Via('POLY', 'METAL1', 180, 80, 2),
                Device('nmos', 192, 31, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 192, (56, 104), 4, False),
                Device('pmos', 192, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (180, 216), 80, 8, False),
                Device('nmos', 216, 31, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 216, (56, 104), 4, False),
                Device('pmos', 216, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            '_net4': [
                Wire('POLY', 72, (104, 106), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net3'),
                Wire('POLY', (72, 82), 102, 4, False),
                Via('POLY', 'METAL1', 84, 100, 2),
                Wire('METAL1', (82, 98), 100, 6, False),
                Wire('METAL1', 100, (82, 98), 6, False),
                Wire('METAL1', (102, 118), 80, 6, False),
                Device('nmos', 120, 31, 4, 38, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 120, (56, 80), 4, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('POLY', (120, 160), 80, 4, False),
                Wire('PDIF', 156, (114, 146), 12, False),
                Wire('NDIF', 158, (34, 62), 8, False),
                Via('NDIF', 'METAL1', 160, 60, 2),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (62, 114), 6, False),
                Via('PDIF', 'METAL1', 160, 116, 2),
            ],
            '_net5': [
                Wire('NDIF', 108, (16, 46), 12, False),
            ],
            'i0': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 24, (50, 56), 4, False),
                Wire('POLY', 24, (104, 110), 4, False),
                Device('pmos', 24, 130, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (24, 48), 56, 4, False),
                Wire('POLY', (24, 48), 104, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 48, (50, 56), 4, False),
                Wire('POLY', 48, (104, 110), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'i1': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net3'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', (72, 82), 58, 4, False),
                Via('POLY', 'METAL1', 84, 60, 2),
                Wire('METAL1', (82, 138), 60, 6, False),
                Wire('POLY', 120, (104, 108), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (120, 144), 102, 4, False),
                Via('POLY', 'METAL1', 140, 60, 2),
                Via('POLY', 'METAL1', 140, 100, 2),
                Wire('METAL1', 140, (62, 158), 6, True),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 144, (54, 62), 4, False),
                Wire('POLY', 144, (104, 108), 4, False),
                Device('pmos', 144, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net4'),
            ],
            'nq': [
                Via('NDIF', 'METAL1', 200, 40, 2),
                Wire('METAL1', 200, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Wire('NDIF', 204, (16, 46), 12, False),
                Wire('PDIF', 204, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('NTIE', 16, (166, 182), 12, False),
                Via('NTIE', 'METAL1', 16, 184, 2),
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Via('PDIF', 'METAL1', 128, 184, 2),
                Wire('PDIF', 130, (114, 186), 8, False),
                Wire('NTIE', 156, (166, 182), 12, False),
                Via('NTIE', 'METAL1', 156, 182, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (142, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Wire('PDIF', 180, (138, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Via('PDIF', 'METAL1', 224, 120, 2),
                Via('PDIF', 'METAL1', 224, 140, 2),
                Wire('METAL1', 224, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 224, 160, 2),
                Via('PDIF', 'METAL1', 224, 184, 2),
                Wire('PDIF', 226, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 128, 18, 2),
                Wire('NDIF', 130, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('NDIF', 180, (16, 38), 12, False),
                Via('NDIF', 'METAL1', 224, 18, 2),
                Wire('METAL1', 224, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 224, 40, 2),
                Wire('NDIF', 226, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o2_x2', width=100, height=200,
        nets={
            '_net1': [
                Wire('PDIF', 14, (114, 166), 8, False),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', (20, 36), 160, 6, False),
                Wire('NDIF', 36, (34, 46), 12, False),
                Via('NDIF', 'METAL1', 38, 40, 2),
                Wire('METAL1', 38, (42, 158), 6, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', (40, 72), 80, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i0': [
                Wire('POLY', 46, (102, 106), 4, False),
                Device('pmos', 46, 140, 4, 60, 'vertical', source_net='_net0', drain_net='vdd'),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 48, (54, 58), 4, False),
                Wire('POLY', (48, 54), 58, 4, False),
                Wire('POLY', (46, 58), 102, 4, False),
                Via('POLY', 'METAL1', 60, 60, 2),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('METAL1', 60, (42, 160), 6, True),
            ],
            'i1': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (60, 140), 6, True),
                Wire('POLY', 26, (76, 84), 4, False),
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 28, (56, 104), 4, False),
                Device('pmos', 28, 140, 4, 60, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('NDIF', 84, (16, 46), 8, False),
                Wire('PDIF', 84, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 60, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 64, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('METAL1', 20, (24, 38), 6, False),
                Via('NDIF', 'METAL1', 20, 38, 2),
                Wire('NDIF', 60, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 64, 18, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o2_x4', width=120, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', (22, 36), 160, 6, False),
                Wire('NDIF', 36, (34, 46), 12, False),
                Wire('METAL1', 38, (42, 158), 6, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', (40, 96), 80, 4, False),
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 72, (56, 104), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 48, (54, 58), 4, False),
                Wire('POLY', 48, (102, 106), 4, False),
                Device('pmos', 48, 140, 4, 60, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (48, 60), 60, 8, False),
                Wire('POLY', (48, 60), 102, 8, False),
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('METAL1', 60, (40, 160), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'i1': [
                Wire('POLY', 20, (56, 102), 4, False),
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (60, 140), 6, True),
                Wire('POLY', (20, 28), 56, 4, False),
                Wire('POLY', (20, 30), 102, 4, False),
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 30, (102, 108), 4, False),
                Device('pmos', 30, 140, 4, 60, 'vertical', source_net='_net0', drain_net='_net1'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 80, 120, 2),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Via('PDIF', 'METAL1', 80, 160, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 62, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 64, 184, 2),
                Via('PDIF', 'METAL1', 104, 120, 2),
                Via('PDIF', 'METAL1', 104, 140, 2),
                Wire('METAL1', 104, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 104, 160, 2),
                Via('PDIF', 'METAL1', 104, 184, 2),
                Wire('PDIF', 106, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('METAL1', 20, (22, 40), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Wire('NDIF', 62, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 64, 18, 2),
                Via('NDIF', 'METAL1', 104, 18, 2),
                Wire('METAL1', 104, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 104, 40, 2),
                Wire('NDIF', 106, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o3_x2', width=120, height=200,
        nets={
            '_net1': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (114, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (40, 58), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 78), 160, 6, False),
                Wire('METAL1', (18, 78), 60, 6, False),
                Via('NDIF', 'METAL1', 52, 40, 2),
                Wire('METAL1', 52, (40, 60), 6, False),
                Wire('NDIF', 54, (34, 46), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 158), 6, False),
                Wire('POLY', (80, 90), 80, 8, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 60, (102, 106), 4, False),
                Wire('METAL1', 60, (80, 140), 6, True),
                Device('pmos', 60, 140, 4, 60, 'vertical', source_net='_net2', drain_net='vdd'),
                Device('nmos', 64, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 64, (56, 98), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (80, 140), 6, True),
                Device('nmos', 42, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 42, (56, 104), 4, False),
                Device('pmos', 42, 140, 4, 60, 'vertical', source_net='_net0', drain_net='_net2'),
            ],
            'i2': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (80, 140), 6, True),
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 140, 4, 60, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 106, (16, 46), 8, False),
                Wire('PDIF', 106, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 74, (114, 186), 8, False),
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
            ],
            'vss': [
                Wire('METAL1', 34, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 34, 40, 2),
                Wire('NDIF', 36, (34, 46), 8, False),
                Wire('METAL1', 76, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 76, 40, 2),
                Wire('NDIF', 76, (34, 46), 6, False),
                Wire('NDIF', 82, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o3_x4', width=140, height=200,
        nets={
            '_net2': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (114, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 78), 160, 6, False),
                Wire('METAL1', (18, 78), 40, 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (42, 158), 6, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (82, 116), 80, 8, False),
                Device('nmos', 116, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 116, (56, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Wire('METAL1', 60, (62, 138), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('POLY', 62, (100, 106), 4, False),
                Device('pmos', 62, 140, 4, 60, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', 64, (60, 100), 4, False),
                Wire('POLY', (64, 70), 58, 4, False),
                Device('nmos', 70, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 70, (52, 58), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 138), 6, True),
                Wire('POLY', 44, (60, 104), 4, False),
                Device('pmos', 44, 140, 4, 60, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (44, 52), 58, 4, False),
                Device('nmos', 52, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 52, (52, 58), 4, False),
            ],
            'i2': [
                Via('POLY', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 140, 4, 60, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 104, (16, 46), 12, False),
                Wire('PDIF', 104, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 76, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 80, 184, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 124, 120, 2),
                Via('PDIF', 'METAL1', 124, 140, 2),
                Wire('METAL1', 124, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 124, 160, 2),
                Via('PDIF', 'METAL1', 124, 184, 2),
                Wire('PDIF', 126, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 38, 18, 2),
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 84, 18, 2),
                Wire('NDIF', 84, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 124, 18, 2),
                Wire('METAL1', 124, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 124, 40, 2),
                Wire('NDIF', 126, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o4_x2', width=140, height=200,
        nets={
            '_net2': [
                Wire('PDIF', 14, (114, 166), 8, False),
                Via('PDIF', 'METAL1', 18, 160, 2),
                Wire('NDIF', 36, (34, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (40, 58), 6, False),
                Wire('METAL1', (18, 100), 160, 6, False),
                Wire('METAL1', (40, 100), 60, 6, False),
                Via('NDIF', 'METAL1', 82, 40, 2),
                Wire('METAL1', 82, (40, 60), 6, False),
                Wire('NDIF', 84, (34, 46), 8, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 102, (62, 158), 6, False),
                Wire('POLY', (96, 112), 80, 8, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 112, (56, 104), 4, False),
                Device('pmos', 112, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i0': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (82, 138), 6, True),
                Wire('POLY', 62, (78, 104), 4, False),
                Device('pmos', 62, 140, 4, 60, 'vertical', source_net='_net3', drain_net='_net0'),
                Wire('POLY', 64, (60, 82), 4, False),
                Wire('POLY', (64, 72), 58, 4, False),
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 72, (52, 58), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (60, 100), 4, False),
                Wire('METAL1', 40, (82, 138), 6, True),
                Wire('POLY', (40, 44), 102, 4, False),
                Wire('POLY', (40, 48), 58, 4, False),
                Wire('POLY', 44, (102, 108), 4, False),
                Device('pmos', 44, 140, 4, 60, 'vertical', source_net='_net1', drain_net='_net3'),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 48, (52, 58), 4, False),
            ],
            'i2': [
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (102, 108), 4, False),
                Wire('METAL1', 80, (82, 138), 6, True),
                Device('pmos', 80, 140, 4, 60, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (80, 84), 102, 4, False),
                Wire('POLY', 84, (60, 100), 4, False),
                Wire('POLY', (84, 90), 58, 4, False),
                Device('nmos', 90, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 90, (52, 58), 4, False),
            ],
            'i3': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', 24, (60, 102), 4, False),
                Wire('POLY', (24, 26), 58, 4, False),
                Wire('POLY', (24, 26), 102, 4, False),
                Device('nmos', 26, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 26, (52, 58), 4, False),
                Wire('POLY', 26, (102, 108), 4, False),
                Device('pmos', 26, 140, 4, 60, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Via('PDIF', 'METAL1', 120, 160, 2),
                Wire('NDIF', 126, (16, 46), 8, False),
                Wire('PDIF', 126, (114, 186), 8, False),
            ],
            'vdd': [
                Wire('PDIF', 94, (114, 186), 8, False),
                Wire('PDIF', 100, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 104, 184, 2),
                Wire('PDIF', 106, (114, 186), 4, False),
            ],
            'vss': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('METAL1', 18, (24, 38), 6, False),
                Via('NDIF', 'METAL1', 18, 38, 2),
                Wire('NDIF', 58, (34, 46), 8, False),
                Wire('METAL1', 60, (26, 40), 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', 100, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('NDIF', 102, (34, 46), 4, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='o4_x4', width=160, height=200,
        nets={
            '_net1': [
                Wire('METAL1', 20, (42, 118), 6, False),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Wire('METAL1', 20, (122, 158), 6, False),
                Wire('PDIF', 20, (114, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('PDIF', 28, (114, 186), 12, False),
                Via('NDIF', 'METAL1', 36, 40, 2),
                Wire('NDIF', 36, (34, 46), 8, False),
                Wire('METAL1', (22, 98), 40, 6, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 84, (34, 46), 8, False),
                Wire('METAL1', 100, (42, 58), 6, False),
                Wire('METAL1', (102, 118), 60, 6, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 112, (52, 58), 4, False),
                Wire('POLY', 112, (102, 108), 4, False),
                Device('pmos', 112, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (112, 116), 58, 4, False),
                Via('POLY', 'METAL1', 124, 60, 2),
                Wire('METAL1', 124, (62, 98), 6, False),
                Via('POLY', 'METAL1', 124, 100, 2),
                Wire('POLY', (112, 136), 102, 4, False),
                Wire('POLY', (118, 136), 58, 4, False),
                Device('nmos', 136, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 136, (52, 58), 4, False),
                Wire('POLY', 136, (102, 108), 4, False),
                Device('pmos', 136, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Device('nmos', 46, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 46, (56, 76), 4, False),
                Wire('POLY', (48, 60), 76, 4, False),
                Wire('POLY', 56, (80, 100), 4, False),
                Wire('POLY', (56, 58), 102, 4, False),
                Wire('POLY', 58, (102, 108), 4, False),
                Device('pmos', 58, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 28, (56, 96), 4, False),
                Wire('POLY', (28, 40), 96, 4, False),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', 40, (100, 108), 4, False),
                Wire('METAL1', 40, (62, 158), 6, True),
                Device('pmos', 40, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net2'),
            ],
            'i2': [
                Device('nmos', 74, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 74, (52, 58), 4, False),
                Wire('POLY', (74, 76), 58, 4, False),
                Wire('POLY', 76, (60, 104), 4, False),
                Device('pmos', 76, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net3'),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 158), 6, True),
            ],
            'i3': [
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 92, (52, 58), 4, False),
                Wire('POLY', (92, 96), 58, 4, False),
                Wire('POLY', 94, (102, 108), 4, False),
                Device('pmos', 94, 150, 4, 80, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (94, 96), 102, 4, False),
                Wire('POLY', 96, (60, 100), 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (82, 158), 6, True),
            ],
            'q': [
                Via('NDIF', 'METAL1', 120, 40, 2),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Wire('METAL1', 120, (122, 158), 6, False),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Via('PDIF', 'METAL1', 120, 160, 2),
                Wire('PDIF', 124, (114, 186), 12, False),
                Wire('NDIF', 126, (16, 46), 8, False),
                Wire('METAL1', (126, 138), 40, 6, False),
                Wire('METAL1', (126, 138), 120, 6, False),
                Wire('METAL1', 140, (42, 120), 6, True),
            ],
            'vdd': [
                Wire('PDIF', 100, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 102, 184, 2),
                Via('PDIF', 'METAL1', 144, 140, 2),
                Wire('METAL1', 144, (142, 178), 6, False),
                Via('PDIF', 'METAL1', 144, 160, 2),
                Via('PDIF', 'METAL1', 144, 184, 2),
                Wire('PDIF', 146, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Via('NDIF', 'METAL1', 60, 18, 2),
                Wire('NDIF', 60, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 104, 18, 2),
                Wire('NDIF', 106, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 144, 18, 2),
                Wire('NDIF', 146, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa22_x2', width=120, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 36, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 38, 140, 2),
                Wire('METAL1', (38, 58), 140, 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 8, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('POLY', (60, 92), 80, 4, False),
                Device('nmos', 92, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 92, (56, 104), 4, False),
                Device('pmos', 92, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net1': [
                Wire('PDIF', 18, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('METAL1', 20, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Wire('METAL1', (14, 58), 160, 6, False),
                Wire('PDIF', 60, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            '_net2': [
                Wire('NDIF', 36, (16, 46), 8, False),
            ],
            'i0': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('POLY', 20, (56, 124), 4, False),
                Wire('POLY', (20, 28), 56, 4, False),
                Wire('POLY', (20, 28), 124, 4, False),
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net2'),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
                Wire('POLY', (40, 48), 124, 4, False),
                Wire('POLY', (40, 50), 56, 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net0', drain_net='_net1'),
                Device('nmos', 50, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net0'),
            ],
            'i2': [
                Device('nmos', 68, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 68, (54, 58), 4, False),
                Wire('POLY', 68, (100, 124), 4, False),
                Device('pmos', 68, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (68, 76), 60, 8, False),
                Wire('POLY', (72, 80), 100, 8, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
                Via('POLY', 'METAL1', 80, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
                Wire('NDIF', 104, (16, 46), 12, False),
                Wire('PDIF', 104, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 82, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 18, 18, 2),
                Via('NDIF', 'METAL1', 84, 18, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa22_x4', width=160, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (134, 166), 8, False),
                Wire('METAL1', (38, 58), 140, 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('POLY', (60, 132), 80, 6, False),
                Device('nmos', 108, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 108, (56, 104), 4, False),
                Device('pmos', 108, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 132, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 132, (56, 104), 4, False),
                Device('pmos', 132, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('PDIF', 16, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 58), 160, 6, False),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
            ],
            '_net2': [
                Wire('NDIF', 36, (34, 46), 12, False),
            ],
            'i0': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('POLY', 20, (56, 124), 4, False),
                Wire('POLY', (20, 28), 56, 4, False),
                Wire('POLY', (20, 28), 124, 4, False),
                Device('nmos', 28, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net2'),
                Device('pmos', 28, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
                Wire('POLY', (40, 48), 56, 4, False),
                Wire('POLY', (40, 48), 124, 4, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net0'),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net0', drain_net='_net1'),
            ],
            'i2': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 72, (106, 124), 4, False),
                Device('pmos', 72, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (72, 80), 56, 4, False),
                Wire('POLY', (72, 80), 104, 4, False),
                Via('POLY', 'METAL1', 80, 60, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
                Via('POLY', 'METAL1', 80, 100, 2),
            ],
            'q': [
                Wire('NDIF', 120, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 120, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 88, (114, 186), 12, False),
                Wire('PDIF', 92, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 92, 184, 2),
                Wire('PDIF', 100, (114, 186), 4, False),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('PDIF', 142, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 142, 160, 2),
                Via('PDIF', 'METAL1', 142, 184, 2),
                Wire('METAL1', 144, (122, 178), 6, False),
            ],
            'vss': [
                Wire('NDIF', 14, (18, 46), 8, False),
                Via('NDIF', 'METAL1', 18, 18, 2),
                Wire('NDIF', 88, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 92, 18, 2),
                Wire('NDIF', 92, (16, 46), 12, False),
                Wire('NDIF', 100, (16, 46), 4, False),
                Via('NDIF', 'METAL1', 140, 18, 2),
                Wire('METAL1', 140, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 140, 40, 2),
                Wire('NDIF', 142, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a22_x2', width=180, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 36, (34, 46), 12, False),
            ],
            '_net1': [
                Wire('NDIF', 84, (34, 46), 12, False),
            ],
            '_net2': [
                Wire('PDIF', 36, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 38, 140, 2),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('METAL1', (38, 138), 140, 6, False),
                Via('POLY', 'METAL1', 140, 80, 2),
                Wire('POLY', 140, (56, 104), 4, False),
                Wire('METAL1', 140, (82, 138), 6, False),
                Wire('POLY', (140, 148), 56, 4, False),
                Wire('POLY', (140, 148), 104, 4, False),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Device('pmos', 148, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net3': [
                Wire('PDIF', 14, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 20, 156, 2),
                Wire('PDIF', 60, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 60, 156, 2),
                Wire('METAL1', (22, 106), 156, 6, False),
                Wire('PDIF', 108, (130, 162), 8, False),
                Via('PDIF', 'METAL1', 108, 156, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('POLY', 20, (56, 118), 4, False),
                Wire('METAL1', 20, (62, 118), 6, True),
                Wire('POLY', (20, 28), 56, 4, False),
                Wire('POLY', (20, 28), 120, 4, False),
                Device('nmos', 28, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Device('pmos', 28, 146, 4, 40, 'vertical', source_net='_net3', drain_net='_net2'),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (56, 118), 4, False),
                Wire('POLY', (40, 48), 56, 4, False),
                Wire('POLY', (40, 48), 120, 4, False),
                Device('nmos', 48, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net2'),
                Device('pmos', 48, 146, 4, 40, 'vertical', source_net='_net2', drain_net='_net3'),
            ],
            'i2': [
                Wire('POLY', 68, (56, 114), 4, False),
                Wire('POLY', 68, (116, 122), 4, False),
                Device('pmos', 68, 146, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (68, 72), 56, 4, False),
                Device('nmos', 72, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', (72, 80), 80, 8, False),
                Wire('METAL1', 80, (42, 118), 6, True),
                Via('POLY', 'METAL1', 80, 80, 2),
            ],
            'i3': [
                Device('nmos', 96, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 96, (52, 58), 4, False),
                Wire('POLY', (96, 100), 58, 4, False),
                Wire('METAL1', 100, (42, 118), 6, True),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('POLY', 100, (60, 124), 4, False),
                Device('pmos', 100, 146, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'q': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 84, (130, 178), 12, False),
                Via('PDIF', 'METAL1', 84, 182, 2),
                Wire('PDIF', 136, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 136, 160, 2),
                Wire('METAL1', 136, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 136, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('METAL1', 20, (22, 40), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Via('NDIF', 'METAL1', 112, 18, 2),
                Wire('NDIF', 112, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 18, 2),
                Wire('METAL1', 136, (22, 38), 6, False),
                Wire('NDIF', 136, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a22_x4', width=200, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (134, 166), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', 60, (42, 138), 6, False),
                Wire('METAL1', (38, 138), 140, 6, False),
                Wire('METAL1', 140, (82, 138), 6, False),
                Via('POLY', 'METAL1', 142, 82, 2),
                Device('nmos', 148, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 148, (56, 104), 4, False),
                Device('pmos', 148, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (140, 172), 82, 8, False),
                Device('nmos', 172, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 172, (56, 104), 4, False),
                Device('pmos', 172, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('NDIF', 84, (34, 46), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 40, (34, 46), 12, False),
            ],
            '_net3': [
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Wire('METAL1', (14, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('PDIF', 108, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            'i0': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('POLY', 24, (60, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net3', drain_net='_net0'),
                Wire('POLY', (24, 30), 58, 4, False),
                Device('nmos', 30, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 30, (52, 58), 4, False),
            ],
            'i1': [
                Wire('METAL1', 40, (42, 118), 6, True),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (60, 124), 4, False),
                Wire('POLY', (40, 48), 124, 4, False),
                Wire('POLY', (40, 52), 58, 4, False),
                Device('pmos', 48, 150, 4, 40, 'vertical', source_net='_net0', drain_net='_net3'),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('POLY', 52, (52, 58), 4, False),
            ],
            'i2': [
                Device('pmos', 68, 150, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Device('nmos', 74, 40, 4, 20, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (68, 80), 124, 4, False),
                Wire('POLY', (74, 80), 56, 4, False),
                Wire('METAL1', 80, (42, 118), 6, True),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (60, 120), 4, False),
            ],
            'i3': [
                Device('nmos', 92, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 92, (52, 58), 4, False),
                Wire('POLY', (92, 96), 58, 4, False),
                Wire('POLY', 96, (60, 120), 4, False),
                Wire('POLY', (96, 100), 122, 4, False),
                Wire('METAL1', 100, (42, 118), 6, True),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('POLY', 100, (122, 128), 4, False),
                Device('pmos', 100, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'q': [
                Wire('NDIF', 160, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('METAL1', 160, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 84, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
                Wire('PDIF', 136, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 136, 160, 2),
                Wire('METAL1', 136, (162, 178), 6, False),
                Via('PDIF', 'METAL1', 136, 184, 2),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Wire('PDIF', 182, (114, 186), 12, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 16, 16, 2),
                Wire('NDIF', 16, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 108, 18, 2),
                Wire('NDIF', 108, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 18, 2),
                Wire('METAL1', 136, (22, 38), 6, False),
                Wire('NDIF', 136, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 136, 40, 2),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('METAL1', 180, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 182, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a2a23_x2', width=240, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 16, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (18, 106), 160, 6, False),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net1': [
                Wire('METAL1', 20, (42, 136), 6, False),
                Wire('METAL1', (22, 34), 138, 6, False),
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (22, 198), 40, 6, False),
                Wire('NDIF', 156, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 156, 40, 2),
                Wire('METAL1', 196, (42, 78), 6, False),
                Via('POLY', 'METAL1', 196, 80, 2),
                Wire('POLY', (200, 208), 80, 8, False),
                Device('nmos', 208, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 208, (56, 104), 4, False),
                Device('pmos', 208, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net2': [
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (86, 170), 140, 6, False),
                Wire('METAL1', 172, (142, 158), 6, False),
                Wire('PDIF', 172, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 172, 160, 2),
            ],
            'i0': [
                Wire('METAL1', 180, (62, 118), 6, True),
                Via('POLY', 'METAL1', 180, 100, 2),
                Device('nmos', 184, 31, 4, 38, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 184, (56, 104), 4, False),
                Device('pmos', 184, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
            ],
            'i1': [
                Wire('POLY', 160, (60, 100), 4, False),
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Wire('POLY', 160, (102, 106), 4, False),
                Device('pmos', 160, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net2'),
                Wire('POLY', (160, 166), 58, 4, False),
                Device('nmos', 166, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net4'),
                Wire('POLY', 166, (52, 58), 4, False),
            ],
            'i2': [
                Device('nmos', 90, 31, 4, 38, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 90, (54, 58), 4, False),
                Wire('POLY', (90, 96), 58, 4, False),
                Wire('POLY', 96, (60, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'i3': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net3'),
                Wire('POLY', 72, (52, 58), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', (72, 76), 58, 4, False),
                Wire('POLY', 76, (60, 102), 4, False),
                Wire('POLY', (72, 80), 104, 4, False),
                Wire('METAL1', 80, (62, 118), 6, True),
                Via('POLY', 'METAL1', 80, 100, 2),
            ],
            'i4': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net5', drain_net='_net1'),
                Wire('POLY', 48, (54, 58), 4, False),
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (48, 56), 58, 4, False),
                Wire('POLY', (48, 56), 102, 4, False),
                Wire('POLY', 56, (60, 100), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
            ],
            'i5': [
                Wire('POLY', 24, (102, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (24, 36), 102, 4, False),
                Device('nmos', 32, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net5'),
                Wire('POLY', 32, (54, 58), 4, False),
                Wire('POLY', (32, 36), 58, 4, False),
                Wire('POLY', 36, (60, 100), 4, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 118), 6, True),
            ],
            'q': [
                Wire('NDIF', 220, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Wire('METAL1', 220, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 220, 120, 2),
                Via('PDIF', 'METAL1', 220, 140, 2),
                Wire('PDIF', 220, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 220, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 148, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 148, 160, 2),
                Wire('METAL1', 148, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 148, 184, 2),
                Via('PDIF', 'METAL1', 196, 140, 2),
                Wire('PDIF', 196, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 196, 160, 2),
                Wire('METAL1', 196, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 196, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 18, 2),
                Wire('NDIF', 20, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 128, 16, 2),
                Wire('PTIE', 128, (20, 34), 12, False),
                Via('NDIF', 'METAL1', 196, 18, 2),
                Wire('NDIF', 196, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a2a23_x4', width=260, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Wire('METAL1', (14, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net1': [
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (86, 170), 140, 6, False),
                Wire('METAL1', 172, (142, 158), 6, False),
                Wire('PDIF', 172, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 172, 160, 2),
            ],
            '_net2': [
                Wire('METAL1', 20, (42, 136), 6, False),
                Wire('METAL1', (22, 34), 138, 6, False),
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (22, 198), 40, 6, False),
                Wire('NDIF', 156, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 156, 40, 2),
                Wire('METAL1', 198, (42, 78), 6, False),
                Via('POLY', 'METAL1', 200, 78, 2),
                Device('nmos', 206, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 206, (56, 104), 4, False),
                Device('pmos', 206, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (200, 232), 80, 4, False),
                Device('nmos', 232, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 232, (56, 104), 4, False),
                Device('pmos', 232, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Wire('METAL1', 180, (62, 118), 6, True),
                Via('POLY', 'METAL1', 180, 100, 2),
                Device('nmos', 184, 31, 4, 38, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 184, (56, 104), 4, False),
                Device('pmos', 184, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
            ],
            'i1': [
                Wire('POLY', 160, (60, 114), 4, False),
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Device('pmos', 160, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
                Wire('POLY', (160, 166), 58, 4, False),
                Device('nmos', 166, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net4'),
                Wire('POLY', 166, (54, 58), 4, False),
            ],
            'i2': [
                Device('nmos', 88, 31, 4, 38, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 88, (52, 58), 4, False),
                Wire('POLY', (88, 96), 58, 4, False),
                Wire('POLY', 96, (60, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'i3': [
                Device('nmos', 70, 31, 4, 38, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('POLY', 70, (54, 58), 4, False),
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Wire('POLY', (70, 76), 58, 4, False),
                Wire('POLY', (72, 76), 102, 4, False),
                Wire('POLY', 76, (62, 100), 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 118), 6, True),
            ],
            'i4': [
                Wire('POLY', 48, (102, 108), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
                Device('nmos', 50, 31, 4, 38, 'vertical', source_net='_net5', drain_net='_net2'),
                Wire('POLY', 50, (52, 58), 4, False),
                Wire('POLY', (48, 56), 102, 4, False),
                Wire('POLY', (50, 56), 58, 4, False),
                Wire('POLY', 56, (60, 100), 4, False),
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
            ],
            'i5': [
                Wire('POLY', 24, (102, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', (24, 36), 102, 4, False),
                Device('nmos', 32, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net5'),
                Wire('POLY', 32, (52, 58), 4, False),
                Wire('POLY', (32, 36), 58, 4, False),
                Wire('POLY', 36, (60, 100), 4, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 118), 6, True),
            ],
            'q': [
                Wire('NDIF', 220, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Wire('METAL1', 220, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 220, 120, 2),
                Via('PDIF', 'METAL1', 220, 140, 2),
                Wire('PDIF', 220, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 220, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 148, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 148, 160, 2),
                Wire('METAL1', 148, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 148, 184, 2),
                Via('PDIF', 'METAL1', 196, 140, 2),
                Wire('PDIF', 196, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 196, 160, 2),
                Wire('METAL1', 196, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 196, 184, 2),
                Via('PDIF', 'METAL1', 240, 140, 2),
                Via('PDIF', 'METAL1', 240, 160, 2),
                Wire('METAL1', 240, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 240, 184, 2),
                Wire('PDIF', 242, (114, 186), 12, False),
            ],
            'vss': [
                Wire('NDIF', 20, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 24, 18, 2),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 128, 16, 2),
                Wire('PTIE', 128, (18, 34), 12, False),
                Via('NDIF', 'METAL1', 196, 18, 2),
                Wire('NDIF', 196, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 240, 18, 2),
                Wire('METAL1', 240, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 240, 40, 2),
                Wire('NDIF', 244, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a2a2a24_x2', width=300, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 58), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 140, 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
            ],
            '_net1': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', (38, 38), 140, 6, False),
                Wire('METAL1', 40, (42, 138), 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (42, 218), 40, 6, False),
                Wire('NDIF', 132, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('METAL1', 192, (42, 78), 6, False),
                Via('POLY', 'METAL1', 192, 80, 2),
                Wire('NDIF', 220, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Wire('POLY', (192, 272), 80, 8, False),
                Device('nmos', 272, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 272, (56, 104), 4, False),
                Device('pmos', 272, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
            ],
            '_net2': [
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 132, 140, 2),
                Wire('METAL1', 132, (142, 158), 6, False),
                Wire('PDIF', 132, (114, 186), 12, False),
                Wire('METAL1', (86, 178), 160, 6, False),
                Via('PDIF', 'METAL1', 132, 160, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            '_net3': [
                Via('PDIF', 'METAL1', 156, 140, 2),
                Wire('PDIF', 156, (114, 186), 12, False),
                Wire('METAL1', (158, 234), 140, 6, False),
                Wire('METAL1', 236, (142, 158), 6, False),
                Wire('PDIF', 236, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 236, 160, 2),
            ],
            '_net5': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            'i0': [
                Device('nmos', 248, 31, 4, 38, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 248, (52, 56), 4, False),
                Wire('POLY', 248, (104, 108), 4, False),
                Device('pmos', 248, 150, 4, 80, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (248, 260), 56, 4, False),
                Wire('POLY', (248, 260), 104, 4, False),
                Wire('METAL1', (254, 258), 60, 6, False),
                Wire('METAL1', (254, 258), 100, 6, False),
                Via('POLY', 'METAL1', 260, 60, 2),
                Wire('METAL1', 260, (62, 138), 6, True),
                Via('POLY', 'METAL1', 260, 100, 2),
            ],
            'i1': [
                Via('POLY', 'METAL1', 220, 60, 2),
                Wire('METAL1', 220, (62, 118), 6, True),
                Via('POLY', 'METAL1', 220, 100, 2),
                Wire('METAL1', (222, 226), 60, 6, False),
                Wire('POLY', 224, (98, 106), 4, False),
                Device('pmos', 224, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net3'),
                Wire('POLY', (220, 230), 56, 4, False),
                Device('nmos', 230, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net4'),
                Wire('POLY', 230, (50, 56), 4, False),
            ],
            'i2': [
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Device('nmos', 162, 31, 4, 38, 'vertical', source_net='_net7', drain_net='vss'),
                Wire('POLY', 162, (56, 102), 4, False),
                Wire('POLY', (160, 168), 104, 4, False),
                Wire('POLY', 168, (104, 110), 4, False),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net2'),
            ],
            'i3': [
                Wire('METAL1', 140, (62, 118), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('nmos', 144, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net7'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net3'),
            ],
            'i4': [
                Wire('METAL1', 120, (62, 118), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
                Wire('POLY', 120, (102, 108), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net2'),
                Device('nmos', 122, 31, 4, 38, 'vertical', source_net='_net6', drain_net='_net1'),
                Wire('POLY', 122, (56, 100), 4, False),
            ],
            'i5': [
                Wire('POLY', 96, (102, 108), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net0'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Wire('POLY', (96, 104), 102, 4, False),
                Device('nmos', 104, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 104, (56, 102), 4, False),
            ],
            'i6': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net5', drain_net='_net1'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', (48, 60), 100, 8, False),
                Wire('METAL1', 60, (62, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'i7': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net5'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 280, 40, 2),
                Wire('METAL1', 280, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 280, 120, 2),
                Via('PDIF', 'METAL1', 280, 140, 2),
                Via('PDIF', 'METAL1', 280, 160, 2),
                Wire('NDIF', 284, (16, 46), 12, False),
                Wire('PDIF', 284, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 212, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 212, 160, 2),
                Wire('METAL1', 212, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 212, 184, 2),
                Wire('PDIF', 260, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 260, 160, 2),
                Wire('METAL1', 260, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 260, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Via('NDIF', 'METAL1', 92, 18, 2),
                Wire('NDIF', 92, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 172, 18, 2),
                Wire('NDIF', 172, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 196, 16, 2),
                Wire('PTIE', 196, (20, 34), 12, False),
                Via('NDIF', 'METAL1', 260, 18, 2),
                Wire('NDIF', 260, (16, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2a2a2a24_x4', width=320, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 36, 140, 2),
                Wire('PDIF', 36, (114, 186), 12, False),
                Wire('METAL1', (38, 38), 140, 6, False),
                Wire('METAL1', 40, (42, 138), 6, False),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('METAL1', (42, 218), 40, 6, False),
                Wire('NDIF', 132, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('METAL1', 192, (42, 78), 6, False),
                Via('POLY', 'METAL1', 192, 80, 2),
                Wire('NDIF', 220, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 220, 40, 2),
                Wire('POLY', (192, 296), 80, 8, False),
                Device('nmos', 272, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 272, (56, 104), 4, False),
                Device('pmos', 272, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 296, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 296, (56, 104), 4, False),
                Device('pmos', 296, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Via('PDIF', 'METAL1', 156, 140, 2),
                Wire('PDIF', 156, (114, 186), 12, False),
                Wire('METAL1', (158, 234), 140, 6, False),
                Wire('METAL1', 236, (142, 158), 6, False),
                Wire('PDIF', 236, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 236, 160, 2),
            ],
            '_net2': [
                Wire('PDIF', 84, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Via('PDIF', 'METAL1', 132, 140, 2),
                Wire('METAL1', 132, (142, 158), 6, False),
                Wire('PDIF', 132, (114, 186), 12, False),
                Wire('METAL1', (86, 178), 160, 6, False),
                Via('PDIF', 'METAL1', 132, 160, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            '_net3': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('METAL1', (14, 58), 160, 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 140, 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
            ],
            '_net7': [
                Wire('NDIF', 36, (16, 46), 12, False),
            ],
            'i0': [
                Wire('POLY', 248, (104, 106), 4, False),
                Device('pmos', 248, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Device('nmos', 250, 31, 4, 38, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 250, (54, 56), 4, False),
                Wire('POLY', (248, 260), 104, 4, False),
                Wire('POLY', (250, 260), 56, 4, False),
                Via('POLY', 'METAL1', 260, 60, 2),
                Wire('METAL1', 260, (62, 138), 6, True),
                Via('POLY', 'METAL1', 260, 100, 2),
            ],
            'i1': [
                Via('POLY', 'METAL1', 220, 60, 2),
                Wire('METAL1', 220, (62, 118), 6, True),
                Via('POLY', 'METAL1', 220, 100, 2),
                Wire('POLY', 224, (98, 106), 4, False),
                Device('pmos', 224, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
                Wire('POLY', (220, 232), 56, 4, False),
                Device('nmos', 232, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net5'),
                Wire('POLY', 232, (54, 56), 4, False),
            ],
            'i2': [
                Wire('METAL1', 160, (62, 118), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
                Device('nmos', 162, 31, 4, 38, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 162, (56, 98), 4, False),
                Wire('POLY', (160, 168), 104, 4, False),
                Wire('POLY', 168, (104, 108), 4, False),
                Device('pmos', 168, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net2'),
            ],
            'i3': [
                Wire('METAL1', 140, (62, 118), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('nmos', 144, 31, 4, 38, 'vertical', source_net='_net0', drain_net='_net4'),
                Wire('POLY', 144, (56, 104), 4, False),
                Device('pmos', 144, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            'i4': [
                Wire('METAL1', 120, (62, 118), 6, True),
                Via('POLY', 'METAL1', 120, 100, 2),
                Wire('POLY', 120, (100, 106), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net2'),
                Device('nmos', 122, 31, 4, 38, 'vertical', source_net='_net6', drain_net='_net0'),
                Wire('POLY', 122, (56, 102), 4, False),
            ],
            'i5': [
                Wire('POLY', 96, (98, 106), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('METAL1', 100, (62, 118), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
                Device('nmos', 104, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 104, (56, 102), 4, False),
            ],
            'i6': [
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='_net7', drain_net='_net0'),
                Wire('POLY', 48, (56, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net3'),
                Wire('POLY', (48, 60), 100, 8, False),
                Wire('METAL1', 60, (62, 118), 6, True),
                Via('POLY', 'METAL1', 60, 100, 2),
            ],
            'i7': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 100, 2),
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net7'),
                Wire('POLY', 24, (56, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net0'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 280, 40, 2),
                Wire('METAL1', 280, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 280, 120, 2),
                Via('PDIF', 'METAL1', 280, 140, 2),
                Via('PDIF', 'METAL1', 280, 160, 2),
                Wire('NDIF', 284, (16, 46), 12, False),
                Wire('PDIF', 284, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 212, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 212, 160, 2),
                Wire('METAL1', 212, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 212, 184, 2),
                Wire('PDIF', 260, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 260, 160, 2),
                Wire('METAL1', 260, (162, 182), 6, False),
                Via('PDIF', 'METAL1', 260, 184, 2),
                Via('PDIF', 'METAL1', 304, 140, 2),
                Via('PDIF', 'METAL1', 304, 160, 2),
                Wire('METAL1', 304, (142, 182), 6, False),
                Via('PDIF', 'METAL1', 304, 184, 2),
                Wire('PDIF', 306, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Via('NDIF', 'METAL1', 92, 18, 2),
                Wire('NDIF', 92, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 172, 18, 2),
                Wire('NDIF', 172, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 196, 16, 2),
                Wire('PTIE', 196, (20, 34), 12, False),
                Wire('NDIF', 260, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 262, 18, 2),
                Via('NDIF', 'METAL1', 304, 18, 2),
                Wire('METAL1', 304, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 304, 40, 2),
                Wire('NDIF', 306, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2ao222_x2', width=200, height=200,
        nets={
            '_net0': [
                Wire('METAL1', 80, (62, 138), 6, False),
                Wire('METAL1', (82, 82), 140, 6, False),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
                Wire('METAL1', (86, 154), 140, 6, False),
                Wire('POLY', 156, (80, 104), 4, False),
                Via('POLY', 'METAL1', 156, 98, 2),
                Wire('METAL1', 156, (102, 138), 6, False),
                Wire('POLY', (156, 164), 104, 4, False),
                Wire('POLY', (156, 170), 78, 4, False),
                Device('pmos', 164, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 170, 50, 4, 40, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 170, (72, 78), 4, False),
            ],
            '_net1': [
                Wire('PDIF', 108, (114, 186), 8, False),
            ],
            '_net2': [
                Via('NDIF', 'METAL1', 58, 60, 2),
                Wire('METAL1', (58, 74), 60, 6, False),
            ],
            '_net3': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('NDIF', 80, (38, 66), 12, False),
                Wire('METAL1', (82, 134), 40, 6, False),
                Via('NDIF', 'METAL1', 136, 42, 2),
                Wire('NDIF', 138, (38, 66), 8, False),
            ],
            '_net5': [
                Wire('PDIF', 14, (114, 164), 8, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('PDIF', 60, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (14, 126), 160, 6, False),
                Wire('PDIF', 128, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 128, 160, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (42, 138), 6, True),
                Wire('POLY', 24, (80, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net5', drain_net='vdd'),
                Wire('POLY', (26, 32), 78, 4, False),
                Device('nmos', 32, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 32, (72, 78), 4, False),
            ],
            'i1': [
                Wire('POLY', 40, (76, 104), 4, False),
                Wire('METAL1', 40, (62, 138), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Wire('POLY', (40, 48), 76, 4, False),
                Wire('POLY', (40, 48), 104, 4, False),
                Device('nmos', 48, 52, 4, 36, 'vertical', source_net='_net4', drain_net='_net2'),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net5'),
            ],
            'i2': [
                Device('nmos', 94, 52, 4, 36, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 94, (74, 82), 4, False),
                Wire('POLY', 96, (82, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net1'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 118), 6, True),
            ],
            'i3': [
                Wire('POLY', 116, (78, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='_net1', drain_net='_net5'),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (62, 118), 6, True),
                Device('nmos', 124, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 124, (74, 82), 4, False),
            ],
            'i4': [
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('METAL1', 60, (82, 138), 6, True),
                Device('nmos', 66, 52, 4, 36, 'vertical', source_net='_net2', drain_net='_net3'),
                Wire('POLY', 66, (76, 98), 4, False),
                Wire('POLY', (64, 72), 102, 4, False),
                Wire('POLY', 72, (102, 106), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net5', drain_net='_net0'),
            ],
            'q': [
                Wire('PDIF', 178, (114, 186), 12, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Wire('NDIF', 180, (34, 66), 12, False),
                Via('NDIF', 'METAL1', 180, 60, 2),
                Wire('METAL1', 180, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 36, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Wire('PDIF', 156, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 156, 160, 2),
                Wire('METAL1', 156, (162, 186), 6, False),
                Via('PDIF', 'METAL1', 156, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('NDIF', 16, (18, 66), 12, False),
                Via('PTIE', 'METAL1', 48, 16, 2),
                Wire('PTIE', (46, 82), 16, 12, False),
                Via('PTIE', 'METAL1', 64, 16, 2),
                Via('PTIE', 'METAL1', 80, 16, 2),
                Via('NDIF', 'METAL1', 108, 18, 2),
                Wire('NDIF', 108, (22, 66), 12, False),
                Wire('NDIF', 160, (34, 66), 12, False),
                Wire('METAL1', 162, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 162, 40, 2),
                Via('NDIF', 'METAL1', 162, 60, 2),
                Via('PTIE', 'METAL1', 170, 14, 2),
                Wire('PTIE', (162, 184), 14, 12, False),
                Via('PTIE', 'METAL1', 184, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa2ao222_x4', width=220, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 56, (38, 66), 12, False),
                Wire('METAL1', (58, 58), 40, 6, False),
                Via('NDIF', 'METAL1', 58, 40, 2),
                Wire('METAL1', 58, (44, 60), 6, False),
                Wire('METAL1', (62, 78), 60, 6, False),
                Wire('METAL1', 80, (62, 138), 6, False),
                Wire('METAL1', (82, 82), 140, 6, False),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 8, False),
                Wire('METAL1', (86, 154), 140, 6, False),
                Via('POLY', 'METAL1', 156, 98, 2),
                Wire('METAL1', 156, (102, 138), 6, False),
                Wire('POLY', (152, 164), 98, 12, False),
                Device('nmos', 164, 50, 4, 40, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 164, (76, 104), 4, False),
                Device('pmos', 164, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (156, 188), 100, 8, False),
                Device('nmos', 192, 50, 4, 40, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 192, (76, 104), 4, False),
                Device('pmos', 192, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('NDIF', 34, (38, 66), 4, False),
            ],
            '_net2': [
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('NDIF', 80, (38, 66), 12, False),
                Wire('METAL1', (82, 126), 40, 6, False),
                Via('NDIF', 'METAL1', 128, 40, 2),
                Wire('NDIF', 128, (38, 66), 12, False),
            ],
            '_net3': [
                Wire('PDIF', 108, (114, 186), 8, False),
            ],
            '_net4': [
                Wire('PDIF', 12, (114, 164), 12, False),
                Via('PDIF', 'METAL1', 12, 160, 2),
                Wire('PDIF', 60, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (14, 126), 160, 6, False),
                Wire('PDIF', 128, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 128, 160, 2),
            ],
            'i0': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Wire('METAL1', 20, (62, 138), 6, True),
                Wire('POLY', (18, 26), 78, 8, False),
                Wire('POLY', 24, (84, 108), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='_net4', drain_net='vdd'),
                Device('nmos', 28, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 28, (74, 80), 4, False),
            ],
            'i1': [
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (80, 104), 4, False),
                Wire('METAL1', 40, (62, 138), 6, True),
                Wire('POLY', (40, 48), 76, 4, False),
                Wire('POLY', (40, 48), 104, 4, False),
                Device('nmos', 48, 52, 4, 36, 'vertical', source_net='_net1', drain_net='_net0'),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net4'),
            ],
            'i2': [
                Device('nmos', 88, 52, 4, 36, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 88, (74, 78), 4, False),
                Wire('POLY', (88, 90), 78, 4, False),
                Wire('POLY', (92, 96), 78, 4, False),
                Wire('POLY', 96, (78, 106), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net3'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 118), 6, True),
            ],
            'i3': [
                Wire('POLY', 116, (78, 104), 4, False),
                Device('pmos', 116, 150, 4, 80, 'vertical', source_net='_net3', drain_net='_net4'),
                Device('nmos', 120, 52, 4, 36, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 120, (72, 80), 4, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (62, 118), 6, True),
            ],
            'i4': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('POLY', 60, (80, 102), 4, False),
                Wire('METAL1', 60, (82, 138), 6, True),
                Wire('POLY', (60, 68), 76, 4, False),
                Wire('POLY', (62, 72), 102, 4, False),
                Device('nmos', 68, 52, 4, 36, 'vertical', source_net='_net0', drain_net='_net2'),
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net4', drain_net='_net0'),
            ],
            'q': [
                Wire('NDIF', 176, (34, 66), 12, False),
                Wire('PDIF', 176, (114, 186), 12, False),
                Via('NDIF', 'METAL1', 180, 40, 2),
                Via('NDIF', 'METAL1', 180, 60, 2),
                Wire('METAL1', 180, (40, 160), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 36, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Wire('PDIF', 152, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 152, 160, 2),
                Wire('METAL1', 152, (162, 186), 6, False),
                Via('PDIF', 'METAL1', 152, 184, 2),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('METAL1', 200, (122, 186), 6, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Via('PDIF', 'METAL1', 200, 184, 2),
                Wire('PDIF', 204, (114, 186), 12, False),
            ],
            'vss': [
                Wire('NDIF', 14, (38, 66), 8, False),
                Wire('METAL1', 20, (20, 40), 8, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Via('PTIE', 'METAL1', 48, 16, 2),
                Wire('PTIE', (46, 82), 16, 12, False),
                Via('PTIE', 'METAL1', 64, 16, 2),
                Via('PTIE', 'METAL1', 80, 16, 2),
                Via('NDIF', 'METAL1', 104, 16, 2),
                Wire('NDIF', 104, (22, 66), 12, False),
                Via('PTIE', 'METAL1', 128, 14, 2),
                Via('PTIE', 'METAL1', 152, 14, 2),
                Wire('METAL1', 152, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 152, 40, 2),
                Wire('NDIF', 152, (34, 66), 12, False),
                Via('NDIF', 'METAL1', 152, 60, 2),
                Wire('PTIE', (122, 198), 14, 12, False),
                Via('PTIE', 'METAL1', 176, 14, 2),
                Via('PTIE', 'METAL1', 200, 14, 2),
                Wire('METAL1', 200, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 200, 40, 2),
                Via('NDIF', 'METAL1', 200, 60, 2),
                Wire('NDIF', 204, (34, 66), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa3ao322_x2', width=220, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 166, (114, 166), 4, False),
            ],
            '_net1': [
                Via('NDIF', 'METAL1', 136, 40, 2),
                Wire('NDIF', 136, (38, 54), 8, False),
                Wire('METAL1', (138, 182), 40, 6, False),
                Wire('NDIF', 184, (38, 46), 8, False),
                Via('NDIF', 'METAL1', 186, 40, 2),
            ],
            '_net2': [
                Wire('PDIF', 68, (130, 166), 8, False),
                Via('PDIF', 'METAL1', 68, 160, 2),
                Wire('PDIF', 116, (126, 166), 8, False),
                Via('PDIF', 'METAL1', 116, 160, 2),
                Wire('METAL1', (70, 204), 160, 6, False),
                Via('PDIF', 'METAL1', 204, 160, 2),
                Wire('PDIF', 206, (114, 166), 8, False),
            ],
            '_net3': [
                Device('nmos', 32, 50, 4, 40, 'vertical', source_net='q', drain_net='vss'),
                Device('pmos', 32, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (32, 40), 76, 4, False),
                Wire('POLY', (32, 40), 104, 4, False),
                Wire('METAL1', 40, (42, 78), 6, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('POLY', 40, (76, 104), 4, False),
                Wire('METAL1', (42, 110), 40, 6, False),
                Via('NDIF', 'METAL1', 112, 40, 2),
                Wire('NDIF', 112, (38, 54), 8, False),
                Wire('METAL1', 112, (42, 58), 6, False),
                Wire('METAL1', (114, 138), 60, 6, False),
                Wire('METAL1', 140, (62, 138), 6, False),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('PDIF', 140, (114, 166), 8, False),
                Wire('PDIF', 148, (114, 118), 4, False),
            ],
            '_net4': [
                Wire('PDIF', 186, (114, 166), 4, False),
            ],
            '_net5': [
                Wire('NDIF', 90, (38, 62), 4, False),
            ],
            '_net6': [
                Wire('NDIF', 70, (38, 62), 4, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 60, 80, 2),
                Wire('METAL1', 60, (62, 138), 6, True),
                Wire('POLY', 60, (82, 120), 4, False),
                Device('pmos', 60, 148, 4, 44, 'vertical', source_net='vdd', drain_net='_net2'),
                Device('nmos', 64, 50, 4, 32, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 64, (72, 82), 4, False),
            ],
            'i1': [
                Wire('POLY', 78, (76, 120), 4, False),
                Device('pmos', 78, 148, 4, 44, 'vertical', source_net='_net2', drain_net='vdd'),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 138), 6, True),
                Device('nmos', 82, 50, 4, 32, 'vertical', source_net='_net6', drain_net='_net5'),
                Wire('POLY', 82, (72, 80), 4, False),
            ],
            'i2': [
                Device('nmos', 100, 50, 4, 32, 'vertical', source_net='_net5', drain_net='_net3'),
                Wire('POLY', 100, (72, 80), 4, False),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (82, 138), 6, True),
                Wire('POLY', 106, (78, 120), 4, False),
                Device('pmos', 106, 146, 4, 48, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            'i3': [
                Device('nmos', 146, 46, 4, 24, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 146, (62, 76), 4, False),
                Wire('POLY', (148, 156), 76, 4, False),
                Wire('POLY', 156, (76, 104), 4, False),
                Device('pmos', 156, 140, 4, 60, 'vertical', source_net='_net3', drain_net='_net0'),
                Wire('METAL1', 160, (62, 138), 6, True),
                Via('POLY', 'METAL1', 160, 100, 2),
            ],
            'i4': [
                Wire('POLY', 176, (98, 104), 4, False),
                Device('pmos', 176, 140, 4, 60, 'vertical', source_net='_net0', drain_net='_net4'),
                Device('nmos', 178, 42, 4, 16, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 178, (56, 94), 4, False),
                Wire('METAL1', 180, (62, 138), 6, True),
                Via('POLY', 'METAL1', 180, 100, 2),
            ],
            'i5': [
                Device('nmos', 196, 42, 4, 16, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 196, (56, 104), 4, False),
                Device('pmos', 196, 140, 4, 60, 'vertical', source_net='_net4', drain_net='_net2'),
                Via('POLY', 'METAL1', 200, 80, 2),
                Wire('METAL1', 200, (62, 138), 6, True),
            ],
            'i6': [
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('METAL1', 120, (82, 138), 6, True),
                Device('nmos', 124, 46, 4, 24, 'vertical', source_net='_net3', drain_net='_net1'),
                Wire('POLY', 124, (64, 116), 4, False),
                Device('pmos', 124, 146, 4, 48, 'vertical', source_net='_net2', drain_net='_net3'),
            ],
            'q': [
                Wire('NDIF', 20, (34, 66), 12, False),
                Via('NDIF', 'METAL1', 20, 60, 2),
                Wire('METAL1', 20, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('PDIF', 20, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 44, 160, 2),
                Wire('METAL1', 44, (162, 186), 6, False),
                Wire('PDIF', 46, (114, 186), 8, False),
                Wire('PDIF', 92, (130, 178), 8, False),
                Via('PDIF', 'METAL1', 92, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 42, (34, 66), 4, False),
                Via('NDIF', 'METAL1', 48, 18, 2),
                Wire('NDIF', 48, (22, 66), 12, False),
                Via('NDIF', 'METAL1', 162, 18, 2),
                Wire('NDIF', 162, (18, 46), 12, False),
                Wire('METAL1', 204, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 204, 40, 2),
                Wire('NDIF', 206, (38, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='oa3ao322_x4', width=240, height=200,
        nets={
            '_net0': [
                Via('NDIF', 'METAL1', 156, 40, 2),
                Wire('NDIF', 156, (38, 54), 8, False),
                Wire('METAL1', (158, 202), 40, 6, False),
                Via('NDIF', 'METAL1', 204, 40, 2),
                Wire('NDIF', 204, (38, 46), 12, False),
            ],
            '_net1': [
                Wire('PDIF', 206, (114, 166), 4, False),
            ],
            '_net2': [
                Wire('PDIF', 186, (114, 166), 4, False),
            ],
            '_net3': [
                Wire('PDIF', 88, (130, 166), 12, False),
                Via('PDIF', 'METAL1', 88, 160, 2),
                Wire('PDIF', 136, (126, 166), 8, False),
                Via('PDIF', 'METAL1', 136, 160, 2),
                Wire('METAL1', (90, 224), 160, 6, False),
                Via('PDIF', 'METAL1', 224, 160, 2),
                Wire('PDIF', 226, (114, 166), 8, False),
            ],
            '_net4': [
                Device('nmos', 28, 50, 4, 40, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 28, (76, 104), 4, False),
                Device('pmos', 28, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (28, 60), 80, 8, False),
                Device('nmos', 52, 50, 4, 40, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 52, (76, 104), 4, False),
                Device('pmos', 52, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('METAL1', 64, (42, 78), 6, False),
                Via('POLY', 'METAL1', 64, 80, 2),
                Wire('METAL1', (62, 130), 40, 6, False),
                Via('NDIF', 'METAL1', 132, 40, 2),
                Wire('NDIF', 132, (38, 54), 8, False),
                Wire('METAL1', 132, (42, 58), 6, False),
                Wire('METAL1', (134, 158), 60, 6, False),
                Wire('METAL1', 160, (62, 138), 6, False),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('PDIF', 160, (114, 166), 12, False),
                Wire('PDIF', 168, (114, 166), 4, False),
            ],
            '_net5': [
                Wire('NDIF', 110, (38, 62), 4, False),
            ],
            '_net6': [
                Wire('NDIF', 90, (38, 62), 4, False),
            ],
            'i0': [
                Wire('POLY', 78, (78, 120), 4, False),
                Device('pmos', 78, 140, 4, 60, 'vertical', source_net='vdd', drain_net='_net3'),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('METAL1', 80, (62, 138), 6, True),
                Device('nmos', 84, 50, 4, 32, 'vertical', source_net='vss', drain_net='_net6'),
                Wire('POLY', 84, (72, 82), 4, False),
            ],
            'i1': [
                Wire('POLY', 96, (78, 120), 4, False),
                Device('pmos', 96, 140, 4, 60, 'vertical', source_net='_net3', drain_net='vdd'),
                Via('POLY', 'METAL1', 100, 80, 2),
                Wire('METAL1', 100, (62, 138), 6, True),
                Device('nmos', 102, 50, 4, 32, 'vertical', source_net='_net6', drain_net='_net5'),
                Wire('POLY', 102, (72, 80), 4, False),
            ],
            'i2': [
                Device('nmos', 120, 50, 4, 32, 'vertical', source_net='_net5', drain_net='_net4'),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('POLY', 120, (72, 104), 4, False),
                Wire('METAL1', 120, (80, 138), 6, True),
                Wire('POLY', (120, 128), 104, 4, False),
                Device('pmos', 128, 140, 4, 60, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'i3': [
                Device('nmos', 164, 46, 4, 24, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 164, (62, 76), 4, False),
                Wire('POLY', (168, 176), 76, 4, False),
                Wire('POLY', 176, (76, 104), 4, False),
                Device('pmos', 176, 140, 4, 60, 'vertical', source_net='_net4', drain_net='_net2'),
                Wire('METAL1', 180, (62, 138), 6, True),
                Via('POLY', 'METAL1', 180, 100, 2),
            ],
            'i4': [
                Device('nmos', 196, 42, 4, 16, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 196, (56, 104), 4, False),
                Device('pmos', 196, 140, 4, 60, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('METAL1', 200, (62, 138), 6, True),
                Via('POLY', 'METAL1', 200, 100, 2),
            ],
            'i5': [
                Device('nmos', 216, 42, 4, 16, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 216, (56, 104), 4, False),
                Device('pmos', 216, 140, 4, 60, 'vertical', source_net='_net1', drain_net='_net3'),
                Via('POLY', 'METAL1', 220, 80, 2),
                Wire('METAL1', 220, (62, 138), 6, True),
            ],
            'i6': [
                Via('POLY', 'METAL1', 140, 80, 2),
                Wire('METAL1', 140, (80, 138), 6, True),
                Device('nmos', 144, 46, 4, 24, 'vertical', source_net='_net4', drain_net='_net0'),
                Wire('POLY', 144, (64, 76), 4, False),
                Wire('POLY', 144, (80, 102), 4, False),
                Wire('POLY', (144, 148), 104, 4, False),
                Device('pmos', 148, 140, 4, 60, 'vertical', source_net='_net3', drain_net='_net4'),
            ],
            'q': [
                Wire('NDIF', 40, (34, 66), 12, False),
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Wire('PDIF', 40, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 40, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 18, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 20, 120, 2),
                Via('PDIF', 'METAL1', 20, 140, 2),
                Wire('METAL1', 20, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 20, 160, 2),
                Via('PDIF', 'METAL1', 20, 184, 2),
                Wire('PDIF', 64, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 64, 160, 2),
                Wire('METAL1', 64, (162, 186), 6, False),
                Wire('PDIF', 112, (114, 184), 12, False),
                Via('PDIF', 'METAL1', 112, 186, 2),
            ],
            'vss': [
                Wire('NDIF', 18, (34, 66), 8, False),
                Wire('METAL1', 20, (18, 58), 6, False),
                Via('NDIF', 'METAL1', 20, 40, 2),
                Via('NDIF', 'METAL1', 20, 60, 2),
                Wire('NDIF', 60, (34, 66), 4, False),
                Via('NDIF', 'METAL1', 68, 18, 2),
                Wire('NDIF', 68, (22, 66), 12, False),
                Via('NDIF', 'METAL1', 180, 16, 2),
                Wire('NDIF', 180, (18, 46), 12, False),
                Via('PTIE', 'METAL1', 208, 16, 2),
                Wire('PTIE', (206, 222), 16, 12, False),
                Via('PTIE', 'METAL1', 224, 16, 2),
                Wire('METAL1', 224, (14, 38), 6, False),
                Via('NDIF', 'METAL1', 224, 40, 2),
                Wire('NDIF', 226, (38, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='on12_x1', width=100, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (54, 66), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 60, 2),
                Via('POLY', 'METAL1', 16, 100, 2),
                Wire('METAL1', 16, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('POLY', (18, 48), 100, 4, False),
                Device('nmos', 52, 50, 4, 40, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 52, (76, 124), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='vdd', drain_net='q'),
            ],
            'i0': [
                Device('nmos', 70, 50, 4, 40, 'vertical', source_net='_net1', drain_net='q'),
                Device('pmos', 70, 150, 4, 40, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (70, 80), 76, 4, False),
                Wire('POLY', (70, 80), 124, 4, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', 80, (76, 124), 4, False),
                Wire('METAL1', 80, (62, 158), 6, True),
            ],
            'i1': [
                Device('nmos', 24, 60, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (74, 78), 4, False),
                Wire('POLY', 24, (124, 126), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 38), 80, 8, False),
                Wire('POLY', (24, 38), 120, 8, False),
                Via('POLY', 'METAL1', 40, 80, 2),
                Wire('METAL1', 40, (62, 158), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
            ],
            'q': [
                Wire('METAL1', 60, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 74), 40, 6, False),
                Wire('NDIF', 76, (34, 66), 8, False),
                Via('NDIF', 'METAL1', 78, 40, 2),
            ],
            'vdd': [
                Wire('PDIF', 38, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 38, 184, 2),
                Wire('PDIF', 84, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 84, 184, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 14, 16, 2),
                Wire('PTIE', 14, (18, 34), 12, False),
                Wire('NDIF', 38, (34, 66), 8, False),
                Wire('METAL1', 40, (22, 40), 8, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Via('PTIE', 'METAL1', 62, 14, 2),
                Wire('PTIE', (56, 82), 14, 12, False),
                Via('PTIE', 'METAL1', 84, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='on12_x4', width=160, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 60, 120, 2),
                Wire('METAL1', 60, (118, 158), 6, False),
                Wire('PDIF', 60, (114, 166), 8, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 74), 116, 6, False),
                Wire('NDIF', 76, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 76, 40, 2),
                Wire('METAL1', 76, (42, 114), 6, False),
                Via('POLY', 'METAL1', 80, 80, 2),
                Wire('POLY', (80, 136), 80, 8, False),
                Device('nmos', 112, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 112, (56, 104), 4, False),
                Device('pmos', 112, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Device('nmos', 136, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 136, (56, 104), 4, False),
                Device('pmos', 136, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            '_net1': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (154, 186), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('POLY', 'METAL1', 16, 80, 2),
                Wire('METAL1', 16, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('POLY', (14, 64), 80, 8, False),
                Device('nmos', 64, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 64, (56, 102), 4, False),
                Wire('POLY', (64, 68), 102, 4, False),
                Wire('POLY', 68, (102, 108), 4, False),
                Device('pmos', 68, 140, 4, 60, 'vertical', source_net='_net0', drain_net='_net2'),
            ],
            'i0': [
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 24, (56, 60), 4, False),
                Wire('POLY', 24, (138, 144), 4, False),
                Device('pmos', 24, 170, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (24, 38), 60, 8, False),
                Wire('POLY', (24, 38), 140, 8, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 140, 2),
            ],
            'i1': [
                Wire('POLY', 86, (100, 106), 4, False),
                Device('pmos', 86, 140, 4, 60, 'vertical', source_net='_net2', drain_net='vdd'),
                Device('nmos', 88, 31, 4, 38, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 88, (54, 58), 4, False),
                Wire('POLY', (86, 98), 100, 8, False),
                Wire('POLY', (88, 100), 60, 8, False),
                Via('POLY', 'METAL1', 100, 60, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('POLY', 'METAL1', 100, 100, 2),
            ],
            'q': [
                Via('NDIF', 'METAL1', 120, 40, 2),
                Wire('METAL1', 120, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 120, 120, 2),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Via('PDIF', 'METAL1', 120, 160, 2),
                Wire('NDIF', 124, (16, 46), 12, False),
                Wire('PDIF', 124, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (154, 186), 12, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Wire('PDIF', 100, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 104, 184, 2),
                Via('PDIF', 'METAL1', 144, 120, 2),
                Via('PDIF', 'METAL1', 144, 140, 2),
                Wire('METAL1', 144, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 144, 160, 2),
                Via('PDIF', 'METAL1', 144, 184, 2),
                Wire('PDIF', 146, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 36, 18, 2),
                Wire('NDIF', 44, (16, 46), 28, False),
                Via('NDIF', 'METAL1', 54, 18, 2),
                Via('NDIF', 'METAL1', 100, 18, 2),
                Wire('NDIF', 100, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 144, 18, 2),
                Wire('METAL1', 144, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 144, 40, 2),
                Wire('NDIF', 146, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='one_x0', width=60, height=200,
        nets={
            'q': [
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Wire('PDIF', 40, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 40, 140, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 146), 16, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (122, 186), 6, False),
                Via('NTIE', 'METAL1', 20, 184, 2),
                Wire('NTIE', (14, 46), 182, 12, False),
                Via('NTIE', 'METAL1', 40, 184, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 20, 20, 2),
                Wire('PTIE', 20, (18, 62), 12, False),
                Via('PTIE', 'METAL1', 20, 40, 2),
                Wire('METAL1', 20, (14, 98), 6, False),
                Via('PTIE', 'METAL1', 20, 60, 2),
                Via('POLY', 'METAL1', 20, 100, 2),
                Wire('POLY', (20, 28), 102, 8, False),
                Device('pmos', 28, 130, 4, 40, 'vertical', source_net='vdd', drain_net='q'),
                Wire('PTIE', (18, 42), 20, 12, False),
                Wire('METAL1', (20, 40), 24, 8, False),
                Via('PTIE', 'METAL1', 40, 20, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='powmid_x0', width=140, height=200,
        nets={
            'vdd': [
                Wire('METAL3', 40, (0, 200), 48, True),
                # Wire('METAL1', (20, 60), 200, 6, False),
            ],
            'vss': [
                # Wire('METAL1', (80, 120), 0, 6, False),
                Wire('METAL3', 100, (0, 200), 48, True),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='rowend_x0', width=20, height=200,
        nets={
            'vdd': [
            ],
            'vss': [
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='sff1_x4', width=360, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 276, (154, 186), 8, False),
            ],
            '_net1': [
                Wire('PDIF', 132, (154, 186), 4, False),
                Wire('PDIF', 136, (134, 186), 8, False),
            ],
            '_net2': [
                Wire('NDIF', 132, (34, 46), 8, False),
            ],
            '_net3': [
                Device('nmos', 284, 40, 4, 20, 'vertical', source_net='_net6', drain_net='vss'),
                Wire('POLY', 284, (54, 58), 4, False),
                Wire('POLY', (284, 290), 58, 4, False),
                Via('POLY', 'METAL1', 290, 60, 2),
            ],
            '_net4': [
                Wire('NDIF', 180, (16, 46), 12, False),
            ],
            '_net5': [
                Wire('PDIF', 182, (134, 186), 8, False),
            ],
            '_net6': [
                Wire('NDIF', 276, (34, 46), 12, False),
            ],
            'ck': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='nckr', drain_net='vss'),
                Wire('POLY', 24, (54, 58), 4, False),
                Wire('POLY', 24, (122, 128), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='nckr', drain_net='vdd'),
                Wire('POLY', (24, 38), 58, 4, False),
                Wire('POLY', (24, 40), 122, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
            ],
            'ckr': [
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', 60, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (134, 166), 8, False),
                Via('POLY', 'METAL1', 64, 80, 2),
                Via('POLY', 'METAL1', 140, 120, 2),
                Wire('POLY', (140, 150), 124, 4, False),
                Wire('METAL1', (142, 158), 120, 6, False),
                Wire('POLY', 150, (124, 126), 4, False),
                Device('pmos', 150, 150, 4, 40, 'vertical', source_net='_net1', drain_net='sff_m'),
                Wire('POLY', (64, 248), 80, 4, False),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (82, 118), 6, False),
                Device('nmos', 164, 40, 4, 20, 'vertical', source_net='sff_m', drain_net='_net4'),
                Wire('POLY', 164, (56, 80), 4, False),
                Device('nmos', 248, 40, 4, 20, 'vertical', source_net='y', drain_net='sff_s'),
                Wire('POLY', 248, (56, 80), 4, False),
                Via('POLY', 'METAL1', 248, 80, 2),
                Wire('METAL1', 252, (82, 138), 6, False),
                Via('POLY', 'METAL1', 252, 140, 2),
                Wire('POLY', (254, 264), 142, 4, False),
                Wire('POLY', 264, (142, 146), 4, False),
                Device('pmos', 264, 170, 4, 40, 'vertical', source_net='sff_s', drain_net='_net0'),
            ],
            'i': [
                Device('nmos', 96, 40, 4, 20, 'vertical', source_net='u', drain_net='vss'),
                Wire('POLY', 96, (54, 60), 4, False),
                Wire('POLY', 96, (138, 146), 4, False),
                Device('pmos', 96, 170, 4, 40, 'vertical', source_net='u', drain_net='vdd'),
                Via('POLY', 'METAL1', 100, 60, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('POLY', 'METAL1', 100, 140, 2),
                Wire('METAL1', (104, 118), 40, 6, False),
                Wire('METAL1', (104, 118), 160, 6, False),
                Wire('METAL1', (120, 120), 40, 6, True),
                Wire('METAL1', (120, 120), 160, 6, True),
            ],
            'nckr': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (42, 138), 6, False),
                Via('POLY', 'METAL1', 16, 100, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='vss', drain_net='ckr'),
                Wire('POLY', 52, (56, 124), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='vdd', drain_net='ckr'),
                Wire('METAL1', 140, (62, 98), 6, False),
                Wire('POLY', (16, 264), 100, 4, False),
                Via('POLY', 'METAL1', 140, 100, 2),
                Via('POLY', 'METAL1', 142, 60, 2),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='_net2', drain_net='sff_m'),
                Wire('POLY', 144, (52, 60), 4, False),
                Wire('POLY', 168, (100, 124), 4, False),
                Device('pmos', 168, 150, 4, 40, 'vertical', source_net='sff_m', drain_net='_net5'),
                Wire('POLY', 240, (100, 144), 4, False),
                Device('pmos', 240, 170, 4, 40, 'vertical', source_net='y', drain_net='sff_s'),
                Device('nmos', 266, 40, 4, 20, 'vertical', source_net='sff_s', drain_net='_net6'),
                Wire('POLY', 266, (56, 100), 4, False),
            ],
            'q': [
                Wire('POLY', 284, (102, 144), 4, False),
                Device('pmos', 284, 170, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (284, 292), 102, 4, False),
                Via('POLY', 'METAL1', 296, 100, 2),
                Wire('METAL1', (298, 320), 60, 6, False),
                Wire('METAL1', (298, 320), 100, 6, False),
                Via('NDIF', 'METAL1', 320, 40, 2),
                Wire('METAL1', 320, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 320, 120, 2),
                Via('PDIF', 'METAL1', 320, 140, 2),
                Via('PDIF', 'METAL1', 320, 160, 2),
                Wire('NDIF', 324, (16, 46), 12, False),
                Wire('PDIF', 324, (114, 186), 12, False),
            ],
            'sff_m': [
                Via('NDIF', 'METAL1', 154, 40, 2),
                Wire('NDIF', 156, (34, 46), 12, False),
                Wire('PDIF', 156, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', (158, 178), 40, 6, False),
                Wire('METAL1', (158, 178), 140, 6, False),
                Wire('METAL1', 180, (42, 138), 6, False),
                Wire('METAL1', (182, 206), 60, 6, False),
                Wire('METAL1', (182, 206), 120, 6, False),
                Via('POLY', 'METAL1', 204, 60, 2),
                Via('POLY', 'METAL1', 204, 120, 2),
                Wire('POLY', (208, 216), 58, 4, False),
                Wire('POLY', (208, 216), 122, 4, False),
                Device('nmos', 216, 21, 4, 18, 'vertical', source_net='vss', drain_net='y'),
                Wire('POLY', 216, (36, 58), 4, False),
                Wire('POLY', 216, (122, 146), 4, False),
                Device('pmos', 216, 170, 4, 40, 'vertical', source_net='vdd', drain_net='y'),
            ],
            'sff_s': [
                Via('PDIF', 'METAL1', 252, 160, 2),
                Wire('PDIF', 252, (154, 186), 12, False),
                Via('NDIF', 'METAL1', 256, 40, 2),
                Wire('METAL1', (254, 274), 40, 6, False),
                Wire('METAL1', (254, 274), 160, 6, False),
                Wire('METAL1', 274, (42, 158), 6, False),
                Wire('METAL1', (278, 294), 80, 6, False),
                Via('POLY', 'METAL1', 296, 80, 2),
                Device('nmos', 312, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 312, (56, 104), 4, False),
                Device('pmos', 312, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (296, 336), 80, 4, False),
                Device('nmos', 336, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 336, (56, 104), 4, False),
                Device('pmos', 336, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'u': [
                Via('POLY', 'METAL1', 80, 120, 2),
                Wire('METAL1', 82, (42, 158), 6, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 84, (34, 46), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Wire('PDIF', 84, (154, 186), 12, False),
                Wire('POLY', (80, 120), 120, 4, False),
                Wire('METAL1', 120, (62, 118), 6, False),
                Via('POLY', 'METAL1', 120, 120, 2),
                Wire('POLY', 120, (124, 144), 4, False),
                Device('pmos', 120, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
                Via('POLY', 'METAL1', 122, 60, 2),
                Device('nmos', 124, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 124, (54, 60), 4, False),
            ],
            'vdd': [
                Wire('PDIF', 38, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 38, 184, 2),
                Wire('PDIF', 108, (154, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 184, 2),
                Wire('PDIF', 204, (154, 186), 8, False),
                Wire('PDIF', 208, (154, 186), 4, False),
                Via('PDIF', 'METAL1', 208, 184, 2),
                Wire('PDIF', 298, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 300, 120, 2),
                Via('PDIF', 'METAL1', 300, 140, 2),
                Via('PDIF', 'METAL1', 300, 160, 2),
                Wire('METAL1', 302, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 304, 184, 2),
                Via('PDIF', 'METAL1', 344, 120, 2),
                Via('PDIF', 'METAL1', 344, 140, 2),
                Wire('METAL1', 344, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 344, 160, 2),
                Via('PDIF', 'METAL1', 344, 184, 2),
                Wire('PDIF', 346, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 38, 16, 2),
                Wire('NDIF', 38, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 60, 14, 2),
                Wire('PTIE', (58, 86), 14, 12, False),
                Via('PTIE', 'METAL1', 84, 14, 2),
                Via('NDIF', 'METAL1', 110, 16, 2),
                Wire('NDIF', 110, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 132, 14, 2),
                Wire('PTIE', (130, 158), 14, 12, False),
                Via('PTIE', 'METAL1', 156, 14, 2),
                Wire('NDIF', 204, (16, 26), 12, False),
                Via('NDIF', 'METAL1', 206, 18, 2),
                Via('PTIE', 'METAL1', 252, 14, 2),
                Wire('PTIE', (250, 278), 14, 12, False),
                Via('PTIE', 'METAL1', 274, 14, 2),
                Wire('NDIF', 298, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 302, 42, 2),
                Via('NDIF', 'METAL1', 304, 18, 2),
                Wire('METAL1', 304, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 344, 18, 2),
                Wire('METAL1', 344, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 344, 40, 2),
                Wire('NDIF', 346, (16, 46), 8, False),
            ],
            'y': [
                Device('nmos', 196, 21, 4, 18, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 196, (34, 40), 4, False),
                Wire('POLY', 196, (140, 146), 4, False),
                Device('pmos', 196, 170, 4, 40, 'vertical', source_net='_net5', drain_net='vdd'),
                Wire('POLY', (196, 202), 42, 4, False),
                Wire('POLY', (196, 202), 138, 4, False),
                Via('POLY', 'METAL1', 200, 40, 2),
                Via('POLY', 'METAL1', 200, 140, 2),
                Wire('METAL1', (202, 226), 40, 6, False),
                Wire('METAL1', (202, 226), 140, 6, False),
                Wire('PDIF', 224, (154, 186), 8, False),
                Wire('NDIF', 228, (16, 26), 12, False),
                Wire('METAL1', 228, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 228, 160, 2),
                Wire('PDIF', 230, (154, 186), 4, False),
                Wire('NDIF', 232, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 232, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='sff1r_x4', width=420, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 132, (154, 186), 4, False),
                Wire('PDIF', 136, (134, 186), 8, False),
            ],
            '_net1': [
                Device('nmos', 346, 40, 4, 20, 'vertical', source_net='_net5', drain_net='vss'),
                Wire('POLY', 346, (54, 58), 4, False),
                Wire('POLY', (346, 352), 58, 4, False),
                Via('POLY', 'METAL1', 352, 60, 2),
            ],
            '_net2': [
                Wire('PDIF', 182, (134, 186), 8, False),
            ],
            '_net3': [
                Via('PDIF', 'METAL1', 260, 160, 2),
                Wire('PDIF', 264, (154, 186), 12, False),
                Wire('METAL1', (266, 336), 160, 6, False),
                Via('PDIF', 'METAL1', 336, 160, 2),
            ],
            '_net4': [
                Wire('NDIF', 228, (16, 26), 4, False),
            ],
            '_net5': [
                Wire('NDIF', 332, (34, 46), 8, False),
            ],
            '_net6': [
                Wire('NDIF', 180, (16, 46), 12, False),
            ],
            'ck': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='nckr', drain_net='vss'),
                Wire('POLY', 24, (54, 58), 4, False),
                Wire('POLY', 24, (122, 128), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='nckr', drain_net='vdd'),
                Wire('POLY', (24, 38), 58, 4, False),
                Wire('POLY', (24, 40), 122, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (40, 158), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
            ],
            'ckr': [
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 60, (34, 46), 12, False),
                Wire('METAL1', 60, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('PDIF', 60, (134, 166), 8, False),
                Via('POLY', 'METAL1', 64, 80, 2),
                Via('POLY', 'METAL1', 146, 120, 2),
                Wire('POLY', 150, (118, 126), 4, False),
                Device('pmos', 150, 150, 4, 40, 'vertical', source_net='_net0', drain_net='sff_m'),
                Wire('METAL1', (148, 158), 120, 6, False),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (82, 118), 6, False),
                Device('nmos', 164, 40, 4, 20, 'vertical', source_net='sff_m', drain_net='_net6'),
                Wire('POLY', 164, (56, 80), 4, False),
                Wire('POLY', (64, 282), 80, 4, False),
                Via('POLY', 'METAL1', 286, 80, 2),
                Device('nmos', 290, 40, 4, 20, 'vertical', source_net='y', drain_net='sff_s'),
                Wire('POLY', 290, (56, 80), 4, False),
                Wire('METAL1', (292, 316), 80, 6, False),
                Wire('METAL1', 318, (82, 122), 6, False),
                Via('POLY', 'METAL1', 318, 122, 2),
                Wire('POLY', (316, 326), 124, 4, False),
                Wire('POLY', 326, (124, 144), 4, False),
                Device('pmos', 326, 170, 4, 40, 'vertical', source_net='sff_s', drain_net='_net3'),
            ],
            'i': [
                Device('nmos', 96, 40, 4, 20, 'vertical', source_net='u', drain_net='vss'),
                Wire('POLY', 96, (54, 60), 4, False),
                Wire('POLY', 96, (138, 146), 4, False),
                Device('pmos', 96, 170, 4, 40, 'vertical', source_net='u', drain_net='vdd'),
                Via('POLY', 'METAL1', 100, 60, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('POLY', 'METAL1', 100, 140, 2),
                Wire('METAL1', (104, 118), 40, 6, False),
                Wire('METAL1', (104, 118), 160, 6, False),
                Wire('METAL1', (120, 120), 40, 6, True),
                Wire('METAL1', (120, 120), 160, 6, True),
            ],
            'nckr': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('METAL1', 16, (42, 138), 6, False),
                Via('POLY', 'METAL1', 16, 100, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Device('nmos', 52, 40, 4, 20, 'vertical', source_net='vss', drain_net='ckr'),
                Wire('POLY', 52, (56, 124), 4, False),
                Device('pmos', 52, 150, 4, 40, 'vertical', source_net='vdd', drain_net='ckr'),
                Wire('METAL1', 140, (62, 98), 6, False),
                Via('POLY', 'METAL1', 140, 100, 2),
                Via('POLY', 'METAL1', 142, 60, 2),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='_net7', drain_net='sff_m'),
                Wire('POLY', 144, (52, 60), 4, False),
                Wire('POLY', (16, 304), 100, 4, False),
                Wire('POLY', 168, (100, 124), 4, False),
                Device('pmos', 168, 150, 4, 40, 'vertical', source_net='sff_m', drain_net='_net2'),
                Wire('POLY', 302, (100, 144), 4, False),
                Device('pmos', 302, 170, 4, 40, 'vertical', source_net='y', drain_net='sff_s'),
                Device('nmos', 306, 40, 4, 20, 'vertical', source_net='sff_s', drain_net='_net8'),
                Wire('POLY', 306, (56, 100), 4, False),
            ],
            'nrst': [
                Wire('POLY', 236, (140, 146), 4, False),
                Device('pmos', 236, 170, 4, 40, 'vertical', source_net='y', drain_net='vdd'),
                Device('nmos', 238, 21, 4, 18, 'vertical', source_net='_net4', drain_net='y'),
                Wire('POLY', 238, (36, 58), 4, False),
                Wire('POLY', (236, 258), 138, 4, False),
                Wire('POLY', (240, 256), 58, 4, False),
                Wire('POLY', 252, (140, 146), 4, False),
                Device('pmos', 252, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
                Via('POLY', 'METAL1', 260, 60, 2),
                Wire('METAL1', 260, (62, 118), 6, True),
                Via('POLY', 'METAL1', 260, 120, 2),
                Wire('POLY', 260, (124, 136), 8, False),
                Wire('METAL1', 280, (40, 58), 6, True),
                Wire('METAL1', (262, 300), 120, 6, True),
                Wire('METAL1', (266, 314), 60, 6, False),
                Wire('METAL1', (320, 320), 60, 6, True),
                Via('POLY', 'METAL1', 320, 60, 2),
                Device('nmos', 322, 40, 4, 20, 'vertical', source_net='_net8', drain_net='_net5'),
                Wire('POLY', 322, (54, 58), 4, False),
            ],
            'q': [
                Wire('POLY', 346, (102, 144), 4, False),
                Device('pmos', 346, 170, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (346, 354), 102, 6, False),
                Via('POLY', 'METAL1', 354, 100, 2),
                Wire('METAL1', (360, 382), 60, 6, False),
                Wire('METAL1', (360, 382), 100, 6, False),
                Via('NDIF', 'METAL1', 380, 40, 2),
                Wire('METAL1', 380, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 380, 120, 2),
                Via('PDIF', 'METAL1', 380, 140, 2),
                Via('PDIF', 'METAL1', 380, 160, 2),
                Wire('NDIF', 384, (16, 46), 12, False),
                Wire('PDIF', 384, (114, 186), 12, False),
            ],
            'sff_m': [
                Via('NDIF', 'METAL1', 154, 40, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', (158, 178), 40, 6, False),
                Wire('METAL1', (158, 178), 140, 6, False),
                Wire('METAL1', 180, (42, 138), 6, False),
                Wire('METAL1', (182, 206), 60, 6, False),
                Wire('METAL1', (182, 206), 120, 6, False),
                Via('POLY', 'METAL1', 208, 60, 2),
                Via('POLY', 'METAL1', 208, 120, 2),
                Wire('POLY', (208, 216), 58, 4, False),
                Wire('POLY', (208, 216), 122, 4, False),
                Device('nmos', 216, 21, 4, 18, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 216, (36, 58), 4, False),
                Wire('POLY', 216, (122, 146), 4, False),
                Device('pmos', 216, 170, 4, 40, 'vertical', source_net='vdd', drain_net='y'),
            ],
            'sff_s': [
                Via('NDIF', 'METAL1', 298, 40, 2),
                Via('PDIF', 'METAL1', 314, 142, 2),
                Wire('PDIF', 314, (150, 186), 12, False),
                Wire('METAL1', (304, 334), 40, 6, False),
                Wire('METAL1', (318, 334), 142, 6, False),
                Wire('METAL1', 336, (42, 138), 6, False),
                Wire('METAL1', (340, 356), 80, 6, False),
                Via('POLY', 'METAL1', 358, 80, 2),
                Device('nmos', 372, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 372, (56, 104), 4, False),
                Device('pmos', 372, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (358, 398), 80, 4, False),
                Device('nmos', 396, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 396, (56, 104), 4, False),
                Device('pmos', 396, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'u': [
                Via('POLY', 'METAL1', 80, 120, 2),
                Wire('METAL1', 82, (42, 158), 6, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('NDIF', 84, (34, 46), 12, False),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Wire('PDIF', 84, (154, 186), 12, False),
                Wire('POLY', (80, 120), 120, 4, False),
                Wire('METAL1', 120, (62, 118), 6, False),
                Via('POLY', 'METAL1', 120, 120, 2),
                Wire('POLY', 120, (124, 144), 4, False),
                Device('pmos', 120, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
                Via('POLY', 'METAL1', 122, 60, 2),
                Device('nmos', 124, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net7'),
                Wire('POLY', 124, (54, 60), 4, False),
            ],
            'vdd': [
                Via('NTIE', 'METAL1', 16, 186, 2),
                Wire('PDIF', 38, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 38, 184, 2),
                Via('NTIE', 'METAL1', 60, 186, 2),
                Wire('PDIF', 108, (154, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 184, 2),
                Via('NTIE', 'METAL1', 160, 186, 2),
                Wire('PDIF', 208, (154, 186), 4, False),
                Via('PDIF', 'METAL1', 208, 184, 2),
                Wire('PDIF', 242, (154, 186), 8, False),
                Via('PDIF', 'METAL1', 244, 184, 2),
                Wire('PDIF', 360, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 362, 120, 2),
                Via('PDIF', 'METAL1', 362, 140, 2),
                Wire('METAL1', 362, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 362, 160, 2),
                Via('PDIF', 'METAL1', 362, 184, 2),
                Via('PDIF', 'METAL1', 404, 120, 2),
                Via('PDIF', 'METAL1', 404, 140, 2),
                Wire('METAL1', 404, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 404, 160, 2),
                Via('PDIF', 'METAL1', 404, 184, 2),
                Wire('PDIF', 406, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 38, 16, 2),
                Wire('NDIF', 38, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 60, 14, 2),
                Wire('PTIE', (60, 84), 14, 12, False),
                Via('PTIE', 'METAL1', 84, 14, 2),
                Via('NDIF', 'METAL1', 110, 16, 2),
                Wire('NDIF', 110, (18, 46), 8, False),
                Via('PTIE', 'METAL1', 132, 14, 2),
                Wire('PTIE', (132, 156), 14, 12, False),
                Via('PTIE', 'METAL1', 156, 14, 2),
                Wire('NDIF', 204, (16, 26), 12, False),
                Via('NDIF', 'METAL1', 206, 18, 2),
                Via('PTIE', 'METAL1', 314, 14, 2),
                Wire('PTIE', (314, 338), 14, 12, False),
                Via('PTIE', 'METAL1', 338, 14, 2),
                Wire('NDIF', 360, (16, 46), 8, False),
                Wire('METAL1', 362, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 362, 42, 2),
                Via('NDIF', 'METAL1', 364, 18, 2),
                Via('NDIF', 'METAL1', 404, 18, 2),
                Wire('METAL1', 404, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 404, 40, 2),
                Wire('NDIF', 406, (16, 46), 8, False),
            ],
            'y': [
                Device('nmos', 196, 21, 4, 18, 'vertical', source_net='_net6', drain_net='vss'),
                Wire('POLY', 196, (34, 40), 4, False),
                Wire('POLY', 196, (140, 146), 4, False),
                Device('pmos', 196, 170, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (196, 202), 42, 4, False),
                Wire('POLY', (196, 202), 138, 4, False),
                Via('POLY', 'METAL1', 200, 40, 2),
                Via('POLY', 'METAL1', 200, 140, 2),
                Wire('METAL1', (202, 252), 40, 6, False),
                Wire('METAL1', 228, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 228, 160, 2),
                Wire('METAL1', (202, 284), 140, 6, False),
                Via('NDIF', 'METAL1', 254, 40, 2),
                Wire('NDIF', 264, (16, 46), 32, False),
                Via('PDIF', 'METAL1', 286, 140, 2),
                Wire('PDIF', 290, (140, 186), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='sff2_x4', width=480, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 254, (34, 46), 12, False),
                Wire('NDIF', 264, (34, 46), 8, False),
            ],
            '_net2': [
                Wire('NDIF', 12, (34, 46), 8, False),
                Wire('METAL1', 12, (42, 138), 6, False),
                Wire('PDIF', 12, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 14, 40, 2),
                Via('PDIF', 'METAL1', 14, 140, 2),
                Wire('METAL1', (14, 98), 40, 6, False),
                Wire('METAL1', 60, (42, 78), 6, False),
                Via('POLY', 'METAL1', 62, 80, 2),
                Device('nmos', 68, 40, 4, 20, 'vertical', source_net='_net1', drain_net='u'),
                Wire('POLY', 68, (56, 80), 4, False),
                Wire('POLY', 94, (122, 126), 4, False),
                Device('pmos', 94, 150, 4, 40, 'vertical', source_net='u', drain_net='_net9'),
                Via('POLY', 'METAL1', 98, 120, 2),
                Wire('METAL1', 100, (42, 118), 6, False),
            ],
            '_net5': [
                Wire('PDIF', 396, (154, 186), 12, False),
            ],
            '_net6': [
                Wire('NDIF', 302, (16, 46), 8, False),
                Wire('NDIF', 308, (16, 26), 12, False),
            ],
            '_net8': [
                Wire('PDIF', 250, (134, 186), 8, False),
            ],
            'ck': [
                Device('nmos', 164, 40, 4, 20, 'vertical', source_net='nckr', drain_net='vss'),
                Wire('POLY', 164, (54, 58), 4, False),
                Wire('POLY', 164, (122, 128), 4, False),
                Device('pmos', 164, 150, 4, 40, 'vertical', source_net='nckr', drain_net='vdd'),
                Wire('POLY', (164, 174), 122, 4, False),
                Wire('POLY', (164, 176), 58, 4, False),
                Via('POLY', 'METAL1', 180, 60, 2),
                Wire('METAL1', 180, (42, 138), 6, True),
                Via('POLY', 'METAL1', 180, 120, 2),
            ],
            'ckr': [
                Via('NDIF', 'METAL1', 204, 40, 2),
                Wire('NDIF', 204, (34, 46), 12, False),
                Wire('METAL1', 204, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 204, 140, 2),
                Wire('PDIF', 206, (134, 166), 8, False),
                Via('POLY', 'METAL1', 208, 80, 2),
                Via('POLY', 'METAL1', 262, 120, 2),
                Wire('POLY', 264, (120, 128), 4, False),
                Device('pmos', 264, 150, 4, 40, 'vertical', source_net='_net8', drain_net='sff_m'),
                Wire('METAL1', (262, 278), 120, 6, False),
                Via('POLY', 'METAL1', 280, 80, 2),
                Wire('METAL1', 280, (82, 118), 6, False),
                Wire('POLY', (208, 364), 80, 10, False),
                Device('nmos', 288, 40, 4, 20, 'vertical', source_net='sff_m', drain_net='_net6'),
                Wire('POLY', 288, (56, 80), 4, False),
                Wire('POLY', 364, (60, 82), 4, False),
                Wire('POLY', (364, 372), 58, 4, False),
                Via('POLY', 'METAL1', 368, 80, 2),
                Wire('POLY', (366, 370), 80, 8, False),
                Device('nmos', 372, 40, 4, 20, 'vertical', source_net='y', drain_net='sff_s'),
                Wire('POLY', 372, (52, 58), 4, False),
                Wire('METAL1', 372, (82, 138), 6, False),
                Via('POLY', 'METAL1', 372, 140, 2),
                Wire('POLY', (372, 384), 140, 8, False),
                Wire('POLY', 384, (142, 144), 4, False),
                Device('pmos', 384, 170, 4, 40, 'vertical', source_net='sff_s', drain_net='_net5'),
            ],
            'cmd': [
                Device('nmos', 22, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 22, (56, 124), 4, False),
                Device('pmos', 22, 150, 4, 40, 'vertical', source_net='_net2', drain_net='vdd'),
                Via('POLY', 'METAL1', 60, 100, 2),
                Wire('METAL1', 60, (100, 158), 6, True),
                Wire('POLY', (24, 100), 104, 4, False),
                Wire('POLY', 70, (106, 126), 4, False),
                Device('pmos', 70, 150, 4, 40, 'vertical', source_net='_net7', drain_net='u'),
                Device('nmos', 100, 40, 4, 20, 'vertical', source_net='u', drain_net='_net3'),
                Wire('POLY', 100, (56, 100), 4, False),
            ],
            'i0': [
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (62, 158), 6, True),
                Via('POLY', 'METAL1', 40, 120, 2),
                Wire('POLY', (38, 50), 58, 8, False),
                Wire('POLY', (38, 50), 122, 8, False),
                Device('nmos', 50, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 50, (52, 58), 4, False),
                Wire('POLY', 50, (120, 126), 4, False),
                Device('pmos', 50, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net7'),
            ],
            'i1': [
                Wire('POLY', 112, (120, 128), 4, False),
                Device('pmos', 112, 150, 4, 40, 'vertical', source_net='_net9', drain_net='vdd'),
                Wire('POLY', (114, 120), 122, 8, False),
                Device('nmos', 118, 40, 4, 20, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 118, (54, 58), 4, False),
                Via('POLY', 'METAL1', 120, 60, 2),
                Wire('METAL1', 120, (42, 140), 6, True),
                Via('POLY', 'METAL1', 120, 120, 2),
            ],
            'nckr': [
                Wire('NDIF', 154, (34, 46), 8, False),
                Wire('PDIF', 154, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 156, 40, 2),
                Wire('METAL1', 156, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 156, 140, 2),
                Via('POLY', 'METAL1', 160, 100, 2),
                Device('nmos', 196, 40, 4, 20, 'vertical', source_net='vss', drain_net='ckr'),
                Wire('POLY', 196, (56, 124), 4, False),
                Device('pmos', 196, 150, 4, 40, 'vertical', source_net='vdd', drain_net='ckr'),
                Via('POLY', 'METAL1', 260, 60, 2),
                Wire('METAL1', 260, (62, 98), 6, False),
                Via('POLY', 'METAL1', 260, 100, 2),
                Wire('POLY', (258, 270), 56, 4, False),
                Device('nmos', 270, 40, 4, 20, 'vertical', source_net='_net0', drain_net='sff_m'),
                Wire('POLY', 270, (52, 56), 4, False),
                Wire('POLY', (160, 384), 100, 4, False),
                Wire('POLY', 288, (100, 124), 4, False),
                Device('pmos', 288, 150, 4, 40, 'vertical', source_net='sff_m', drain_net='vdd'),
                Wire('POLY', 360, (100, 144), 4, False),
                Device('pmos', 360, 170, 4, 40, 'vertical', source_net='y', drain_net='sff_s'),
                Wire('POLY', 384, (60, 100), 4, False),
                Wire('POLY', (384, 390), 58, 4, False),
                Device('nmos', 390, 40, 4, 20, 'vertical', source_net='sff_s', drain_net='_net4'),
                Wire('POLY', 390, (52, 58), 4, False),
            ],
            'q': [
                Wire('POLY', 404, (98, 144), 4, False),
                Device('pmos', 404, 170, 4, 40, 'vertical', source_net='_net5', drain_net='vdd'),
                Device('nmos', 408, 40, 4, 20, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 408, (54, 56), 4, False),
                Wire('POLY', (408, 420), 60, 8, False),
                Wire('POLY', (408, 420), 100, 8, False),
                Via('POLY', 'METAL1', 416, 100, 2),
                Via('POLY', 'METAL1', 420, 60, 2),
                Wire('METAL1', (418, 440), 60, 6, False),
                Wire('METAL1', (418, 440), 100, 6, False),
                Via('NDIF', 'METAL1', 440, 40, 2),
                Wire('METAL1', 440, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 440, 120, 2),
                Via('PDIF', 'METAL1', 440, 140, 2),
                Via('PDIF', 'METAL1', 440, 160, 2),
                Wire('NDIF', 444, (16, 46), 12, False),
                Wire('PDIF', 444, (114, 186), 12, False),
            ],
            'sff_m': [
                Via('PDIF', 'METAL1', 276, 140, 2),
                Wire('PDIF', 276, (134, 166), 12, False),
                Via('NDIF', 'METAL1', 280, 40, 2),
                Wire('METAL1', (278, 298), 40, 6, False),
                Wire('METAL1', (278, 298), 140, 6, False),
                Wire('METAL1', 300, (42, 138), 6, False),
                Wire('METAL1', (302, 326), 60, 6, False),
                Wire('METAL1', (302, 326), 120, 6, False),
                Via('POLY', 'METAL1', 324, 120, 2),
                Via('POLY', 'METAL1', 328, 60, 2),
                Wire('POLY', (324, 336), 120, 10, False),
                Wire('POLY', (328, 338), 60, 8, False),
                Wire('POLY', 336, (120, 144), 4, False),
                Device('pmos', 336, 170, 4, 40, 'vertical', source_net='vdd', drain_net='y'),
                Device('nmos', 340, 21, 4, 18, 'vertical', source_net='vss', drain_net='y'),
                Wire('POLY', 340, (36, 62), 4, False),
            ],
            'sff_s': [
                Via('PDIF', 'METAL1', 372, 160, 2),
                Wire('PDIF', 372, (154, 186), 12, False),
                Via('NDIF', 'METAL1', 382, 40, 2),
                Wire('METAL1', (374, 394), 160, 6, False),
                Wire('METAL1', (384, 394), 40, 6, False),
                Wire('METAL1', 396, (42, 158), 6, False),
                Wire('METAL1', (398, 414), 80, 6, False),
                Via('POLY', 'METAL1', 416, 80, 2),
                Device('nmos', 432, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 432, (56, 104), 4, False),
                Device('pmos', 432, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (416, 456), 80, 8, False),
                Device('nmos', 456, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 456, (56, 104), 4, False),
                Device('pmos', 456, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'u': [
                Wire('NDIF', 76, (34, 46), 12, False),
                Wire('METAL1', 80, (62, 158), 6, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('NDIF', 84, (34, 62), 12, False),
                Via('NDIF', 'METAL1', 84, 62, 2),
                Wire('PDIF', 84, (134, 166), 8, False),
                Wire('PDIF', 90, (134, 166), 4, False),
                Wire('METAL1', (82, 238), 160, 6, False),
                Via('POLY', 'METAL1', 236, 140, 2),
                Wire('POLY', 236, (140, 146), 4, False),
                Device('pmos', 236, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net8'),
                Wire('METAL1', 240, (62, 158), 6, False),
                Via('POLY', 'METAL1', 242, 60, 2),
                Device('nmos', 244, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 244, (54, 58), 4, False),
            ],
            'vdd': [
                Wire('PDIF', 36, (134, 182), 8, False),
                Via('PDIF', 'METAL1', 36, 184, 2),
                Wire('PDIF', 128, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 128, 186, 2),
                Wire('PDIF', 180, (134, 182), 12, False),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Wire('PDIF', 226, (154, 186), 8, False),
                Via('PDIF', 'METAL1', 228, 184, 2),
                Wire('PDIF', 304, (154, 186), 12, False),
                Wire('PDIF', 320, (154, 186), 12, False),
                Via('PDIF', 'METAL1', 324, 184, 2),
                Wire('PDIF', 328, (154, 186), 4, False),
                Via('PDIF', 'METAL1', 420, 120, 2),
                Via('PDIF', 'METAL1', 420, 140, 2),
                Wire('METAL1', 420, (122, 178), 6, False),
                Wire('PDIF', 420, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 420, 160, 2),
                Via('PDIF', 'METAL1', 420, 184, 2),
                Via('PDIF', 'METAL1', 464, 120, 2),
                Via('PDIF', 'METAL1', 464, 140, 2),
                Wire('METAL1', 464, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 464, 160, 2),
                Via('PDIF', 'METAL1', 464, 184, 2),
                Wire('PDIF', 466, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 36, 16, 2),
                Wire('NDIF', 36, (18, 46), 8, False),
                Wire('NDIF', 132, (18, 46), 8, False),
                Via('NDIF', 'METAL1', 134, 18, 2),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('NDIF', 180, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 228, 18, 2),
                Wire('NDIF', 228, (18, 46), 12, False),
                Via('NDIF', 'METAL1', 332, 18, 2),
                Wire('NDIF', 422, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 424, 18, 2),
                Wire('METAL1', 424, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 424, 40, 2),
                Via('NDIF', 'METAL1', 464, 18, 2),
                Wire('METAL1', 464, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 464, 40, 2),
                Wire('NDIF', 466, (16, 46), 8, False),
            ],
            'y': [
                Wire('POLY', 312, (144, 146), 4, False),
                Device('pmos', 312, 170, 4, 40, 'vertical', source_net='vdd', drain_net='vdd'),
                Wire('POLY', (312, 324), 140, 8, False),
                Via('POLY', 'METAL1', 320, 40, 2),
                Wire('POLY', (318, 322), 40, 8, False),
                Device('nmos', 322, 21, 4, 18, 'vertical', source_net='_net6', drain_net='vss'),
                Wire('POLY', 322, (34, 38), 4, False),
                Via('POLY', 'METAL1', 324, 140, 2),
                Wire('METAL1', (322, 346), 140, 6, False),
                Wire('METAL1', (322, 352), 40, 6, False),
                Wire('PDIF', 344, (154, 186), 12, False),
                Wire('NDIF', 348, (16, 26), 8, False),
                Wire('METAL1', 348, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 348, 160, 2),
                Wire('PDIF', 352, (154, 186), 4, False),
                Wire('NDIF', 356, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 356, 40, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='srlatch_x1', width=120, height=200,
        nets={
            'nq': [
                Wire('PDIF', 20, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 22, 140, 2),
                Via('PDIF', 'METAL1', 22, 160, 2),
                Wire('METAL1', 30, (140, 160), 24, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Wire('METAL1', (40, 64), 70, 6, False),
                Via('POLY', 'METAL1', 64, 70, 2),
                Device('nmos', 70, 40, 4, 20, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 70, (56, 106), 4, False),
                Device('pmos', 70, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'q': [
                Device('nmos', 50, 40, 4, 20, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 50, (56, 106), 4, False),
                Device('pmos', 50, 150, 4, 80, 'vertical', source_net='_net1', drain_net='vdd'),
                Via('POLY', 'METAL1', 54, 90, 2),
                Wire('METAL1', (56, 80), 90, 6, False),
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (42, 158), 6, True),
                Wire('METAL1', 90, (140, 160), 24, False),
                Via('PDIF', 'METAL1', 98, 140, 2),
                Via('PDIF', 'METAL1', 98, 160, 2),
                Wire('PDIF', 100, (114, 186), 8, False),
            ],
            'rst': [
                Device('nmos', 90, 40, 4, 20, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 90, (56, 104), 4, False),
                Device('pmos', 90, 150, 4, 80, 'vertical', source_net='_net2', drain_net='q'),
                Via('POLY', 'METAL1', 96, 80, 2),
                Wire('METAL1', 100, (42, 118), 6, True),
            ],
            'set': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 24, 80, 2),
                Device('nmos', 30, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 30, (56, 104), 4, False),
                Device('pmos', 30, 150, 4, 80, 'vertical', source_net='nq', drain_net='_net0'),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 60, 184, 2),
                Wire('PDIF', 62, (114, 186), 8, False),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 16, 2),
                Wire('NDIF', 20, (22, 46), 8, False),
                Via('PTIE', 'METAL1', 40, 14, 2),
                Via('PTIE', 'METAL1', 60, 14, 2),
                Wire('METAL1', 60, (24, 40), 6, False),
                Via('NDIF', 'METAL1', 60, 40, 2),
                Wire('NDIF', 62, (34, 46), 8, False),
                Via('PTIE', 'METAL1', 80, 14, 2),
                Via('NDIF', 'METAL1', 100, 16, 2),
                Wire('NDIF', 100, (22, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='srlatch_x4', width=220, height=200,
        nets={
            '_net0': [
                Wire('PDIF', 36, (114, 186), 6, False),
            ],
            '_net1': [
                Wire('PDIF', 78, (114, 186), 8, False),
            ],
            'nq': [
                Wire('NDIF', 140, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 140, 60, 2),
                Wire('METAL1', 140, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 140, 120, 2),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('PDIF', 140, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
            ],
            'nq_i': [
                Wire('PDIF', 16, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 18, 140, 2),
                Via('PDIF', 'METAL1', 18, 160, 2),
                Wire('METAL1', 26, (140, 160), 24, False),
                Via('NDIF', 'METAL1', 36, 40, 2),
                Wire('METAL1', 36, (42, 158), 6, False),
                Wire('METAL1', (36, 60), 70, 6, False),
                Via('POLY', 'METAL1', 60, 70, 2),
                Device('nmos', 66, 40, 4, 20, 'vertical', source_net='vss', drain_net='q_i'),
                Wire('POLY', 66, (56, 106), 4, False),
                Device('pmos', 66, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net1'),
                Wire('METAL1', (36, 200), 40, 6, False),
                Device('nmos', 170, 50, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 170, (56, 128), 4, False),
                Device('pmos', 170, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (170, 190), 90, 8, False),
                Device('nmos', 190, 50, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 190, (56, 104), 4, False),
                Device('pmos', 190, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Via('POLY', 'METAL1', 196, 90, 2),
                Wire('METAL1', 200, (42, 88), 6, False),
            ],
            'q': [
                Wire('NDIF', 180, (35, 65), 12, False),
                Via('NDIF', 'METAL1', 180, 60, 2),
                Wire('METAL1', 180, (62, 158), 6, True),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 180, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
            ],
            'q_i': [
                Device('nmos', 46, 40, 4, 20, 'vertical', source_net='nq_i', drain_net='vss'),
                Wire('POLY', 46, (56, 106), 4, False),
                Device('pmos', 46, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Via('POLY', 'METAL1', 50, 90, 2),
                Wire('METAL1', (50, 78), 90, 6, False),
                Wire('NDIF', 78, (34, 60), 8, False),
                Via('NDIF', 'METAL1', 78, 60, 2),
                Wire('METAL1', 78, (60, 158), 6, False),
                Via('PDIF', 'METAL1', 98, 140, 2),
                Via('PDIF', 'METAL1', 98, 160, 2),
                Wire('METAL1', 100, (140, 160), 40, False),
                Wire('PDIF', 100, (114, 186), 8, False),
                Wire('METAL1', 120, (90, 158), 6, False),
                Via('POLY', 'METAL1', 124, 90, 2),
                Device('nmos', 130, 50, 4, 38, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 130, (56, 104), 4, False),
                Device('pmos', 130, 150, 4, 80, 'vertical', source_net='vdd', drain_net='nq'),
                Wire('POLY', (130, 150), 90, 8, False),
                Device('nmos', 150, 50, 4, 38, 'vertical', source_net='nq', drain_net='vss'),
                Wire('POLY', 150, (56, 128), 4, False),
                Device('pmos', 150, 150, 4, 80, 'vertical', source_net='nq', drain_net='vdd'),
            ],
            'rst': [
                Device('nmos', 90, 40, 4, 20, 'vertical', source_net='q_i', drain_net='vss'),
                Wire('POLY', 90, (56, 104), 4, False),
                Device('pmos', 90, 150, 4, 80, 'vertical', source_net='_net1', drain_net='q_i'),
                Via('POLY', 'METAL1', 96, 80, 2),
                Wire('METAL1', 100, (62, 118), 6, True),
            ],
            'set': [
                Wire('METAL1', 20, (42, 118), 6, True),
                Via('POLY', 'METAL1', 20, 80, 2),
                Device('nmos', 26, 40, 4, 20, 'vertical', source_net='vss', drain_net='nq_i'),
                Wire('POLY', 26, (56, 104), 4, False),
                Device('pmos', 26, 150, 4, 80, 'vertical', source_net='nq_i', drain_net='_net0'),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 56, 120, 2),
                Via('PDIF', 'METAL1', 56, 140, 2),
                Wire('METAL1', 56, (122, 178), 6, False),
                Wire('PDIF', 56, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 56, 160, 2),
                Via('PDIF', 'METAL1', 56, 184, 2),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 120, 184, 2),
                Via('PDIF', 'METAL1', 160, 120, 2),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', 160, (122, 178), 6, False),
                Wire('PDIF', 160, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
                Via('PDIF', 'METAL1', 160, 184, 2),
                Wire('PDIF', 200, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 200, 184, 2),
            ],
            'vss': [
                Via('NDIF', 'METAL1', 20, 14, 2),
                Wire('NDIF', 20, (14, 46), 8, False),
                Via('NDIF', 'METAL1', 56, 14, 2),
                Wire('NDIF', 56, (14, 46), 8, False),
                Via('PTIE', 'METAL1', 78, 14, 2),
                Via('NDIF', 'METAL1', 100, 14, 2),
                Wire('NDIF', 110, (12, 46), 30, False),
                Via('NDIF', 'METAL1', 120, 14, 2),
                Wire('NDIF', 120, (14, 65), 10, False),
                Via('PTIE', 'METAL1', 140, 14, 2),
                Via('NDIF', 'METAL1', 160, 14, 2),
                Wire('NDIF', 160, (14, 65), 10, False),
                Via('PTIE', 'METAL1', 180, 14, 2),
                Via('NDIF', 'METAL1', 200, 14, 2),
                Wire('NDIF', 200, (14, 65), 10, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='tie_x0', width=40, height=200,
        nets={
            'vdd': [
                Via('NTIE', 'METAL1', 20, 120, 2),
                Via('NTIE', 'METAL1', 20, 140, 2),
                Wire('NTIE', 20, (122, 180), 12, False),
                Wire('METAL1', 20, (128, 184), 6, False),
                Via('NTIE', 'METAL1', 20, 160, 2),
                Via('NTIE', 'METAL1', 20, 180, 2),
            ],
            'vss': [
                Via('PTIE', 'METAL1', 20, 20, 2),
                Wire('METAL1', 20, (18, 54), 6, False),
                Via('PTIE', 'METAL1', 20, 40, 2),
                Wire('PTIE', 20, (22, 58), 12, False),
                Via('PTIE', 'METAL1', 20, 60, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ts_x4', width=200, height=200,
        nets={
            '4': [
                Wire('NDIF', 84, (34, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 42, 2),
                Via('PDIF', 'METAL1', 84, 160, 2),
                Wire('PDIF', 84, (154, 186), 12, False),
                Wire('METAL1', (86, 94), 42, 6, False),
                Wire('METAL1', (86, 94), 160, 8, False),
                Wire('METAL1', 96, (44, 158), 6, False),
                Via('POLY', 'METAL1', 100, 60, 2),
                Via('POLY', 'METAL1', 100, 128, 2),
                Wire('POLY', (100, 128), 58, 4, False),
                Wire('POLY', (100, 128), 122, 4, False),
                Device('nmos', 128, 40, 4, 20, 'vertical', source_net='_net1', drain_net='vss'),
                Wire('POLY', 128, (52, 58), 4, False),
                Wire('POLY', 128, (122, 128), 4, False),
                Device('pmos', 128, 150, 4, 40, 'vertical', source_net='_net1', drain_net='_net0'),
            ],
            '_net0': [
                Wire('POLY', 24, (92, 104), 4, False),
                Device('pmos', 24, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', 48, (92, 104), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (24, 186), 92, 4, False),
                Via('PDIF', 'METAL1', 140, 140, 2),
                Wire('METAL1', 140, (142, 158), 6, False),
                Wire('PDIF', 140, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 140, 160, 2),
                Wire('METAL1', (142, 180), 160, 6, False),
                Via('NDIF', 'METAL1', 184, 40, 2),
                Via('POLY', 'METAL1', 184, 92, 2),
                Wire('METAL1', 184, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 184, 140, 2),
                Via('PDIF', 'METAL1', 184, 160, 2),
                Wire('NDIF', 186, (34, 46), 8, False),
                Wire('PDIF', 186, (134, 166), 8, False),
            ],
            '_net1': [
                Device('nmos', 24, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 24, (56, 76), 4, False),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 48, (56, 76), 4, False),
                Wire('POLY', (24, 122), 76, 4, False),
                Wire('NDIF', 116, (34, 46), 12, False),
                Via('NDIF', 'METAL1', 120, 40, 2),
                Via('POLY', 'METAL1', 120, 72, 2),
                Wire('METAL1', 120, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 120, 140, 2),
                Wire('PDIF', 120, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 120, 160, 2),
                Wire('METAL1', (118, 162), 40, 6, False),
                Via('NDIF', 'METAL1', 166, 40, 2),
                Wire('NDIF', 168, (34, 46), 8, False),
            ],
            'cmd': [
                Via('POLY', 'METAL1', 60, 60, 2),
                Wire('METAL1', 60, (42, 158), 6, True),
                Wire('POLY', (60, 76), 58, 4, False),
                Wire('METAL1', (62, 74), 116, 10, False),
                Device('nmos', 76, 40, 4, 20, 'vertical', source_net='vss', drain_net='4'),
                Wire('POLY', 76, (52, 58), 4, False),
                Wire('POLY', 76, (114, 144), 4, False),
                Device('pmos', 76, 170, 4, 40, 'vertical', source_net='vdd', drain_net='4'),
                Via('POLY', 'METAL1', 80, 116, 2),
                Wire('POLY', (76, 148), 112, 4, False),
                Via('POLY', 'METAL1', 140, 72, 2),
                Wire('METAL1', 140, (74, 106), 6, False),
                Via('POLY', 'METAL1', 140, 108, 2),
                Wire('POLY', 148, (114, 124), 4, False),
                Device('pmos', 148, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (140, 176), 76, 4, False),
                Device('nmos', 176, 40, 4, 20, 'vertical', source_net='_net1', drain_net='_net0'),
                Wire('POLY', 176, (56, 76), 4, False),
            ],
            'i': [
                Device('nmos', 158, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 158, (52, 58), 4, False),
                Via('POLY', 'METAL1', 160, 60, 2),
                Wire('METAL1', 160, (62, 138), 6, True),
                Via('POLY', 'METAL1', 160, 120, 2),
                Wire('POLY', (164, 176), 122, 4, False),
                Wire('POLY', 176, (122, 128), 4, False),
                Device('pmos', 176, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'q': [
                Wire('NDIF', 36, (16, 46), 12, False),
                Wire('PDIF', 36, (114, 186), 12, False),
                Via('NDIF', 'METAL1', 40, 40, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 40, 120, 2),
                Via('PDIF', 'METAL1', 40, 140, 2),
                Via('PDIF', 'METAL1', 40, 160, 2),
            ],
            'vdd': [
                Wire('PDIF', 14, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Via('PDIF', 'METAL1', 16, 184, 2),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 184, 2),
                Via('NTIE', 'METAL1', 108, 184, 2),
                Wire('PDIF', 162, (134, 186), 8, False),
                Via('PDIF', 'METAL1', 162, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 16, 18, 2),
                Wire('METAL1', 16, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('NDIF', 'METAL1', 60, 18, 2),
                Wire('NDIF', 60, (16, 46), 12, False),
                Via('PTIE', 'METAL1', 100, 16, 2),
                Wire('NDIF', 140, (34, 46), 4, False),
                Via('NDIF', 'METAL1', 144, 16, 2),
                Wire('NDIF', 144, (18, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='ts_x8', width=260, height=200,
        nets={
            '_net0': [
                Via('NDIF', 'METAL1', 144, 40, 2),
                Wire('NDIF', 144, (34, 46), 12, False),
                Via('PDIF', 'METAL1', 144, 160, 2),
                Wire('PDIF', 144, (154, 186), 12, False),
                Wire('METAL1', (146, 154), 40, 6, False),
                Wire('METAL1', (146, 154), 160, 8, False),
                Via('POLY', 'METAL1', 156, 60, 2),
                Wire('METAL1', 158, (42, 158), 6, False),
                Via('POLY', 'METAL1', 160, 128, 2),
                Wire('POLY', (154, 188), 58, 4, False),
                Wire('POLY', (158, 188), 122, 4, False),
                Device('nmos', 188, 40, 4, 20, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 188, (52, 58), 4, False),
                Wire('POLY', 188, (122, 128), 4, False),
                Device('pmos', 188, 150, 4, 40, 'vertical', source_net='_net2', drain_net='_net1'),
            ],
            '_net1': [
                Wire('POLY', 36, (92, 104), 4, False),
                Device('pmos', 36, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', 60, (92, 104), 4, False),
                Device('pmos', 60, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', 84, (92, 104), 4, False),
                Device('pmos', 84, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', 108, (92, 104), 4, False),
                Device('pmos', 108, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
                Wire('POLY', (36, 246), 92, 4, False),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Wire('METAL1', 200, (142, 158), 6, False),
                Wire('PDIF', 200, (134, 166), 8, False),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Wire('METAL1', (202, 246), 160, 6, False),
                Via('POLY', 'METAL1', 244, 92, 2),
                Wire('METAL1', 244, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 244, 140, 2),
                Via('PDIF', 'METAL1', 244, 160, 2),
                Via('NDIF', 'METAL1', 246, 40, 2),
                Wire('NDIF', 246, (34, 46), 8, False),
                Wire('PDIF', 246, (134, 166), 8, False),
            ],
            '_net2': [
                Device('nmos', 36, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 36, (56, 76), 4, False),
                Device('nmos', 60, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 60, (56, 76), 4, False),
                Device('nmos', 84, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 84, (56, 76), 4, False),
                Wire('POLY', (36, 178), 76, 4, False),
                Device('nmos', 108, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 108, (56, 76), 4, False),
                Via('NDIF', 'METAL1', 176, 40, 2),
                Wire('NDIF', 176, (34, 46), 12, False),
                Via('POLY', 'METAL1', 176, 72, 2),
                Wire('METAL1', 176, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('PDIF', 180, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Wire('METAL1', (178, 222), 40, 6, False),
                Via('NDIF', 'METAL1', 228, 40, 2),
            ],
            'cmd': [
                Wire('METAL1', 120, (42, 158), 6, True),
                Wire('METAL1', 124, (56, 64), 6, False),
                Wire('METAL1', (122, 134), 120, 6, False),
                Wire('POLY', (128, 132), 58, 4, False),
                Via('POLY', 'METAL1', 130, 60, 2),
                Device('nmos', 132, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net0'),
                Wire('POLY', 132, (52, 58), 4, False),
                Wire('POLY', 136, (110, 144), 4, False),
                Device('pmos', 136, 170, 4, 40, 'vertical', source_net='vdd', drain_net='_net0'),
                Via('POLY', 'METAL1', 140, 120, 2),
                Wire('POLY', (136, 208), 108, 4, False),
                Via('POLY', 'METAL1', 196, 72, 2),
                Wire('METAL1', 196, (74, 106), 6, False),
                Via('POLY', 'METAL1', 196, 108, 2),
                Wire('POLY', 208, (108, 124), 4, False),
                Device('pmos', 208, 150, 4, 40, 'vertical', source_net='_net1', drain_net='vdd'),
                Wire('POLY', (194, 236), 76, 4, False),
                Device('nmos', 236, 40, 4, 20, 'vertical', source_net='_net2', drain_net='_net1'),
                Wire('POLY', 236, (56, 76), 4, False),
            ],
            'i': [
                Device('nmos', 220, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net2'),
                Wire('POLY', 220, (52, 60), 4, False),
                Via('POLY', 'METAL1', 220, 60, 2),
                Wire('METAL1', 220, (62, 138), 6, True),
                Via('POLY', 'METAL1', 220, 120, 2),
                Wire('POLY', (220, 236), 122, 4, False),
                Wire('POLY', 236, (122, 128), 4, False),
                Device('pmos', 236, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net1'),
            ],
            'q': [
                Wire('NDIF', 48, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 48, 40, 2),
                Wire('METAL1', 48, (42, 158), 6, False),
                Via('PDIF', 'METAL1', 48, 120, 2),
                Via('PDIF', 'METAL1', 48, 140, 2),
                Wire('PDIF', 48, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 48, 160, 2),
                Wire('METAL1', (50, 98), 84, 6, False),
                Wire('NDIF', 96, (16, 46), 12, False),
                Wire('PDIF', 96, (114, 186), 12, False),
                Via('NDIF', 'METAL1', 100, 40, 2),
                Wire('METAL1', 100, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 100, 120, 2),
                Via('PDIF', 'METAL1', 100, 140, 2),
                Via('PDIF', 'METAL1', 100, 160, 2),
            ],
            'vdd': [
                Via('PDIF', 'METAL1', 24, 120, 2),
                Via('PDIF', 'METAL1', 24, 140, 2),
                Wire('METAL1', 24, (122, 178), 6, False),
                Wire('PDIF', 24, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 24, 160, 2),
                Via('PDIF', 'METAL1', 24, 184, 2),
                Via('PDIF', 'METAL1', 72, 120, 2),
                Via('PDIF', 'METAL1', 72, 140, 2),
                Wire('METAL1', 72, (122, 178), 6, False),
                Wire('PDIF', 72, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 72, 160, 2),
                Via('PDIF', 'METAL1', 72, 184, 2),
                Wire('PDIF', 120, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 124, 184, 2),
                Via('NTIE', 'METAL1', 168, 184, 2),
                Wire('PDIF', 222, (134, 180), 8, False),
                Via('PDIF', 'METAL1', 222, 184, 2),
            ],
            'vss': [
                Wire('NDIF', 26, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 28, 18, 2),
                Wire('METAL1', 28, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 28, 40, 2),
                Via('NDIF', 'METAL1', 72, 18, 2),
                Wire('METAL1', 72, (22, 38), 6, False),
                Wire('NDIF', 72, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 72, 40, 2),
                Via('NDIF', 'METAL1', 116, 18, 2),
                Wire('NDIF', 118, (16, 46), 8, False),
                Via('PTIE', 'METAL1', 166, 16, 2),
                Wire('PTIE', (158, 178), 14, 8, False),
                Via('NDIF', 'METAL1', 204, 18, 2),
                Wire('NDIF', 204, (18, 46), 12, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='xr2_x1', width=180, height=200,
        nets={
            '_net0': [
                Wire('NDIF', 14, (34, 46), 8, False),
                Wire('PDIF', 14, (134, 166), 8, False),
                Via('NDIF', 'METAL1', 16, 40, 2),
                Via('POLY', 'METAL1', 16, 80, 2),
                Wire('METAL1', 16, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('METAL1', 16, (142, 158), 6, False),
                Via('PDIF', 'METAL1', 16, 160, 2),
                Wire('POLY', (14, 96), 80, 4, False),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='q', drain_net='_net4'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='q', drain_net='_net2'),
            ],
            '_net1': [
                Wire('NDIF', 60, (16, 46), 12, False),
            ],
            '_net2': [
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 108, 120, 2),
                Wire('METAL1', 108, (122, 158), 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net3': [
                Wire('POLY', 72, (106, 112), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net2', drain_net='q'),
                Wire('POLY', (72, 82), 104, 4, False),
                Via('POLY', 'METAL1', 84, 100, 2),
                Wire('METAL1', (82, 98), 100, 6, False),
                Wire('METAL1', 100, (82, 98), 6, False),
                Wire('METAL1', (102, 118), 80, 6, False),
                Device('nmos', 120, 31, 4, 38, 'vertical', source_net='_net4', drain_net='vss'),
                Wire('POLY', 120, (56, 80), 4, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('POLY', (120, 160), 80, 4, False),
                Wire('NDIF', 152, (34, 46), 4, False),
                Wire('PDIF', 152, (134, 166), 4, False),
                Via('NDIF', 'METAL1', 160, 40, 2),
                Wire('NDIF', 160, (34, 46), 12, False),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (42, 138), 6, False),
                Via('PDIF', 'METAL1', 160, 140, 2),
                Wire('METAL1', 160, (142, 158), 6, False),
                Wire('PDIF', 160, (134, 166), 12, False),
                Via('PDIF', 'METAL1', 160, 160, 2),
            ],
            '_net4': [
                Wire('NDIF', 108, (16, 46), 12, False),
            ],
            'i0': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net0', drain_net='vss'),
                Wire('POLY', 24, (50, 56), 4, False),
                Wire('POLY', 24, (104, 124), 4, False),
                Device('pmos', 24, 150, 4, 40, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (24, 48), 56, 4, False),
                Wire('POLY', (24, 48), 104, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 48, (52, 56), 4, False),
                Wire('POLY', 48, (104, 110), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net2'),
            ],
            'i1': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net1', drain_net='q'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', (72, 82), 58, 4, False),
                Via('POLY', 'METAL1', 84, 60, 2),
                Wire('METAL1', (82, 138), 60, 6, False),
                Wire('POLY', 120, (102, 108), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net2', drain_net='vdd'),
                Wire('POLY', (120, 144), 102, 4, False),
                Via('POLY', 'METAL1', 140, 60, 2),
                Wire('METAL1', 140, (42, 158), 6, True),
                Via('POLY', 'METAL1', 140, 100, 2),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net3'),
                Wire('POLY', 144, (54, 62), 4, False),
                Wire('POLY', 144, (104, 124), 4, False),
                Device('pmos', 144, 150, 4, 40, 'vertical', source_net='vdd', drain_net='_net3'),
            ],
            'q': [
                Wire('METAL1', 60, (42, 118), 6, True),
                Wire('METAL1', (62, 78), 120, 6, False),
                Wire('METAL1', (62, 82), 40, 6, False),
                Via('NDIF', 'METAL1', 80, 40, 2),
                Wire('METAL1', 80, (122, 138), 6, False),
                Via('PDIF', 'METAL1', 80, 140, 2),
                Wire('NDIF', 84, (16, 46), 12, False),
                Wire('PDIF', 84, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('PDIF', 38, (114, 186), 8, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Via('PDIF', 'METAL1', 128, 184, 2),
                Wire('PDIF', 130, (114, 186), 8, False),
                Via('NTIE', 'METAL1', 162, 184, 2),
                Wire('NTIE', (160, 166), 184, 12, False),
            ],
            'vss': [
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 128, 18, 2),
                Wire('NDIF', 130, (16, 46), 8, False),
                Via('PTIE', 'METAL1', 158, 14, 2),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='xr2_x4', width=240, height=200,
        nets={
            '_net0': [
                Via('PDIF', 'METAL1', 60, 140, 2),
                Wire('METAL1', 60, (142, 158), 6, False),
                Wire('PDIF', 60, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 60, 160, 2),
                Wire('METAL1', (62, 106), 160, 6, False),
                Via('PDIF', 'METAL1', 108, 120, 2),
                Wire('METAL1', 108, (122, 158), 6, False),
                Via('PDIF', 'METAL1', 108, 140, 2),
                Wire('PDIF', 108, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 108, 160, 2),
            ],
            '_net1': [
                Wire('NDIF', 60, (16, 46), 12, False),
            ],
            '_net2': [
                Wire('NDIF', 108, (16, 46), 12, False),
            ],
            '_net3': [
                Via('NDIF', 'METAL1', 16, 40, 2),
                Wire('NDIF', 16, (34, 46), 12, False),
                Wire('METAL1', 16, (42, 118), 6, False),
                Via('POLY', 'METAL1', 16, 80, 2),
                Via('PDIF', 'METAL1', 16, 120, 2),
                Wire('METAL1', 16, (122, 138), 6, False),
                Wire('PDIF', 16, (114, 146), 12, False),
                Via('PDIF', 'METAL1', 16, 140, 2),
                Wire('POLY', (16, 96), 80, 4, False),
                Device('nmos', 96, 31, 4, 38, 'vertical', source_net='_net5', drain_net='_net2'),
                Wire('POLY', 96, (56, 104), 4, False),
                Device('pmos', 96, 150, 4, 80, 'vertical', source_net='_net5', drain_net='_net0'),
            ],
            '_net4': [
                Device('nmos', 72, 31, 4, 38, 'vertical', source_net='_net1', drain_net='_net5'),
                Wire('POLY', 72, (52, 58), 4, False),
                Wire('POLY', (72, 82), 58, 4, False),
                Via('POLY', 'METAL1', 84, 60, 2),
                Wire('METAL1', (82, 98), 60, 6, False),
                Wire('METAL1', 100, (62, 78), 6, False),
                Wire('METAL1', (102, 118), 80, 6, False),
                Via('POLY', 'METAL1', 120, 80, 2),
                Wire('POLY', 120, (80, 104), 4, False),
                Device('pmos', 120, 150, 4, 80, 'vertical', source_net='_net0', drain_net='vdd'),
                Wire('POLY', (120, 160), 80, 4, False),
                Wire('PDIF', 156, (114, 146), 12, False),
                Wire('NDIF', 158, (34, 62), 8, False),
                Via('NDIF', 'METAL1', 160, 60, 2),
                Via('POLY', 'METAL1', 160, 80, 2),
                Wire('METAL1', 160, (62, 114), 6, False),
                Via('PDIF', 'METAL1', 160, 116, 2),
            ],
            '_net5': [
                Wire('METAL1', 60, (42, 118), 6, False),
                Wire('METAL1', (62, 82), 120, 6, False),
                Wire('NDIF', 84, (16, 46), 12, False),
                Via('NDIF', 'METAL1', 84, 40, 2),
                Wire('METAL1', 84, (122, 138), 6, False),
                Via('PDIF', 'METAL1', 84, 140, 2),
                Wire('PDIF', 84, (114, 186), 12, False),
                Wire('METAL1', (62, 178), 40, 6, False),
                Wire('METAL1', 180, (42, 78), 6, False),
                Via('POLY', 'METAL1', 180, 80, 2),
                Device('nmos', 192, 31, 4, 38, 'vertical', source_net='vss', drain_net='q'),
                Wire('POLY', 192, (56, 104), 4, False),
                Device('pmos', 192, 150, 4, 80, 'vertical', source_net='vdd', drain_net='q'),
                Wire('POLY', (180, 212), 80, 8, False),
                Device('nmos', 212, 31, 4, 38, 'vertical', source_net='q', drain_net='vss'),
                Wire('POLY', 212, (56, 104), 4, False),
                Device('pmos', 212, 150, 4, 80, 'vertical', source_net='q', drain_net='vdd'),
            ],
            'i0': [
                Device('nmos', 24, 40, 4, 20, 'vertical', source_net='_net3', drain_net='vss'),
                Wire('POLY', 24, (50, 56), 4, False),
                Wire('POLY', 24, (106, 112), 4, False),
                Device('pmos', 24, 130, 4, 40, 'vertical', source_net='_net3', drain_net='vdd'),
                Wire('POLY', (24, 48), 56, 4, False),
                Wire('POLY', (24, 48), 104, 4, False),
                Via('POLY', 'METAL1', 40, 60, 2),
                Wire('METAL1', 40, (42, 158), 6, True),
                Via('POLY', 'METAL1', 40, 100, 2),
                Device('nmos', 48, 31, 4, 38, 'vertical', source_net='vss', drain_net='_net1'),
                Wire('POLY', 48, (50, 56), 4, False),
                Wire('POLY', 48, (104, 110), 4, False),
                Device('pmos', 48, 150, 4, 80, 'vertical', source_net='vdd', drain_net='_net0'),
            ],
            'i1': [
                Wire('POLY', 72, (102, 108), 4, False),
                Device('pmos', 72, 150, 4, 80, 'vertical', source_net='_net0', drain_net='_net5'),
                Wire('POLY', (72, 82), 102, 4, False),
                Via('POLY', 'METAL1', 84, 100, 2),
                Wire('METAL1', (82, 138), 100, 6, False),
                Device('nmos', 120, 31, 4, 38, 'vertical', source_net='_net2', drain_net='vss'),
                Wire('POLY', 120, (52, 58), 4, False),
                Wire('POLY', (120, 144), 58, 4, False),
                Via('POLY', 'METAL1', 140, 60, 2),
                Via('POLY', 'METAL1', 140, 100, 2),
                Wire('METAL1', 140, (62, 158), 6, True),
                Device('nmos', 144, 40, 4, 20, 'vertical', source_net='vss', drain_net='_net4'),
                Wire('POLY', 144, (52, 58), 4, False),
                Wire('POLY', 144, (98, 106), 4, False),
                Device('pmos', 144, 130, 4, 40, 'vertical', source_net='vdd', drain_net='_net4'),
            ],
            'q': [
                Via('NDIF', 'METAL1', 200, 40, 2),
                Wire('METAL1', 200, (42, 158), 6, True),
                Via('PDIF', 'METAL1', 200, 120, 2),
                Via('PDIF', 'METAL1', 200, 140, 2),
                Via('PDIF', 'METAL1', 200, 160, 2),
                Wire('NDIF', 204, (16, 46), 12, False),
                Wire('PDIF', 204, (114, 186), 12, False),
            ],
            'vdd': [
                Wire('NTIE', 20, (166, 182), 12, False),
                Via('NTIE', 'METAL1', 20, 184, 2),
                Wire('PDIF', 40, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 40, 184, 2),
                Wire('PDIF', 128, (114, 186), 12, False),
                Via('PDIF', 'METAL1', 128, 184, 2),
                Wire('NTIE', 156, (166, 182), 12, False),
                Via('NTIE', 'METAL1', 156, 184, 2),
                Wire('PDIF', 176, (114, 132), 4, False),
                Via('PDIF', 'METAL1', 180, 120, 2),
                Wire('PDIF', 180, (114, 134), 4, False),
                Via('PDIF', 'METAL1', 180, 140, 2),
                Wire('METAL1', 180, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 180, 160, 2),
                Wire('PDIF', 180, (138, 186), 12, False),
                Via('PDIF', 'METAL1', 180, 184, 2),
                Wire('PDIF', 184, (114, 132), 4, False),
                Via('PDIF', 'METAL1', 224, 120, 2),
                Via('PDIF', 'METAL1', 224, 140, 2),
                Wire('METAL1', 224, (122, 178), 6, False),
                Via('PDIF', 'METAL1', 224, 160, 2),
                Via('PDIF', 'METAL1', 224, 184, 2),
                Wire('PDIF', 226, (114, 186), 8, False),
            ],
            'vss': [
                Wire('NDIF', 38, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 40, 18, 2),
                Via('NDIF', 'METAL1', 128, 18, 2),
                Wire('NDIF', 130, (16, 46), 8, False),
                Via('NDIF', 'METAL1', 180, 18, 2),
                Wire('NDIF', 180, (16, 38), 12, False),
                Via('NDIF', 'METAL1', 224, 18, 2),
                Wire('METAL1', 224, (22, 38), 6, False),
                Via('NDIF', 'METAL1', 224, 40, 2),
                Wire('NDIF', 226, (16, 46), 8, False),
            ],
        },
        finalize=True,
    ),
    StdCell(
        name='zero_x0', width=60, height=200,
        nets={
            'nq': [
                Via('NDIF', 'METAL1', 40, 60, 2),
                Wire('NDIF', 40, (54, 66), 12, False),
                Wire('METAL1', 40, (42, 158), 6, True),
            ],
            'vdd': [
                Via('POLY', 'METAL1', 20, 80, 2),
                Via('NTIE', 'METAL1', 20, 120, 2),
                Wire('METAL1', 20, (82, 186), 6, False),
                Via('NTIE', 'METAL1', 20, 140, 2),
                Wire('NTIE', 20, (118, 182), 12, False),
                Via('NTIE', 'METAL1', 20, 160, 2),
                Via('NTIE', 'METAL1', 20, 180, 2),
                Wire('POLY', (16, 28), 78, 8, False),
                Device('nmos', 28, 60, 4, 20, 'vertical', source_net='vss', drain_net='nq'),
                Wire('POLY', 28, (72, 80), 4, False),
                Wire('NTIE', (18, 42), 180, 12, False),
                Via('NTIE', 'METAL1', 40, 182, 2),
            ],
            'vss': [
                Wire('NDIF', 14, (54, 66), 8, False),
                Via('PTIE', 'METAL1', 16, 18, 2),
                Wire('METAL1', 16, (14, 58), 6, False),
                Via('NDIF', 'METAL1', 16, 60, 2),
                Wire('PTIE', (14, 42), 20, 12, False),
                Via('PTIE', 'METAL1', 40, 18, 2),
            ],
        },
        finalize=True,
    ),
]
